@@ -1,6 +1,6 @@
 /* aguix.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2005 Ralf Hoffmann.
+ * Copyright (C) 2001-2006 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -23,6 +23,8 @@
 #include "aguix.h"
 #include "awindow.h"
 #include <locale.h>
+#include "utf8.hh"
+#include "drawablecont.hh"
 
 #ifdef USE_AGUIXTIMER
 #include <signal.h>
@@ -121,7 +123,6 @@ AGUIX::AGUIX()
 
   initOK=False;
   classname=NULL;
-  myfont=NULL;
   mainfont=NULL;
   dsp=NULL;
   colors=0;
@@ -156,20 +157,29 @@ AGUIX::AGUIX()
   
 int AGUIX::initX( int targc, char **targv, const char *tclassname )
 {
-#ifdef DEBUG
-  printf("Opening display...");
-#endif
+  debugmsg("Opening display...");
+
   char *displayname=getenv("DISPLAY");
   dsp=XOpenDisplay(displayname);
   if(dsp==NULL) {
-#ifdef DEBUG
-    printf("failed\n");
-#endif
+    debugmsg("failed");
     return 5;
   }
-#ifdef DEBUG
-  printf("Ok\n");
-#endif
+  debugmsg("Ok");
+  
+  if ( setlocale( LC_ALL, "" ) == NULL ) {
+    fprintf( stderr, "Worker Warning: locale not supported\n" );
+  }
+  if ( XSupportsLocale() == False ) {
+    fprintf( stderr, "Worker Warning: X doesn't support current locale, setting locale to C\n" );
+    setlocale( LC_ALL, "C" );
+  }
+  if ( XSetLocaleModifiers( "" ) == NULL ) {
+    fprintf( stderr, "Worker Warning: Cannot set locale modifiers\n" );
+  }
+
+  UTF8::checkSupportedEncodings();
+
   this->classname=dupstring(tclassname);
   scr=XDefaultScreen(dsp);
   cmap=DefaultColormap(dsp,scr);
@@ -177,35 +187,29 @@ int AGUIX::initX( int targc, char **targv, const char *tclassname )
   black=BlackPixel(dsp,scr);
 
   gc=XCreateGC(dsp,RootWindow(dsp,scr),0,0);
+  debugmsg( "Loading font..." );
+  if ( setFont( "fixed" ) != 0 ) {
+    debugmsg( "Trying generic font..." );
+    if ( setFont( "-misc-fixed-medium-r-semicondensed--13-*-*-*-c-*-*-*" ) != 0 ) {
+      debugmsg( "Trying even more generic font..." );
+      if ( setFont( "-misc-fixed-medium-r-semicondensed--*-*-*-*-c-*-*-*" ) != 0 ) {
+        debugmsg( "Trying * as a last resort..." );
+        if ( setFont( "*" ) != 0 ) {
+          panic( "no fixed font found, exit" );
+        }
+      }
+    }
+  }
+  debugmsg("Ok");
+
+  unsigned long gc_valuemask=GCGraphicsExposures|GCForeground|GCBackground|GCLineWidth|GCCapStyle;
   XGCValues gc_values;
   gc_values.graphics_exposures=False;
   gc_values.foreground=black;
   gc_values.background=white;
   gc_values.line_width=0;
   gc_values.cap_style=CapButt;
-#ifdef DEBUG
-  printf("Loading font...");
-#endif
-  myfont=XLoadQueryFont(dsp,"fixed");
-  if(myfont==NULL) {
-    printf("no font, trying default: ");
-    myfont=XLoadQueryFont(dsp,"fixed");
-    if(myfont==NULL) panic("failed");
-#ifndef DEBUG
-    printf("Ok\n");
-#endif
-  }
-#ifdef DEBUG
-  printf("Ok\n");
-#endif
-  CharHeight=myfont->ascent+myfont->descent;
-#if 0
-  CharWidth=myfont->max_bounds.rbearing-myfont->min_bounds.lbearing;
-#else
-  CharWidth=XTextWidth(myfont,"M",1);
-#endif
-  gc_values.font=myfont->fid;
-  unsigned long gc_valuemask=GCGraphicsExposures|GCForeground|GCBackground|GCLineWidth|GCFont|GCCapStyle;
+
   XChangeGC(dsp,gc,gc_valuemask,&gc_values);
 
   dotted_gc = XCreateGC( dsp, RootWindow( dsp, scr ), 0, 0 );
@@ -228,7 +232,6 @@ int AGUIX::initX( int targc, char **targv, const char *tclassname )
   gc_values.background = white;
   XChangeGC( dsp, dashdouble_gc, GCLineStyle | GCBackground | GCForeground, &gc_values );
 
-  if(getFont("fixed")==NULL) printf("Opps, no \"fixed\"\n");
   WM_delete_window=XInternAtom(dsp,"WM_DELETE_WINDOW",False);
   this->argc=targc;
   this->argv=targv;
@@ -242,21 +245,13 @@ int AGUIX::initX( int targc, char **targv, const char *tclassname )
   int rx, ry;
   Window rootw;
   XGetGeometry( dsp, DefaultRootWindow( dsp ), &rootw, &rx, &ry, &rootWindowWidth, &rootWindowHeight, &rbw, &rd );
-
-  if ( setlocale( LC_ALL, "" ) == NULL ) {
-    fprintf( stderr, "Worker Warning: locale not supported\n" );
-  }
-  if ( XSupportsLocale() == False ) {
-    fprintf( stderr, "Worker Warning: X doesn't support current locale, setting locale to C\n" );
-    setlocale( LC_ALL, "C" );
-  }
-  if ( XSetLocaleModifiers( "" ) == NULL ) {
-    fprintf( stderr, "Worker Warning: Cannot set locale modifiers\n" );
-  }
 #ifdef USE_XIM
   openIM();
 #endif
 
+  XA_NET_WM_NAME = XInternAtom( dsp, "_NET_WM_NAME", False );
+  XA_NET_WM_ICON_NAME = XInternAtom( dsp, "_NET_WM_ICON_NAME", False );
+
   initOK=True;
   return 0;
 }
@@ -297,7 +292,11 @@ void AGUIX::closeX()
   }
   fonts->closeEnum(id);
   if(classname!=NULL) _freesafe(classname);
-  if(myfont!=NULL) XFreeFont(dsp,myfont);
+
+  while ( colors > 0 ) {
+    removeLastColor();
+  }
+  
   if(privatecmap==true) {
     XFreeColormap(dsp,cmap);
   }
@@ -345,18 +344,13 @@ int AGUIX::getCharHeight() const
   return CharHeight;
 }
 
-int AGUIX::getCharWidth() const
-{
-  return CharWidth;
-}
-
 void AGUIX::setFG(int color)
 {
   if(color<0) color=0;
   if(color<colors) {
-    XSetForeground(dsp,gc,ColBuf[color]);
+    XSetForeground(dsp,gc, getPixel( color ) );
   } else {
-    XSetForeground(dsp,gc,ColBuf[colors-1]);
+    XSetForeground(dsp,gc, getPixel( colors - 1 ) );
   }
 }
 
@@ -366,9 +360,9 @@ void AGUIX::setFG(GC tgc,int color)
   else {
     if(color<0) color=0;
     if(color<colors) {
-      XSetForeground(dsp,tgc,ColBuf[color]);
+      XSetForeground(dsp,tgc, getPixel( color ) );
     } else {
-      XSetForeground(dsp,tgc,ColBuf[colors-1]);
+      XSetForeground(dsp,tgc, getPixel( colors - 1 ) );
     }
   }
 }
@@ -377,9 +371,9 @@ void AGUIX::setBG(int color)
 {
   if(color<0) color=0;
   if(color<colors) {
-    XSetBackground(dsp,gc,ColBuf[color]);
+    XSetBackground(dsp,gc, getPixel( color ) );
   } else {
-    XSetBackground(dsp,gc,ColBuf[colors-1]);
+    XSetBackground(dsp,gc, getPixel( colors - 1 ) );
   }
 }
 
@@ -389,9 +383,9 @@ void AGUIX::setBG(GC tgc,int color)
   else {
     if(color<0) color=0;
     if(color<colors) {
-      XSetBackground(dsp,tgc,ColBuf[color]);
+      XSetBackground(dsp,tgc, getPixel( color ) );
     } else {
-      XSetBackground(dsp,tgc,ColBuf[colors-1]);
+      XSetBackground(dsp,tgc, getPixel( colors - 1 ) );
     }
   }
 }
@@ -412,26 +406,30 @@ void AGUIX::FillRectangle(Drawable buffer,GC tgc,int x,int y,int w,int h)
   else XFillRectangle(dsp,buffer,tgc,x,y,w,h);
 }
 
-void AGUIX::DrawText(Drawable buffer,const char *text,int x,int y)
+void AGUIX::DrawText( DrawableCont &dc, const char *text, int x, int y, int color )
 {
-  XDrawString(dsp,buffer,gc,x,y+getFontBaseline(),text,strlen(text));
+  DrawText( dc, mainfont, text, x, y, color );
 }
 
-void AGUIX::DrawText(Drawable buffer,AGUIXFont *tf,const char *text,int x,int y)
+void AGUIX::DrawText( DrawableCont &dc, AGUIXFont *tf, const char *text, int x, int y, int color )
 {
-  XDrawString(dsp,buffer,tf->getGC(),x,y+tf->getBaseline(),text,strlen(text));
+  if ( tf == NULL ) {
+    mainfont->drawText( dc, text, x, y, color );
+  } else {
+    tf->drawText( dc, text, x, y, color );
+  }
 }
 
 int AGUIX::getFontBaseline() const
 {
-  if(mainfont!=NULL) return mainfont->getBaseline();
-  return myfont->ascent;
+  return mainfont->getBaseline();
 }
 
 int AGUIX::AddColor(int red,int green,int blue)
 {
-  XColor col;
   if(colors<256) {
+#ifndef HAVE_XFT
+    XColor col;
     col.flags=DoRed|DoGreen|DoBlue;
     col.red=red*256;
     col.green=green*256;
@@ -449,14 +447,45 @@ int AGUIX::AddColor(int red,int green,int blue)
     if ( colors == 1 ) {
       prepareExtColors( red, green, blue );
     }
+#else
+    XRenderColor col;
+    col.red = red * 256;
+    col.green = green * 256;
+    col.blue = blue * 256;
+    col.alpha = 0xffff;
+    if ( ! XftColorAllocValue ( dsp,
+                                DefaultVisual( dsp, scr ),
+                                cmap,
+                                &col,
+                                &ColBuf[colors] ) ) {
+      // error
+      if ( privatecmap == true ) return -1;
+      else {
+        // now try to go to a private colormap
+	changeColormap();
+	return AddColor( red, green, blue );
+      }
+    }
+    colors++;
+    if ( colors == 1 ) {
+      prepareExtColors( red, green, blue );
+    }
+#endif
   }
-  return colors-1;
+  return colors - 1;
 }
 
 void AGUIX::removeLastColor()
 {
   if(colors>0) {
+#ifdef HAVE_XFT
+    XftColorFree( dsp,
+                  DefaultVisual( dsp, scr ),
+                  cmap,
+                  &ColBuf[colors - 1] );
+#else
     XFreeColors(dsp,cmap,ColBuf+colors-1,1,0);
+#endif
     colors--;
   }
 }
@@ -473,12 +502,32 @@ char *AGUIX::getClassname() const
   return tstr;
 }
 
-unsigned long AGUIX::getPixel(int color) const
+unsigned long AGUIX::getPixel( int color ) const
 {
-  if((color<colors)&&(color>=0)) {
+  if ( color < colors && color >= 0 ) {
+#ifdef HAVE_XFT
+    return ColBuf[color].pixel;
+#else
+    return ColBuf[color];
+#endif
+  } else return 0;
+}
+
+#ifdef HAVE_XFT
+XftColor *AGUIX::getColBufEntry( int color )
+{
+  if ( color < colors && color >= 0 ) {
+    return &ColBuf[color];
+  } else return NULL;
+}
+#else
+unsigned long AGUIX::getColBufEntry( int color )
+{
+  if ( color < colors && color >= 0 ) {
     return ColBuf[color];
   } else return 0;
 }
+#endif
 
 Atom *AGUIX::getCloseAtom()
 {
@@ -489,13 +538,31 @@ void AGUIX::insertWindow(AWindow *win)
 {
   if(win==NULL) return;
   wins->addElement(win);
+
+  if ( win->isTopLevel() == true ) {
+    setTransientWindow( win );
+  }
 }
 
 void AGUIX::removeWindow(AWindow *win)
 {
   if(win==NULL) return;
   wins->removeElement(win);
-  if ( win == transientwindow ) setTransientWindow();
+  if ( win == transientwindow ) {
+    AWindow *new_transient_win = NULL, *win_id;
+    int id = wins->initEnum();
+
+    win_id = (AWindow*)wins->getFirstElement( id );
+    while ( win_id != NULL ) {
+      if ( win_id->isTopLevel() == true ) {
+        new_transient_win = win_id;
+      }
+      win_id = (AWindow*)wins->getNextElement( id );
+    }
+    wins->closeEnum( id );
+    
+    setTransientWindow( new_transient_win );
+  }
 }
 
 Message *AGUIX::wait4mess( int mode )
@@ -736,65 +803,17 @@ void AGUIX::buildAGMessage( Message *msg )
 {
   AGMessage *agmsg[2];
 
-  agmsg[0] = AGUIX_allocAGMessage();  // Hauptmessage
+  agmsg[0] = AGUIX_allocAGMessage( msg );  // Hauptmessage
   agmsg[1] = NULL;           // eventl. Nebenmessage;
   switch( msg->type ) {
-    case KeyPress:
-      agmsg[0]->type = AG_KEYPRESSED;
-    case KeyRelease:
-      if ( agmsg[0]->type == AG_NONE ) agmsg[0]->type = AG_KEYRELEASED;
-      agmsg[0]->key.window = msg->window;
-      agmsg[0]->key.key = msg->key;
-      agmsg[0]->key.keystate = msg->keystate;
-      agmsg[0]->key.keybuf = dupstring( msg->keybuf );
-      break;
-    case ButtonPress:
-      agmsg[0]->type = AG_MOUSEPRESSED;
     case ButtonRelease:
-      if ( agmsg[0]->type == AG_NONE ) {
-        agmsg[0]->type = AG_MOUSERELEASED;
-        agmsg[1] = AGUIX_allocAGMessage();
-        agmsg[1]->type = AG_MOUSECLICKED;
-        agmsg[1]->mouse.window = msg->window;
-        agmsg[1]->mouse.button = msg->button;
-        agmsg[1]->mouse.x = msg->mousex;
-        agmsg[1]->mouse.y = msg->mousey;
-        agmsg[1]->mouse.time = msg->time;
-      }
-      agmsg[0]->mouse.window = msg->window;
-      agmsg[0]->mouse.button = msg->button;
-      agmsg[0]->mouse.x = msg->mousex;
-      agmsg[0]->mouse.y = msg->mousey;
-      agmsg[0]->mouse.time = msg->time;
-      break;
-    case MotionNotify:
-      agmsg[0]->type = AG_MOUSEMOVE;
-      agmsg[0]->mouse.window = msg->window;
-      /* button is wrong -> use queryPointer */
-      agmsg[0]->mouse.button = 0;
-      agmsg[0]->mouse.x = msg->mousex;
-      agmsg[0]->mouse.y = msg->mousey;
-      break;
-    case Expose:
-      agmsg[0]->type = AG_EXPOSE;
-      agmsg[0]->expose.window = msg->window;
-      agmsg[0]->expose.x = msg->x;
-      agmsg[0]->expose.y = msg->y;
-      agmsg[0]->expose.w = msg->width;
-      agmsg[0]->expose.h = msg->height;
-      break;
-    case ClientMessage:
-      if ( msg->gadgettype == CLOSE_GADGET ) {
-        agmsg[0]->type = AG_CLOSEWINDOW;
-        agmsg[0]->closewindow.window = msg->window;
-      }
-      break;
-    case EnterNotify:
-      agmsg[0]->type = AG_ENTERWINDOW;
-    case LeaveNotify:
-      if ( agmsg[0]->type == AG_NONE ) agmsg[0]->type = AG_LEAVEWINDOW;
-      agmsg[0]->cross.window = msg->window;
-      break;
+      agmsg[1] = AGUIX_allocAGMessage();
+      agmsg[1]->type = AG_MOUSECLICKED;
+      agmsg[1]->mouse.window = msg->window;
+      agmsg[1]->mouse.button = msg->button;
+      agmsg[1]->mouse.x = msg->mousex;
+      agmsg[1]->mouse.y = msg->mousey;
+      agmsg[1]->mouse.time = msg->time;
   }
   // agmsg in FIFO speichern
   putAGMsg( agmsg[0] );
@@ -1043,9 +1062,9 @@ void AGUIX::SetWindowBG(Window win,int color)
 {
   if(color<0) color=0;
   if(color<colors) {
-    XSetWindowBackground(dsp,win,ColBuf[color]);
+    XSetWindowBackground(dsp,win, getPixel( color ) );
   } else {
-    XSetWindowBackground(dsp,win,ColBuf[color-1]);
+    XSetWindowBackground(dsp,win, getPixel( color - 1 ) );
   }
 }
 
@@ -1061,10 +1080,31 @@ void AGUIX::WindowtoFront(Window win)
 
 int AGUIX::changeColor(int index2,int red,int green,int blue)
 {
-  XColor col;
 #ifdef DEBUG
   printf("changeColor:%d/%d\n",index2,colors);
 #endif
+  if ( index2 < 0 || index2 >= colors ) return 1;
+
+#ifdef HAVE_XFT
+  XftColorFree( dsp,
+                DefaultVisual( dsp, scr ),
+                cmap,
+                &ColBuf[index2] );
+
+  XRenderColor col;
+  col.red = red * 256;
+  col.green = green * 256;
+  col.blue = blue * 256;
+  col.alpha = 0xffff;
+  if ( ! XftColorAllocValue ( dsp,
+                              DefaultVisual( dsp, scr ),
+                              cmap,
+                              &col,
+                              &ColBuf[index2] ) ) {
+    return -1;
+  }
+#else
+  XColor col;
   XFreeColors(dsp,cmap,ColBuf+index2,1,0);
   col.flags=DoRed|DoGreen|DoBlue;
   col.red=red*256;
@@ -1072,6 +1112,7 @@ int AGUIX::changeColor(int index2,int red,int green,int blue)
   col.blue=blue*256;
   if(!XAllocColor(dsp,cmap,&col)) return -1;
   ColBuf[index2]=col.pixel;
+#endif
 
   if ( index2 == 0 ) {
     prepareExtColors( red, green, blue );
@@ -1079,88 +1120,6 @@ int AGUIX::changeColor(int index2,int red,int green,int blue)
   return 0;
 }
 
-AGUIXFont::AGUIXFont(AGUIX *parent)
-{
-  name=NULL;
-  gc=0;
-  font=NULL;
-  aguix=parent;
-}
-
-AGUIXFont::~AGUIXFont()
-{
-  removeFont();
-}
-
-void AGUIXFont::removeFont()
-{
-  if(gc!=0) {
-    XFreeGC(aguix->getDisplay(),gc);
-    gc=0;
-  }
-  if(font!=NULL) {
-    XFreeFont(aguix->getDisplay(),font);
-    font=NULL;
-  }
-  if(name!=NULL) {
-    _freesafe(name);
-    name=NULL;
-  }
-}
-
-int AGUIXFont::setFont( const char *fontname )
-{
-  Display *dsp=aguix->getDisplay();
-  int scr=aguix->getScreen();
-  unsigned long white=WhitePixel(dsp,scr);
-  unsigned long black=BlackPixel(dsp,scr);
-  gc=XCreateGC(dsp,RootWindow(dsp,scr),0,0);
-  XGCValues gc_values;
-  gc_values.graphics_exposures=False;
-  gc_values.foreground=black;
-  gc_values.background=white;
-  gc_values.line_width=0;
-  gc_values.cap_style=CapButt;
-  font=XLoadQueryFont(dsp,fontname);
-  if(font==NULL) {
-    XFreeGC(dsp,gc);
-    gc=0;
-    return 1;
-  }
-  charHeight=font->ascent+font->descent;
-#if 0
-  charWidth=font->max_bounds.rbearing-font->min_bounds.lbearing;
-#else
-  charWidth=XTextWidth(font,"M",1);
-#endif
-  gc_values.font=font->fid;
-  unsigned long gc_valuemask=GCGraphicsExposures|GCForeground|GCBackground|GCLineWidth|GCFont|GCCapStyle;
-  XChangeGC(dsp,gc,gc_valuemask,&gc_values);
-  if(name!=NULL) _freesafe(name);
-  name=dupstring(fontname);
-  return 0;
-}
-
-const char *AGUIXFont::getName() const
-{
-  return name;
-}
-
-GC AGUIXFont::getGC() const
-{
-  return gc;
-}
-
-int AGUIXFont::getCharWidth() const
-{
-  return charWidth;
-}
-
-int AGUIXFont::getCharHeight() const
-{
-  return charHeight;
-}
-
 AGUIXFont *AGUIX::getFont( const char *name )
 {
   int id;
@@ -1185,11 +1144,6 @@ AGUIXFont *AGUIX::getFont( const char *name )
   return tf;
 }
 
-int AGUIXFont::getBaseline() const
-{
-  return font->ascent;
-}
-
 void AGUIX::ExposeHandler(Message *msg)
 {
   AWindow *win;
@@ -1349,30 +1303,13 @@ AGUIX::queryRootPointer(int *x,int *y)
 int
 AGUIX::setFont( const char *newfont )
 {
-  Flush();
   AGUIXFont *afont=getFont(newfont);
   if(afont==NULL) return 1;
   mainfont=afont;
-
-  XGCValues gc_values;
-  XFontStruct *xfont;
-  xfont=mainfont->getFontStruct();
-  
   CharHeight=mainfont->getCharHeight();
-  CharWidth=mainfont->getCharWidth();
-  gc_values.font=xfont->fid;
-  unsigned long gc_valuemask=GCFont;
-  XChangeGC(dsp,gc,gc_valuemask,&gc_values);
-  Flush();
   return 0;
 }
 
-XFontStruct*
-AGUIXFont::getFontStruct() const
-{
-  return font;
-}
-
 void
 AGUIX::changeColormap()
 {
@@ -1580,6 +1517,7 @@ bool AGUIX::isDoubleClick( Time t1, Time t2) const
  * used width = wantedWidth is NOT guaranteed
  *
  */
+//TODO eigentlich obsolete
 int AGUIX::scaleElementsW( int wantedWidth,
 			   int borderwidth,
 			   int minSpace,
@@ -2293,48 +2231,59 @@ int AGUIX::getTextWidth( const char *str, AGUIXFont *font )
 
 int AGUIX::getTextWidth( const char *str, AGUIXFont *font, int len )
 {
-  XFontStruct *fs;
   int slen;
+  AGUIXFont *use_font;
 
   if ( str == NULL ) return 0;
 
   if ( font != NULL ) {
-    fs = font->getFontStruct();
-  } else if ( mainfont != NULL ) {
-    fs = mainfont->getFontStruct();
+    use_font = font;
   } else {
-    fs = myfont;
+    use_font = mainfont;
   }
+  if ( use_font == NULL ) return 0;
 
   slen = strlen( str );
   if ( ( len < 0 ) || ( len > slen ) )
     len = slen;
 
-  return XTextWidth( fs, str, len );
+  return use_font->textWidth( str, len );
 }
 
 int AGUIX::getStrlen4Width( const char *str, int width, int *return_width, AGUIXFont *font )
 {
-  int maxlen, leftlen, leftw, rightlen, rightw, erglen, ergw, midlen, midw;
-  XFontStruct *fs;
+  int leftlen, leftw, rightlen, rightw, erglen, ergw, midlen, midw;
+  AGUIXFont *use_font;
 
-  if ( str == NULL ) {
+  if ( font != NULL ) {
+    use_font = font;
+  } else {
+    use_font = mainfont;
+  }
+  if ( use_font == NULL ) return 0;
+
+  if ( str == NULL || use_font == NULL ) {
     if ( return_width != NULL ) *return_width = 0;
     return 0;
   }
 
-  if ( font != NULL ) {
-    fs = font->getFontStruct();
-  } else if ( mainfont != NULL ) {
-    fs = mainfont->getFontStruct();
-  } else {
-    fs = myfont;
+  std::vector<int> lookup_list;
+
+  if ( UTF8::getUTF8Mode() != UTF8::UTF8_DISABLED ) {  
+    if ( UTF8::buildCharacterLookupList( str, lookup_list ) != 0 ) {
+      if ( return_width != NULL ) *return_width = 0;
+      return 0;
+    }
+    
+    if ( lookup_list.size() < 1 ) {
+      if ( return_width != NULL ) *return_width = 0;
+      return 0;
+    }
   }
 
-  maxlen = strlen( str );
   leftlen = leftw = 0;
-  rightlen = maxlen;
-  rightw = XTextWidth( fs, str, rightlen );
+  rightlen = strlen( str );
+  rightw = use_font->textWidth( str, rightlen );
 
   if ( leftw >= width ) {
     erglen = leftlen;
@@ -2346,15 +2295,25 @@ int AGUIX::getStrlen4Width( const char *str, int width, int *return_width, AGUIX
     // from now on leftw is always less than width
     // and rightw always more than width
 
+    // in UTF8 mode len means characters and not bytes!
+    if ( UTF8::getUTF8Mode() != UTF8::UTF8_DISABLED ) {
+      rightlen = lookup_list.size() - 1;
+    }
+
+    erglen = ergw = 0;
     for (;;) {
       midlen = ( leftlen + rightlen ) / 2;
       if ( ( midlen == leftlen ) || ( midlen == rightlen ) ) {
-	erglen = leftlen;
+        erglen = leftlen;
 	ergw = leftw;
 	break;
       }
 
-      midw = XTextWidth( fs, str, midlen );
+      if ( UTF8::getUTF8Mode() != UTF8::UTF8_DISABLED ) {
+        midw = use_font->textWidth( str, lookup_list[midlen] );
+      } else {
+        midw = use_font->textWidth( str, midlen );
+      }
       if ( midw == width ) {
 	erglen = midlen;
 	ergw = midw;
@@ -2369,26 +2328,49 @@ int AGUIX::getStrlen4Width( const char *str, int width, int *return_width, AGUIX
 	rightw = midw;
       }
     }
+    if ( UTF8::getUTF8Mode() != UTF8::UTF8_DISABLED ) {
+      if ( erglen > 0 ) {
+        // erglen is the number of characters
+        // the lookup list stores the number of bytes
+        erglen = lookup_list[erglen];
+      }
+    }
   }
 
   if ( return_width != NULL ) *return_width = ergw;
   return erglen;
 }
 
-void AGUIX::SetClipRectangles( AGUIXFont *font, int origin_x, int origin_y, XRectangle *rect, int rect_n, int ordering )
+void AGUIX::setClip( AGUIXFont *font, DrawableCont *dc, int x, int y, int width, int height )
 {
+  if ( dc != NULL ) {
+    dc->clip( x, y, width, height );
+  }
   if ( font != NULL ) {
-    XSetClipRectangles( dsp, font->getGC(), origin_x, origin_y, rect, rect_n, ordering );
+    font->clip( x, y, width, height );
   } else {
-    XSetClipRectangles( dsp, gc, origin_x, origin_y, rect, rect_n, ordering );
+    mainfont->clip( x, y, width, height );
+    
+    XRectangle clip_rect;
+    
+    clip_rect.x = x;
+    clip_rect.y = y;
+    clip_rect.width = width;
+    clip_rect.height = height;
+    
+    XSetClipRectangles( dsp, gc, 0, 0, &clip_rect, 1, Unsorted );
   }
 }
 
-void AGUIX::UnsetClipMask( AGUIXFont *font )
+void AGUIX::unclip( AGUIXFont *font, DrawableCont *dc )
 {
+  if ( dc != NULL ) {
+    dc->unclip();
+  }
   if ( font != NULL ) {
-    XSetClipMask( dsp, font->getGC(), None );
+    font->unclip();
   } else {
+    mainfont->unclip();
     XSetClipMask( dsp, gc, None );
   }
 }
@@ -2428,11 +2410,20 @@ void AGUIX::prepareExtColors( int gray_r, int gray_g, int gray_b )
   XColor col;
   Visual *vis;
 
+  //TODO auf XftColor umstellen
+  /* ich muesste alle noetigen Farben allokieren
+   * alles andere waere ein zu grosser Aufwand
+   * Dazu muss ich jedoch eine neue Datenstruktur
+   * benutzen, da 1. die map die gesamte XftColor
+   * Struktur kopieren muesste und 2. ich zu-
+   * saetzlich speichern muss, welche Farben
+   * tatsaehclich allokiert wurden
+   */
   _extcolors[EXTCOLOR_BLACK] = black;
   _extcolors[EXTCOLOR_WHITE] = white;
   if ( colors > 0 ) {
-    _extcolors[EXTCOLOR_LIGHTGRAY] = ColBuf[0];
-    _extcolors[EXTCOLOR_DARKGRAY] = ColBuf[0];
+    _extcolors[EXTCOLOR_LIGHTGRAY] = getPixel( 0 );
+    _extcolors[EXTCOLOR_DARKGRAY] = getPixel( 0 );
   } else {
     _extcolors[EXTCOLOR_LIGHTGRAY] = white;
     _extcolors[EXTCOLOR_DARKGRAY] = black;
@@ -2552,3 +2543,16 @@ void AGUIX::freeExtColors()
   // as I only support extended colors in true color
   // mode where there are now color cells
 }
+
+Atom AGUIX::getAtom( atom_name_t name ) const
+{
+  switch ( name ) {
+    case CLOSE_ATOM:
+      return WM_delete_window;
+    case NET_WM_NAME_ATOM:
+      return XA_NET_WM_NAME;
+    case NET_WM_ICON_NAME_ATOM:
+      return XA_NET_WM_ICON_NAME;
+  }
+  return None;
+}
