@@ -1,6 +1,6 @@
 /* aguix.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2005 Ralf Hoffmann.
+ * Copyright (C) 2001-2006 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -37,10 +37,15 @@
 #include <X11/cursorfont.h>
 #include <X11/Xatom.h>
 
+#ifdef HAVE_XFT
+#include <X11/Xft/Xft.h>
+#endif
+
 #include <map>
 
+#include "aguixfont.hh"
+
 class AWindow;
-class AGUIXFont;
 
 enum {MES_WAIT,MES_GET};
 enum {NON_GADGET,CLOSE_GADGET,BUTTON_GADGET,SHADOW_GADGET,CHOOSE_GADGET,LISTVIEW,ONELVC,MORELVC,STRING_GADGET};
@@ -65,20 +70,19 @@ public:
   void setFG(GC gc,int color);
   void setBG(GC gc,int color);
   int getCharHeight() const;
-  int getCharWidth() const;
   void FillRectangle(Drawable buffer,int x,int y,int w,int h);
-  void DrawText(Drawable buffer,const char *text,int x,int y);
+  void DrawText( class DrawableCont &dc, const char *text, int x, int y, int color );
   void DrawLine(Drawable buffer,int px1,int py1,int px2,int py2);
   void DrawPoint(Drawable buffer,int x,int y);
   void FillRectangle(Drawable buffer,GC gc,int x,int y,int w,int h);
-  void DrawText(Drawable buffer,AGUIXFont *,const char *text,int x,int y);
+  void DrawText( class DrawableCont &dc, AGUIXFont *, const char *text, int x, int y, int color );
   void DrawLine(Drawable buffer,GC gc,int px1,int py1,int px2,int py2);
   void DrawPoint(Drawable buffer,GC gc,int x,int y);
 
   void DrawTriangleFilled(Drawable buffer, int px1, int py1, int px2, int py2, int px3, int py3);
   void DrawTriangleFilled(Drawable buffer, GC tgc, int px1, int py1, int px2, int py2, int px3, int py3);
-  void SetClipRectangles( AGUIXFont *, int origin_x, int origin_y, XRectangle *rect, int rect_n, int ordering );
-  void UnsetClipMask( AGUIXFont *font );
+  void setClip( AGUIXFont *font, class DrawableCont *dc, int x, int y, int width, int height );
+  void unclip( AGUIXFont *font, class DrawableCont *dc );
 
   void ClearWin(Window win);
   void SetWindowBG(Window win,int color);
@@ -88,6 +92,12 @@ public:
   int changeColor(int,int,int,int);
   int getMaxCols() const;
   unsigned long getPixel(int color) const;
+#ifdef HAVE_XFT
+  XftColor *getColBufEntry( int color );
+#else
+  unsigned long getColBufEntry( int color );
+#endif
+
   char *getClassname() const;
   Atom *getCloseAtom();
   void insertWindow(AWindow *win);
@@ -195,22 +205,29 @@ public:
   void drawBorder( Drawable buffer, GC usegc, bool pressed, int x, int y, int w, int h, int topright_space );
   void drawBorder( Drawable buffer, bool pressed, int x, int y, int w, int h, int topright_space );
   bool extColorsAvail();
+
+  typedef enum { CLOSE_ATOM, NET_WM_NAME_ATOM, NET_WM_ICON_NAME_ATOM } atom_name_t;
+  Atom getAtom( atom_name_t name ) const;
 private:
   Display *dsp;
   int scr;
   Colormap cmap;
   GC gc, dotted_gc, dashxor_gc, dashdouble_gc;
-  Atom WM_delete_window;
+  Atom WM_delete_window,
+    XA_NET_WM_NAME,
+    XA_NET_WM_ICON_NAME;
   char *classname;
   unsigned long white,black;
-  XFontStruct *myfont;
   AGUIXFont *mainfont;
   int initOK;
   int argc;
   char **argv;
   int CharHeight;
-  int CharWidth;
+#ifdef HAVE_XFT
+  XftColor ColBuf[256];
+#else
   unsigned long ColBuf[256];
+#endif
   int colors;
   XEvent LastEvent;
   List *wins;
@@ -260,28 +277,4 @@ private:
   void freeExtColors();
 };
 
-class AGUIXFont
-{
-public:
-  AGUIXFont(AGUIX*);
-  ~AGUIXFont();
-  AGUIXFont( const AGUIXFont &other );
-  AGUIXFont &operator=( const AGUIXFont &other );
-
-  int setFont( const char* );
-  void removeFont();
-  GC getGC() const;
-  const char *getName() const;
-  int getCharHeight() const;
-  int getCharWidth() const;
-  int getBaseline() const;
-  XFontStruct *getFontStruct() const;
-private:
-  char *name;
-  GC gc;
-  AGUIX *aguix;
-  XFontStruct *font;
-  int charWidth,charHeight;
-};
-
 #endif
