@@ -52,7 +52,7 @@ public:
   int getData() const;
   void setData(int);
   void setState(bool);
-  int getState() const;
+  bool getState() const;
   virtual void redraw();
   virtual void flush();
   bool isInside(int x,int y) const;
