@@ -1,6 +1,6 @@
 /* condvar.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2002-2004 Ralf Hoffmann.
+ * Copyright (C) 2002-2006 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: condvar.h,v 1.5 2004/10/27 20:36:35 ralf Exp $ */
 
 #ifndef CONDVAR_H
 #define CONDVAR_H
@@ -34,13 +33,11 @@ public:
   CondVar( const CondVar &other );
   CondVar &operator=( const CondVar &other );
 
-  void wait();
-  void signal();
-  void bcast();
-  void lock();
-  void unlock();
+  virtual void wait();
+  virtual void signal();
+  virtual void bcast();
 protected:
+  pthread_cond_t _condvar;
 };
 
 #endif
-
