@@ -23,6 +23,7 @@
 #include "cyclebutton.h"
 #include "awindow.h"
 #include "guielement.h"
+#include "drawablecont.hh"
 
 const char *CycleButton::type="CycleButton";
 
@@ -170,7 +171,6 @@ void CycleButton::redraw()
 			{7.0/8, 4.0/8, 6.0/8, 3.0/8},
 			{7.0/8, 4.0/8, 8.0/8, 3.0/8}};
 
-  GC usegc;
   double x1,x2,ty1,y2;
   int len, strwidth;
   char *tstr;
@@ -182,14 +182,13 @@ void CycleButton::redraw()
   prepareBG();
   
   _aguix->ClearWin(win);
-  if(font==NULL) usegc=0; else usegc=font->getGC();
 
-  _aguix->drawBorder( win, usegc, ( state == 0 ) ? false : true, 0, 0, _h, _h, 0 );
-  _aguix->drawBorder( win, usegc, ( state == 0 ) ? false : true, _h, 0, _w - _h, _h, 0 );
+  _aguix->drawBorder( win, ( state == 0 ) ? false : true, 0, 0, _h, _h, 0 );
+  _aguix->drawBorder( win, ( state == 0 ) ? false : true, _h, 0, _w - _h, _h, 0 );
   
   bw = 2;
   
-  _aguix->setFG(usegc,1);
+  _aguix->setFG( 1 );
   for ( int i = 0; i < 11; i++ ) {
     x1 = circle[i][0];
     x2 = circle[i][2];
@@ -199,10 +198,9 @@ void CycleButton::redraw()
     x2 *= _h - 2 * bw - 1;
     ty1 *= _h - 2 * bw - 1;
     y2 *= _h - 2 * bw - 1;
-    _aguix->DrawLine( win, usegc, (int)x1 + bw, (int)ty1 + bw, (int)x2 + bw, (int)y2 + bw );
+    _aguix->DrawLine( win, (int)x1 + bw, (int)ty1 + bw, (int)x2 + bw, (int)y2 + bw );
   }
   
-  _aguix->setFG(usegc,fg);
   int ch;
   if(font==NULL) {
     ch=_aguix->getCharHeight();
@@ -220,11 +218,9 @@ void CycleButton::redraw()
     int dx = _h + 5;
 
     tstr[len] = '\0';
-    if ( font == NULL ) {
-      _aguix->DrawText( win, tstr, dx, dy );
-    } else {
-      _aguix->DrawText( win, font, tstr, dx, dy );
-    }
+
+    DrawableCont dc( _aguix, win );
+    _aguix->DrawText( dc, font, tstr, dx, dy, fg );
   }
   _freesafe(tstr);
 
@@ -301,7 +297,7 @@ bool CycleButton::handleMessage(XEvent *E,Message *msg)
 	  agmsg->type=AG_CYCLEBUTTONCLICKED;
 	  agmsg->cyclebutton.cyclebutton=this;
 	  agmsg->cyclebutton.option=act_opt;
-	  _aguix->putAGMsg(agmsg);
+          msgAndCB( std::auto_ptr<AGMessage>( agmsg ) );
 	}
 	if(instate!=0) {
 	  setState(0);
@@ -348,7 +344,7 @@ bool CycleButton::handleMessage(XEvent *E,Message *msg)
 	      agmsg->type=AG_CYCLEBUTTONCLICKED;
 	      agmsg->cyclebutton.cyclebutton=this;
 	      agmsg->cyclebutton.option=act_opt;
-	      _aguix->putAGMsg(agmsg);
+              msgAndCB( std::auto_ptr<AGMessage>( agmsg ) );
 	      if(instate!=0) {
 		setState(0);
 		instate=0;
@@ -362,7 +358,7 @@ bool CycleButton::handleMessage(XEvent *E,Message *msg)
 		agmsg->type = AG_CYCLEBUTTONCLICKED;
 		agmsg->cyclebutton.cyclebutton = this;
 		agmsg->cyclebutton.option = act_opt;
-		_aguix->putAGMsg( agmsg );
+                msgAndCB( std::auto_ptr<AGMessage>( agmsg ) );
 		redraw();
 	      }
 	      break;
@@ -373,7 +369,7 @@ bool CycleButton::handleMessage(XEvent *E,Message *msg)
 		agmsg->type = AG_CYCLEBUTTONCLICKED;
 		agmsg->cyclebutton.cyclebutton = this;
 		agmsg->cyclebutton.option = act_opt;
-		_aguix->putAGMsg( agmsg );
+                msgAndCB( std::auto_ptr<AGMessage>( agmsg ) );
 		redraw();
 	      }
 	      break;
