@@ -1,6 +1,6 @@
 /* fieldlistview.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2002-2005 Ralf Hoffmann.
+ * Copyright (C) 2002-2006 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -24,6 +24,7 @@
 #include <stdlib.h>
 #include "awindow.h"
 #include "guielement.h"
+#include "drawablecont.hh"
 
 const char *FieldListView::type="FieldListView";
 
@@ -137,6 +138,11 @@ FieldListView::FieldListView( AGUIX *caguix, int cx, int cy, int cwidth, int che
   drag_field = -1;
 
   header_cursor_set = false;
+  
+  _last_single_select_row = -1;
+  _last_single_select_time = 0;
+  _last_single_middle_row = -1;
+  _last_single_middle_time = 0;
 }
 
 FieldListView::~FieldListView()
@@ -459,9 +465,13 @@ int FieldListView::addRow()
   newrow = elements++;
   elementarray[ newrow ] = new Content();
 
+  // this code is actually not needed since adding rows cannot invalidate
+  // selection states (the selected rows still exist)
+#if 0
   // deactivate select/middle mode
   selectModeIgnore();
   middleModeIgnore();
+#endif
 
   return newrow;
 }
@@ -508,7 +518,7 @@ int FieldListView::deleteRow( int row )
   return 0;
 }
 
-void FieldListView::setXOffset( int nv )
+void FieldListView::setXOffset( int nv, bool no_redraw )
 {
   int t;
 
@@ -518,9 +528,11 @@ void FieldListView::setXOffset( int nv )
   if ( nv != xoffset ) {
     xoffset = nv;
     
-    redrawHeader();
-    redrawContent();
-    hbarredraw();
+    if ( no_redraw == false ) {
+      redrawHeader();
+      redrawContent();
+      hbarredraw();
+    }
   }
 }
 
@@ -552,7 +564,7 @@ void FieldListView::redrawContent()
   drawBuffer();
 }
 
-void FieldListView::setYOffset( int nv )
+void FieldListView::setYOffset( int nv, bool no_redraw )
 {
   if ( ( nv + maxdisplayv ) >= elements ) nv = elements - maxdisplayv;
   if ( nv < 0 ) nv = 0;
@@ -560,8 +572,10 @@ void FieldListView::setYOffset( int nv )
     yoffset = nv;
 
     clearNonElements();
-    redrawContent();
-    vbarredraw();
+    if ( no_redraw == false ) {
+      redrawContent();
+      vbarredraw();
+    }
   }
 }
 
@@ -707,10 +721,10 @@ void FieldListView::redrawLine( int element )
 			 vis * elementHeight + oy,
 			 getInnerWidth(),
 			 elementHeight );
-  if ( font == NULL )
-    _aguix->setFG( tfg );
-  else
-    _aguix->setFG( font->getGC(), tfg );
+
+  //TODO this could be member variable for efficiency since this method
+  // is usually could for every visible line
+  DrawableCont dc( _aguix, buffer );
   for ( f = 0; f < fields; f++ ) {
     if ( fieldwidth[ f ] < 0)
       ex = sx + getUsedWidth( f );
@@ -730,25 +744,20 @@ void FieldListView::redrawLine( int element )
       clip_rect.width = tx;
       
       clip_rect.height = _h;
-      _aguix->SetClipRectangles( font, 0, 0, &clip_rect, 1, Unsorted );
+      _aguix->setClip( font, &dc, clip_rect.x, clip_rect.y, clip_rect.width, clip_rect.height );
       s = elementarray[ element ]->getText( f );
+
       if ( fieldalign[ f ] == ALIGN_RIGHT ) {
 	int tw = _aguix->getTextWidth( s.c_str(), font );
-	if ( font == NULL )
-	  _aguix->DrawText( buffer, s.c_str(), ox + ex - xoffset - tw, vis * elementHeight + oy );
-	else
-	  _aguix->DrawText( buffer, font, s.c_str(), ox + ex - xoffset - tw, vis * elementHeight + oy );
+	_aguix->DrawText( dc, font, s.c_str(), ox + ex - xoffset - tw, vis * elementHeight + oy, tfg );
       } else {
-	if ( font == NULL )
-	  _aguix->DrawText( buffer, s.c_str(), ox + sx - xoffset, vis * elementHeight + oy );
-	else
-	  _aguix->DrawText( buffer, font, s.c_str(), ox + sx - xoffset, vis * elementHeight + oy );
+	_aguix->DrawText( dc, font, s.c_str(), ox + sx - xoffset, vis * elementHeight + oy, tfg );
       }
     }
     
     sx = ex;
   }
-  _aguix->UnsetClipMask( font );
+  _aguix->unclip( font, &dc );
   if ( getVisMark( element ) == true ) {
     _aguix->setDashDFG( 1 );
     _aguix->setDashDBG( 0 );
@@ -1028,7 +1037,7 @@ bool FieldListView::handleMessage( XEvent *E, Message *msg )
 	agmsg->fieldlv.time = msg->time;
 	agmsg->fieldlv.mouse = true;
 	agmsg->type = AG_FIELDLV_PRESSED;
-	_aguix->putAGMsg( agmsg );
+        msgAndCB( std::auto_ptr<AGMessage>( agmsg ) );
       }
     } else if ( msg->type == ButtonRelease ) {
       // handle button release only for header
@@ -1592,7 +1601,30 @@ void FieldListView::handleSelect( Message *msg )
 	  } else {
 	    agmsg->type = AG_FIELDLV_MULTISELECT;
 	  }
-	  _aguix->putAGMsg( agmsg );
+          msgAndCB( std::auto_ptr<AGMessage>( agmsg ) );
+
+          if ( clickSelected == 1 ) {
+            int dc_row = _last_single_select_row;
+            Time dc_time = _last_single_select_time;
+            
+            _last_single_select_row = clickFirstSelectedRow;
+            _last_single_select_time = msg->time;
+            
+            if ( isValidRow( dc_row ) == true && clickFirstSelectedRow == dc_row ) {
+              if ( _aguix->isDoubleClick( msg->time, dc_time ) == true ) {
+                agmsg = AGUIX_allocAGMessage();
+                agmsg->fieldlv.lv = this;
+                agmsg->fieldlv.row = clickFirstSelectedRow;
+                agmsg->fieldlv.time = msg->time;
+                agmsg->fieldlv.mouse = true;
+                agmsg->type = AG_FIELDLV_DOUBLECLICK;
+                msgAndCB( std::auto_ptr<AGMessage>( agmsg ) );
+                _last_single_select_row = -1;
+                _last_single_select_time = 0;
+              }
+            }
+          }
+ 
 	  _aguix->msgUnlock( this );
 	  selectMode = SELECT_IDLE;
 	  break;
@@ -1603,22 +1635,24 @@ void FieldListView::handleSelect( Message *msg )
   } else if ( msg->type == ClientMessage ) {
     if ( msg->specialType == Message::TIMEREVENT ) {
       if ( ( msg->time % 1 ) == 0 ) { //HARDCODED
-	if ( selectMode == SELECT_SCROLL_UP ) {
-	  newelement = clickLastSelectedRow - 1;
-	  if ( newelement >= 0 ) {
-	    scrollV1( -1 );
-	    clickSelected += selectRowsRange( clickLastSelectedRow, newelement, clickState );
-	    clickLastSelectedRow = newelement;
-	  }
-	} else if ( selectMode == SELECT_SCROLL_DOWN ) {
-	  newelement = clickLastSelectedRow + 1;
-	  if ( newelement < elements ) {
-	    scrollV1( 1 );
-	    clickSelected += selectRowsRange( clickLastSelectedRow, newelement, clickState );
-	    clickLastSelectedRow = newelement;
-	  }
-	}
-	_aguix->Flush();
+        if ( getCurrentMouseButtonState( win ) & _select_buttonmask ) {
+          if ( selectMode == SELECT_SCROLL_UP ) {
+            newelement = clickLastSelectedRow - 1;
+            if ( newelement >= 0 ) {
+              scrollV1( -1 );
+              clickSelected += selectRowsRange( clickLastSelectedRow, newelement, clickState );
+              clickLastSelectedRow = newelement;
+            }
+          } else if ( selectMode == SELECT_SCROLL_DOWN ) {
+            newelement = clickLastSelectedRow + 1;
+            if ( newelement < elements ) {
+              scrollV1( 1 );
+              clickSelected += selectRowsRange( clickLastSelectedRow, newelement, clickState );
+              clickLastSelectedRow = newelement;
+            }
+          }
+          _aguix->Flush();
+        }
       }
     }
   }
@@ -1709,11 +1743,19 @@ void FieldListView::handleThird(Message *msg)
     if ( ( msg->specialType == Message::TIMEREVENT ) &&
 	 ( thirdMode == THIRD_SCROLL ) ) {
       if ( ( msg->time % scrollDelta ) == 0 ) {
-	if ( scrollXDir < 0 ) setXOffset( xoffset - getHScrollStep() );
-	else if ( scrollXDir > 0 ) setXOffset( xoffset + getHScrollStep() );
-	if ( scrollYDir < 0 ) scrollV1( -1 );
-	else if ( scrollYDir > 0 ) scrollV1( 1 );
-	_aguix->Flush();
+        if ( getCurrentMouseButtonState( win ) & _scroll_buttonmask ) {
+          const int oldx = getXOffset(), oldy = getYOffset();
+
+          if ( scrollXDir < 0 ) setXOffset( xoffset - getHScrollStep(), true );
+          else if ( scrollXDir > 0 ) setXOffset( xoffset + getHScrollStep(), true );
+          if ( scrollYDir < 0 ) scrollV1( -1, true );
+          else if ( scrollYDir > 0 ) scrollV1( 1, true );
+
+          if ( getXOffset() != oldx || getYOffset() != oldy ) {
+            redraw();
+            _aguix->Flush();
+          }
+        }
       }
     }
   }
@@ -1835,12 +1877,14 @@ void FieldListView::handleHBar( Message *msg )
 	 ( hbarMode == HBAR_SCROLL ) ) {
       int tmx;
       double f1;
-      tmx = msg->mousex;
+
+      _aguix->queryPointer( hbarwin, &mx, &my );
+      tmx = mx;
       tmx -= hbar_height;
       tmx -= scrollDelta;
       f1 = tmx / b;
       setXOffset( (int)f1 );
-      _aguix->Flush();
+      //_aguix->Flush();
     }
   } else if ( msg->type == ButtonRelease ) {
     if ( ( msg->window == hbarwin ) &&
@@ -1871,17 +1915,19 @@ void FieldListView::handleHBar( Message *msg )
     if ( ( msg->specialType == Message::TIMEREVENT ) &&
 	 ( hbarMode != HBAR_IDLE ) ) {
       if ( ( msg->time % 2 ) == 0 ) { //HARDCODED
-	switch ( hbarMode ) {
-	  case HBAR_SCROLL_LEFT:
-	    setXOffset( xoffset - getHScrollStep() );
-	    break;
-	  case HBAR_SCROLL_RIGHT:
-	    setXOffset( xoffset + getHScrollStep() );
-	    break;
-	default:
-	  break;
-	}
-	_aguix->Flush();
+        if ( getCurrentMouseButtonState( win ) & Button1Mask ) {
+          switch ( hbarMode ) {
+            case HBAR_SCROLL_LEFT:
+              setXOffset( xoffset - getHScrollStep() );
+              break;
+            case HBAR_SCROLL_RIGHT:
+              setXOffset( xoffset + getHScrollStep() );
+              break;
+            default:
+              break;
+          }
+          _aguix->Flush();
+        }
       }
     }
   }
@@ -2001,12 +2047,14 @@ void FieldListView::handleVBar(Message *msg)
 	 ( vbarMode == VBAR_SCROLL ) ) {
       int tmy;
       double f1;
-      tmy = msg->mousey;
+
+      _aguix->queryPointer( vbarwin, &mx, &my );
+      tmy = my;
       tmy -= vbar_width;
       tmy -= scrollDelta;
       f1 = tmy / b;
       setYOffset( (int)f1 );
-      _aguix->Flush();
+      //        _aguix->Flush();
     }
   } else if ( msg->type == ButtonRelease ) {
     if ( ( msg->window == vbarwin ) &&
@@ -2037,31 +2085,33 @@ void FieldListView::handleVBar(Message *msg)
     if ( ( msg->specialType == Message::TIMEREVENT ) &&
 	 ( vbarMode != VBAR_IDLE ) ) {
       if ( ( msg->time % 2 ) == 0 ) { //HARDCODED
-	switch ( vbarMode ) {
-	  case VBAR_SCROLL_UP:
-	    scrollV1( -1 );
-	    break;
-	  case VBAR_SCROLL_DOWN:
-	    scrollV1( 1 );
-	    break;
-	default:
-	  break;
-	}
-	_aguix->Flush();
+        if ( getCurrentMouseButtonState( win ) & Button1Mask ) {
+          switch ( vbarMode ) {
+            case VBAR_SCROLL_UP:
+              scrollV1( -1 );
+              break;
+            case VBAR_SCROLL_DOWN:
+              scrollV1( 1 );
+              break;
+            default:
+              break;
+          }
+          _aguix->Flush();
+        }
       }
     }
   }
   return;
 }
 
-void FieldListView::scrollV(int delta)
+void FieldListView::scrollV( int delta, bool no_redraw )
 {
-  setYOffset(yoffset+delta);
+  setYOffset( yoffset + delta, no_redraw );
 }
 
-void FieldListView::scrollV1(int dir)
+void FieldListView::scrollV1( int dir, bool no_redraw )
 {
-  setYOffset(yoffset+dir);
+  setYOffset( yoffset + dir, no_redraw );
 }
 
 void FieldListView::setSelectHandler( void (*nsh)( FieldListView*, int p ) )
@@ -2335,7 +2385,30 @@ void FieldListView::handleMiddle(Message *msg)
 	  agmsg->fieldlv.time = msg->time;
 	  agmsg->fieldlv.mouse = true;
 	  agmsg->type = AG_FIELDLV_ONESELECT;
-	  _aguix->putAGMsg( agmsg );
+          msgAndCB( std::auto_ptr<AGMessage>( agmsg ) );
+
+          {
+            int dc_row = _last_single_middle_row;
+            Time dc_time = _last_single_middle_time;
+
+            _last_single_middle_row = clickFirstSelectedRow;
+            _last_single_middle_time = msg->time;
+
+            if ( isValidRow( dc_row ) == true && clickFirstSelectedRow == dc_row ) {
+              if ( _aguix->isDoubleClick( msg->time, dc_time ) == true ) {
+                agmsg = AGUIX_allocAGMessage();
+                agmsg->fieldlv.lv = this;
+                agmsg->fieldlv.row = clickFirstSelectedRow;
+                agmsg->fieldlv.time = msg->time;
+                agmsg->fieldlv.mouse = true;
+                agmsg->type = AG_FIELDLV_DOUBLECLICK;
+                msgAndCB( std::auto_ptr<AGMessage>( agmsg ) );
+                _last_single_middle_row = -1;
+                _last_single_middle_time = 0;
+              }
+            }
+          }
+ 
 	  _aguix->msgUnlock( this );
 	  middleMode = MIDDLE_IDLE;
 	  break;
@@ -2346,24 +2419,26 @@ void FieldListView::handleMiddle(Message *msg)
   } else if ( msg->type == ClientMessage ) {
     if ( msg->specialType == Message::TIMEREVENT ) {
       if ( ( msg->time % 1 ) == 0 ) { //HARDCODED
-	if ( middleMode == MIDDLE_SCROLL_UP ) {
-	  newelement = clickLastSelectedRow - 1;
-	  if ( newelement >= 0 ) {
-	    scrollV1( -1 );
-	    setActiveRow( newelement );
-	    runSelectHandler( newelement );
-	    clickLastSelectedRow = newelement;
-	  }
-	} else if ( middleMode == MIDDLE_SCROLL_DOWN ) {
-	  newelement = clickLastSelectedRow + 1;
-	  if ( newelement < elements ) {
-	    scrollV1( 1 );
-	    setActiveRow( newelement );
-	    runSelectHandler( newelement );
-	    clickLastSelectedRow = newelement;
-	  }
-	}
-	_aguix->Flush();
+        if ( getCurrentMouseButtonState( win ) & _activate_buttonmask ) {
+          if ( middleMode == MIDDLE_SCROLL_UP ) {
+            newelement = clickLastSelectedRow - 1;
+            if ( newelement >= 0 ) {
+              scrollV1( -1 );
+              setActiveRow( newelement );
+              runSelectHandler( newelement );
+              clickLastSelectedRow = newelement;
+            }
+          } else if ( middleMode == MIDDLE_SCROLL_DOWN ) {
+            newelement = clickLastSelectedRow + 1;
+            if ( newelement < elements ) {
+              scrollV1( 1 );
+              setActiveRow( newelement );
+              runSelectHandler( newelement );
+              clickLastSelectedRow = newelement;
+            }
+          }
+          _aguix->Flush();
+        }
       }
     }
   }
@@ -2444,6 +2519,8 @@ bool FieldListView::handleKeys(Message *msg)
 	  runSelectHandler( pos );
 	  _aguix->Flush();
           sendmsg = true;
+
+          returnvalue = true;
 	}
       } else if ( msg->key == XK_space ) {
 	if ( activerow >= 0 ) {
@@ -2453,6 +2530,8 @@ bool FieldListView::handleKeys(Message *msg)
 	  runSelectHandler( activerow );
 	  _aguix->Flush();
           sendmsg = true;
+
+          returnvalue = true;
 	}
       } else if ( msg->key == XK_Return ) {
       }
@@ -2467,7 +2546,7 @@ bool FieldListView::handleKeys(Message *msg)
     agmsg->fieldlv.time = time( NULL );
     agmsg->fieldlv.mouse = false;
     agmsg->type = AG_FIELDLV_ONESELECT;
-    _aguix->putAGMsg( agmsg );
+    msgAndCB( std::auto_ptr<AGMessage>( agmsg ) );
   }
   return returnvalue;
 }
@@ -2884,6 +2963,7 @@ void FieldListView::redrawHeader()
 			getInnerWidth(),
 			hh - 1 );
   
+  DrawableCont dc( _aguix, use_pixmap );
   sx = ex = 0;
   for ( f = 0; f < fields; f++ ) {
     // merge all fields with fieldtextmerged == true
@@ -2951,11 +3031,7 @@ void FieldListView::redrawHeader()
 	  // so always use left alignment for better reading
 	  usedAlign = ALIGN_LEFT;
 	}
-	if ( font == NULL )
-	  _aguix->setFG( headerCols[0] );
-	else
-	  _aguix->setFG( font->getGC(), headerCols[0] );
-
+	
 	clip_rect.x = a_max( sx + header_border - xoffset, 0 ) + use_ox;
 	clip_rect.y = 0;
 
@@ -2966,7 +3042,7 @@ void FieldListView::redrawHeader()
 	clip_rect.width = tx;
 
 	clip_rect.height = _h;
-	_aguix->SetClipRectangles( font, 0, 0, &clip_rect, 1, Unsorted );
+	_aguix->setClip( font, &dc, clip_rect.x, clip_rect.y, clip_rect.width, clip_rect.height );
 
 	if ( usedAlign == ALIGN_RIGHT ) {
 	  text_x = use_ox + ex - header_border - xoffset + 1 - tw - 1;
@@ -2975,11 +3051,9 @@ void FieldListView::redrawHeader()
 	  text_x = use_ox + sx + header_border - xoffset + 1;
 	  text_y = use_oy - hh + header_border;
 	}
-	if ( font == NULL )
-	  _aguix->DrawText( use_pixmap, s.c_str(), text_x, text_y );
-	else
-	  _aguix->DrawText( use_pixmap, font, s.c_str(), text_x, text_y );
-	_aguix->UnsetClipMask( font );
+
+	_aguix->DrawText( dc, font, s.c_str(), text_x, text_y, headerCols[0] );
+	_aguix->unclip( font, &dc );
       }
     }
     
@@ -3182,11 +3256,18 @@ void FieldListView::handleHeader( Message *msg )
   } else if ( msg->type == MotionNotify && headerMode == HEADER_DRAG ) {
     // motion event in drag mode
     // calculate new width
+
+    int my;
+    _aguix->queryPointer( win, &mx, &my );
+    mx = mx - ox + xoffset;
+    
     int nw = drag_base_w + ( mx - drag_base_x );
     if ( nw < 0 ) nw = 0;
 
     resizeable_f = findResizeableField( drag_field );
-    setFieldWidth( resizeable_f, nw );
+    if ( getFieldWidth( resizeable_f ) != nw ) {
+      setFieldWidth( resizeable_f, nw );
+    }
 
     // reset drag time to prevent double click
     last_drag_time = 0;
@@ -3233,7 +3314,7 @@ void FieldListView::handleHeader( Message *msg )
 	  agmsg->fieldlv.mouse = true;
 	  agmsg->fieldlv.button = msg->button;
 	  agmsg->type = AG_FIELDLV_HEADERCLICKED;
-	  _aguix->putAGMsg( agmsg );
+          msgAndCB( std::auto_ptr<AGMessage>( agmsg ) );
 	}
       }
     }
@@ -3508,3 +3589,14 @@ int FieldListView::singleSelectRow( int row, bool state )
 
   return selected;
 }
+
+unsigned int FieldListView::getCurrentMouseButtonState( Window twin )
+{
+  if ( twin != win && twin != vbarwin && twin != hbarwin ) return 0;
+
+  unsigned int buttons;
+  int mx, my;
+  
+  _aguix->queryPointer( twin, &mx, &my, &buttons );
+  return buttons;
+}
