@@ -1,6 +1,6 @@
 /* fieldlistview.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2002-2005 Ralf Hoffmann.
+ * Copyright (C) 2002-2006 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -56,9 +56,9 @@ public:
   int insertRow( int row );
   void swapRows( int row1, int row2 );
 
-  void setXOffset( int nv );
+  void setXOffset( int nv, bool no_redraw = false );
   int getMaxTextWidth();
-  void setYOffset( int nv );
+  void setYOffset( int nv, bool no_redraw = false );
 
   typedef enum { ALIGN_LEFT, ALIGN_RIGHT } align_t;
 
@@ -109,8 +109,8 @@ public:
   int getVBarWidth() const;
   void setHBarHeight( int new_height );
   int getHBarHeight() const;
-  void scrollV( int delta );
-  void scrollV1( int dir );
+  void scrollV( int delta, bool no_redraw = false );
+  void scrollV1( int dir, bool no_redraw = false );
   void setSelectHandler( void (*nsh)( FieldListView*, int element ) );
   void showActive();
   void centerActive();
@@ -296,6 +296,11 @@ protected:
   typedef enum { MIDDLE_IDLE, MIDDLE_HOLD, MIDDLE_SCROLL_UP, MIDDLE_SCROLL_DOWN, MIDDLE_IGNORE } middleMode_t;
   middleMode_t middleMode;
 
+  int _last_single_select_row;
+  Time _last_single_select_time;
+  int _last_single_middle_row;
+  Time _last_single_middle_time;
+
   typedef enum { HEADER_IDLE, HEADER_CLICK, HEADER_DRAG } headerMode_t;
   headerMode_t headerMode;
 
@@ -324,6 +329,8 @@ protected:
   static unsigned int _activate_button, _activate_buttonmask;
   static unsigned int _scroll_button, _scroll_buttonmask;
   static mouse_select_t _select_mode;
+
+  unsigned int getCurrentMouseButtonState( Window twin );
 };
 
 #endif
