@@ -1,6 +1,6 @@
 /* fieldlistviewdnd.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2002-2005 Ralf Hoffmann.
+ * Copyright (C) 2002-2006 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: fieldlistviewdnd.cc,v 1.21 2005/12/05 18:51:02 ralf Exp $ */
 
 #include "fieldlistviewdnd.h"
 #include "awindow.h"
@@ -112,7 +111,7 @@ void FieldListViewDND::handleSelect(Message *msg)
 	  agmsg->dnd.relx = win_x;
 	  agmsg->dnd.rely = win_y;
 	  agmsg->type = AG_DND_START;
-	  _aguix->putAGMsg( agmsg );
+          msgAndCB( std::auto_ptr<AGMessage>( agmsg ) );
 
 	  dndtext = new DNDText( _aguix,
 				 tstr,
@@ -156,7 +155,7 @@ void FieldListViewDND::handleDND( Message *msg )
       Display *dsp=_aguix->getDisplay();
       root=RootWindow(dsp,_aguix->getScreen());
       for(;;) {
-      XQueryPointer(dsp,root,&rroot,&child,&xr,&yr,&xw,&yw,&keys_button);
+        XQueryPointer(dsp,root,&rroot,&child,&xr,&yr,&xw,&yw,&keys_button);
 	if(child==0) break;
 	root=child;
       }
@@ -178,7 +177,7 @@ void FieldListViewDND::handleDND( Message *msg )
       agmsg->dnd.rely=yw;
       if ( dndMode == DND_ACTIVE ) agmsg->type=AG_DND_END;
       else agmsg->type=AG_DND_CANCEL;
-      _aguix->putAGMsg(agmsg);
+      msgAndCB( std::auto_ptr<AGMessage>( agmsg ) );
 
       switch ( selectMode ) {
 	case SELECT_SCROLL_UP:
@@ -197,7 +196,7 @@ void FieldListViewDND::handleDND( Message *msg )
 	  } else {
 	    agmsg->type = AG_FIELDLV_MULTISELECT;
 	  }
-	  _aguix->putAGMsg( agmsg );
+          msgAndCB( std::auto_ptr<AGMessage>( agmsg ) );
 	  break;
 	default:
 	  break;
