@@ -24,6 +24,7 @@
 #include "awindow.h"
 #include "guielement.h"
 #include "kartei.h"
+#include "drawablecont.hh"
 
 const char *KarteiButton::type="KarteiButton";
 
@@ -103,6 +104,8 @@ void KarteiButton::redraw()
     ch = font->getCharHeight();
   }
 
+  DrawableCont dc( _aguix, win );
+
   // make two runs
   // first to draw the bg for inactive options in dark grey
   // second to draw lines and text
@@ -196,11 +199,7 @@ void KarteiButton::redraw()
       }
       
       if ( run != 0 ) {
-	if ( font == NULL ) {
-	  _aguix->DrawText( win, tstr, sx + dx + delx, 2 );
-	} else {
-	  _aguix->DrawText( win, font, tstr, sx + dx + delx, 1 );
-	}
+	_aguix->DrawText( dc, font, tstr, sx + dx + delx, 1, 1 );
       }
 
       _freesafe( tstr );
@@ -273,7 +272,7 @@ bool KarteiButton::handleMessage(XEvent *E,Message *msg)
 	  agmsg->type=AG_KARTEIBUTTONCLICKED;
 	  agmsg->karteibutton.karteibutton=this;
 	  agmsg->karteibutton.option=act_opt;
-	  _aguix->putAGMsg(agmsg);
+          msgAndCB( std::auto_ptr<AGMessage>( agmsg ) );
 
 	  if ( ( optionChangeCallback != NULL ) && ( act_opt >= 0 ) ) {
 	    optionChangeCallback( k2, (unsigned int)act_opt );
@@ -323,7 +322,7 @@ bool KarteiButton::handleMessage(XEvent *E,Message *msg)
 		agmsg->type=AG_KARTEIBUTTONCLICKED;
 		agmsg->karteibutton.karteibutton=this;
 		agmsg->karteibutton.option=act_opt;
-		_aguix->putAGMsg(agmsg);
+                msgAndCB( std::auto_ptr<AGMessage>( agmsg ) );
 
                 if ( ( optionChangeCallback != NULL ) && ( act_opt >= 0 ) ) {
                   optionChangeCallback( k2, (unsigned int)act_opt );
