@@ -66,7 +66,7 @@ enum {AG_NONE,AG_KEYPRESSED,AG_KEYRELEASED,AG_MOUSEPRESSED,AG_MOUSERELEASED,AG_M
       AG_SIZECHANGED,
       AG_DND_START,AG_DND_END,AG_DND_CANCEL,
       AG_CYCLEBUTTONCLICKED,
-      AG_FIELDLV_ONESELECT,AG_FIELDLV_MULTISELECT,AG_FIELDLV_PRESSED,AG_FIELDLV_HEADERCLICKED,
+      AG_FIELDLV_ONESELECT,AG_FIELDLV_MULTISELECT,AG_FIELDLV_PRESSED,AG_FIELDLV_HEADERCLICKED,AG_FIELDLV_DOUBLECLICK,
       AG_KARTEIBUTTONCLICKED,
       AG_SLIDER_PRESSED, AG_SLIDER_CHANGED };
 
@@ -233,6 +233,7 @@ typedef union agmessage {
 Message *AGUIX_allocMessage();
 void AGUIX_freeMessage( Message *);
 AGMessage *AGUIX_allocAGMessage();
+AGMessage *AGUIX_allocAGMessage( Message * );
 void AGUIX_freeAGMessage( AGMessage *);
 
 #endif
