@@ -1,6 +1,6 @@
 /* slider.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2005 Ralf Hoffmann.
+ * Copyright (C) 2005-2006 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -49,7 +49,6 @@ Slider::Slider( AGUIX *caguix, int cx, int cy, int cwidth, int cheight, bool cve
     _h = 6;
   bar_dir = 0;
   bar_pressed = false;
-  callbackhandler=NULL;
 
   displayFocus = false;
   setCanHandleFocus();
@@ -58,9 +57,7 @@ Slider::Slider( AGUIX *caguix, int cx, int cy, int cwidth, int cheight, bool cve
   barMode = BAR_IDLE;
   grabs = 0;
   scrollDelta = 0;
-  sendMsg = true;
   
-  cb = NULL;
   _init_timer_wait = 0;
   _allow_timerevent_break = true;
 }
@@ -126,14 +123,14 @@ bool Slider::handleMessage( XEvent *E, Message *msg )
 	handleBar( msg );
 	isc = true;
       }
-      if ( ( isc == true ) && ( sendMsg == true ) ) {
+      if ( isc == true ) {
 	AGMessage *agmsg = AGUIX_allocAGMessage();
 	agmsg->slider.slider = this;
 	agmsg->slider.offset = offset;
 	agmsg->slider.time = msg->time;
 	agmsg->slider.mouse = true;
 	agmsg->type = AG_SLIDER_PRESSED;
-	_aguix->putAGMsg( agmsg );
+        msgAndCB( std::auto_ptr<AGMessage>( agmsg ) );
       }
     } else if ( msg->type == KeyPress ) {
       if ( ( getAcceptFocus() == true ) && ( getHasFocus() == true ) ) {
@@ -543,17 +540,6 @@ void Slider::handleBar( Message *msg )
   return;
 }
 
-void Slider::setCallbackHandler( void (*ncbh)( Slider*, int new_offset ) )
-{
-  callbackhandler = ncbh;
-}
-
-void Slider::setCallbackHandler( CallBack *new_cb )
-{
-  cb = new_cb;
-  setSendMessage( false );
-}
-
 const char *Slider::getType() const
 {
   return type;
@@ -573,15 +559,6 @@ bool Slider::isParent(Window child) const
   return false;
 }
 
-void Slider::runCallbackHandler( int new_offset )
-{
-  if ( cb != NULL ) {
-    cb->run( this, new_offset );
-  } else  if ( callbackhandler != NULL ) {
-    ( callbackhandler )( this, new_offset );
-  }
-}
-
 bool Slider::handleKeys(Message *msg)
 {
   bool returnvalue=false;
@@ -654,32 +631,20 @@ void Slider::checkValues()
 void Slider::msgAndCallback()
 {
   if ( offset != old_offset ) {
-    if ( sendMsg == true ) {
-      AGMessage *agmsg = AGUIX_allocAGMessage();
-      agmsg->slider.slider = this;
-      agmsg->slider.offset = offset;
-      agmsg->slider.time = time( NULL );
-      agmsg->slider.mouse = false;
-      agmsg->type = AG_SLIDER_CHANGED;
-      _aguix->putAGMsg( agmsg );
-    }
+    AGMessage *agmsg = AGUIX_allocAGMessage();
+    agmsg->slider.slider = this;
+    agmsg->slider.offset = offset;
+    agmsg->slider.time = time( NULL );
+    agmsg->slider.mouse = false;
+    agmsg->type = AG_SLIDER_CHANGED;
+    msgAndCB( std::auto_ptr<AGMessage>( agmsg ) );
     
-    runCallbackHandler( offset );
+    callback( offset );
     
     old_offset = offset;
   }
 }
 
-void Slider::setSendMessage( bool nv )
-{
-  sendMsg = nv;
-}
-
-bool Slider::getSendMessage() const
-{
-  return sendMsg;
-}
-
 void Slider::enableTimer()
 {
   _aguix->enableTimer();
