@@ -1,6 +1,6 @@
 /* stringgadget.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2005 Ralf Hoffmann.
+ * Copyright (C) 2001-2006 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -25,6 +25,8 @@
 
 #include "aguixdefs.h"
 #include "guielement.h"
+#include <string>
+#include <vector>
 
 class StringGadget:public GUIElement {
 public:
@@ -62,17 +64,51 @@ public:
   void insertAtCursor( const char *str );
   void selectAll();
   void setPasswordMode( bool nv );
+  void changeHeightForCurFont();
 protected:
   virtual void doCreateStuff();
   virtual void doDestroyStuff();
 private:
+  class SGContent
+  {
+  public:
+    SGContent();
+
+    void setXOffset( int np );
+    void setSelStart( int np );
+    void setSelEnd( int np );
+    void setCursorPos( int np );
+    void setPasswordMode( bool mode );
+    const char *getText() const;
+    int getXOffset() const;
+    int getSelStart() const;
+    int getSelEnd() const;
+    int getCursorPos() const;
+
+    void insertAtCursor( const char *text );
+    void setText( const char *text );
+
+    const char *getRealText() const;
+
+    void removeRange( int start, int end );
+  private:
+    std::string real_text, pw_text;
+    int xoffset, selstart, selend, cursorpos;
+    bool password_mode;
+    std::vector<int> real_char2byte_lookup;
+    std::vector<int> pw_char2byte_lookup;
+
+    int pw2realPos( int pos );
+    int real2pwPos( int pos );
+    void fixPositions();
+    void fixPosition( int &pos );
+  };
+
+  SGContent content;
+
   int data;
-  char *text;
-  int cursorpos;
-  int xoffset;
   bool active;
   static const char *type;
-  int selstart,selend;
   class AGUIXFont *font;
   bool forbidPosChange;
   bool ignoreRelease;
