@@ -1,6 +1,6 @@
 /* textstorage.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2005 Ralf Hoffmann.
+ * Copyright (C) 2005-2006 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,9 +18,9 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: textstorage.cc,v 1.3 2005/08/16 21:01:40 ralf Exp $ */
 
 #include "textstorage.h"
+#include "utf8.hh"
 
 TextStorageString::TextStorageString( const char *buf, int len, AWidth &lencalc ) : _lencalc( lencalc )
 {
@@ -51,6 +51,13 @@ int TextStorageString::getLine( int line_nr, unsigned int offset, int len, std::
 
   if ( offset < line_len ) {
     // offset given still inside line
+
+    if ( UTF8::isValidCharacter( buffer.c_str() + start_offset + offset ) == false ) {
+      int n = (int)offset;
+      UTF8::movePosToPrevChar( buffer.c_str() + start_offset, n );
+      offset = (unsigned int )n;
+    }
+
     start_offset += offset;
     line_len -= offset;
     
@@ -72,18 +79,24 @@ int TextStorageString::getLine( int line_nr, unsigned int offset, std::string &r
 void TextStorageString::initBuffer( std::string &content, int line_limit_width )
 {
   unsigned int i;
+  int current_line = 0, current_subline = 0;
 
   buffer = content;
   line_offsets.clear();
   line_offsets.push_back( 0 );
+  _real_lines.clear();
+  _real_lines.push_back( std::pair<int,int>( current_line, current_subline ) );
 
   if ( line_limit_width < 1 ) {
     // the easiest stuff: no line limit
     for ( i = 0; i < buffer.length(); i++ ) {
       if ( buffer[i] == '\n' ) {
+        current_line++;
+
 	line_offsets.push_back( i + 1 );  // if newline is last character
                                           // this line offset will be outside
                                           // the buffer
+        _real_lines.push_back( std::pair<int,int>( current_line, current_subline ) );
       }
     }
   } else {
@@ -97,12 +110,20 @@ void TextStorageString::initBuffer( std::string &content, int line_limit_width )
       if ( buffer[i] == '\n' ) {
 	newline = true;
 	i++;
+
+        current_line++;
+        current_subline = 0;
       } else {
 	token_characters = getTokenLen( i );
 	if ( ( i + token_characters ) > buffer.length() ) {
 	  token_characters = buffer.length() - i;
 	}
-	if ( token_characters < 1 ) token_characters = 1;
+        
+	if ( token_characters < 1 )
+          token_characters = UTF8::getLenOfCharacter( buffer.c_str() + i );
+        if ( token_characters < 1 )
+          token_characters = 1;
+        
 	token_width = _lencalc.getWidth( buffer.c_str() + i, token_characters );
 
 	if ( ( cur_line_width + token_width ) <= (unsigned int)line_limit_width ) {
@@ -116,20 +137,28 @@ void TextStorageString::initBuffer( std::string &content, int line_limit_width )
 	  if ( token_characters < 1 ) {
 	    // no room for at least one character at line start so we need to take
 	    // this first one even this will break the line limit
-	    token_characters = 1;
+            token_characters = UTF8::getLenOfCharacter( buffer.c_str() + i );
+            if ( token_characters < 1 )
+              token_characters = 1;
 	  }
 	  i += token_characters;
 	  newline = true;
+
+          current_subline++;
 	} else {
 	  newline = true;
 	  // i is not advanced but for the newline cur_line_len will be 0
 	  // in the next round so the previous case will catch on if it
 	  // doesn't fit
+          
+          current_subline++;
 	}
       }
       if ( newline == true ) {
 	line_offsets.push_back( i );
 	cur_line_width = 0;
+
+        _real_lines.push_back( std::pair<int,int>( current_line, current_subline ) );
       }
     }
   }
@@ -140,6 +169,7 @@ TextStorageString &TextStorageString::operator=( const TextStorageString &other
   if ( this != &other ) {
     buffer = other.buffer;
     line_offsets = other.line_offsets;
+    _real_lines = other._real_lines;
   }
   return *this;
 }
@@ -183,12 +213,18 @@ int TextStorageString::getLineWidth( int line_nr ) const
 unsigned int TextStorageString::getTokenLen( unsigned int start_offset )
 {
   unsigned int token_len;
+  size_t l;
 
   if ( start_offset >= buffer.length() ) return 0;
   
-  for ( token_len = 0; start_offset < buffer.length(); start_offset++, token_len++ ) {
+  for ( token_len = 0; start_offset < buffer.length(); ) {
     if ( buffer[start_offset] == ' ' ) break;
     if ( buffer[start_offset] == '\n' ) break;
+    
+    l = UTF8::getLenOfCharacter( buffer.c_str() + start_offset );
+    start_offset += l;
+    token_len += l;
+    if ( l < 1 ) break;
   }
   
   return token_len;
@@ -223,3 +259,28 @@ int TextStorageString::getLineCharacters( int line_nr ) const
     return buffer.length() - start_offset;
   }
 }
+
+std::pair<int,int> TextStorageString::getRealLinePair( int line_nr ) const
+{
+  if ( line_nr < 0 || line_nr >= (int)_real_lines.size() ) return std::pair<int,int>( -1, -1);
+  return _real_lines[line_nr];
+}
+
+AWidth &TextStorageString::getAWidth()
+{
+  return _lencalc;
+}
+
+int TextStorageString::findLineNr( std::pair<int,int> real_line ) const
+{
+  int s = (int)_real_lines.size();
+  if ( real_line.first < 0 || real_line.first >= s ) return 0;
+
+  int l = real_line.first;
+  for ( ; l < s; l++ ) {
+    if ( _real_lines[l] == real_line )
+      break;
+  }
+  if ( l >= s ) return 0;
+  return l;
+}
