@@ -26,6 +26,7 @@
 #include "aguixdefs.h"
 #include <vector>
 #include <string>
+#include <utility>
 #include "awidth.h"
 
 class TextStorage
@@ -38,6 +39,9 @@ class TextStorage
   virtual int getMaxLineWidth() const = 0;
   virtual int getLineWidth( int line_nr ) const = 0;
   virtual void setLineLimit( int new_limit ) = 0;
+  virtual std::pair<int,int> getRealLinePair( int line_nr ) const = 0;
+  virtual int findLineNr( std::pair<int,int> real_line ) const = 0;
+  virtual AWidth &getAWidth() = 0;
 };
 
 class TextStorageString : public TextStorage
@@ -54,6 +58,9 @@ class TextStorageString : public TextStorage
   int getMaxLineWidth() const;
   int getLineWidth( int line_nr ) const;
   void setLineLimit( int new_limit );
+  std::pair<int,int> getRealLinePair( int line_nr ) const;
+  int findLineNr( std::pair<int,int> real_line ) const;
+  AWidth &getAWidth();
  private:
   void initBuffer( std::string &content, int line_limit_width = -1 );
   unsigned int getTokenLen( unsigned int start_offset );
@@ -61,6 +68,7 @@ class TextStorageString : public TextStorage
   std::string buffer;                      // stores text file
   std::vector<unsigned int> line_offsets;  // stores offset for each line (can be outside of buffer
                                            // for last line)
+  std::vector<std::pair<int,int> > _real_lines;
   int getLineCharacters( int line_nr ) const;
   AWidth &_lencalc;
 };
