@@ -1,6 +1,6 @@
 /* textview.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2005 Ralf Hoffmann.
+ * Copyright (C) 2005-2006 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,10 +18,10 @@
  * along with this program; if not^, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: textview.cc,v 1.6 2005/12/05 06:39:51 ralf Exp $ */
 
 #include "textview.h"
 #include "acontainer.h"
+#include "drawablecont.hh"
 
 TVCallBack::TVCallBack( TextView *_tv )
 {
@@ -32,15 +32,11 @@ TVCallBack::~TVCallBack()
 {
 }
 
-void TVCallBack::run( GUIElement *elem, int value )
+void TVCallBack::run_int( Widget *elem, int value )
 {
   if ( tv != NULL ) tv->gui_callback( elem, value );
 }
 
-void TVCallBack::run( GUIElement *elem, void *p )
-{
-}
-
 TextView::TextView( AGUIX *parent,
 		    int x,
 		    int y,
@@ -48,7 +44,10 @@ TextView::TextView( AGUIX *parent,
 		    int height,
 		    int bg,
 		    std::string title,
-		    TextStorage &_ts ) : AWindow( parent, x, y, width, height, bg, title ), ts( _ts ), tvcb( this )
+		    TextStorage &_ts ) : AWindow( parent, x, y, width, height, bg, title ),
+                                         ts( _ts ),
+                                         tvcb( this ),
+                                         _show_line_numbers( false )
 {
   hbar = vbar = NULL;
   cont = NULL;
@@ -74,10 +73,10 @@ void TextView::doCreateStuff()
   if ( _created == false ) return;
 
   hbar = new Slider( _aguix, 0, 0, 30, 12, false, 0 );
-  hbar->setCallbackHandler( &tvcb );
+  hbar->connect( &tvcb );
   hbar->setAcceptFocus( false );
   vbar = new Slider( _aguix, 0, 0, 12, 30, true, 1 );
-  vbar->setCallbackHandler( &tvcb );
+  vbar->connect( &tvcb );
   vbar->setAcceptFocus( false );
   
   createContainer();
@@ -220,8 +219,29 @@ bool TextView::handleMessage(XEvent *E,Message *msg)
 	      }
 	      break;
 	    case XK_w:
-	      setLineWrap( ( getLineWrap() == true ) ? false : true );
+              if ( KEYSTATEMASK( msg->keystate ) == 0 ) {
+                setLineWrap( ( getLineWrap() == true ) ? false : true );
+              }
 	      break;
+	    case XK_l:
+              if ( KEYSTATEMASK( msg->keystate ) == 0 ) {
+                setShowLineNumbers( ( getShowLineNumbers() == true ) ? false : true );
+              }
+	      break;
+              
+              // another pair of handy shortcuts
+	    case XK_BackSpace:
+	      if ( vbar != NULL ) {
+		vbar->setOffset( vbar->getOffset() - vbar->getMaxDisplay() + 1 );
+		redraw();
+	      }
+              break;
+	    case XK_space:
+	      if ( vbar != NULL ) {
+		vbar->setOffset( vbar->getOffset() + vbar->getMaxDisplay() - 1 );
+		redraw();
+	      }
+              break;
 	    default:
 	      break;
 	  }
@@ -273,7 +293,7 @@ void TextView::doDestroyStuff()
   hbar = vbar = NULL;
 }
 
-void TextView::gui_callback( GUIElement *elem, int value )
+void TextView::gui_callback( Widget *elem, int value )
 {
   if ( ( elem == vbar ) || ( elem == hbar ) ) {
     redraw();
@@ -282,10 +302,9 @@ void TextView::gui_callback( GUIElement *elem, int value )
 
 void TextView::redraw()
 {
-  int tx, ty, elementHeight, lines, width;
-  GC usegc;
-  XRectangle clip_rect;
+  int tx, ty, elementHeight, lines, width, basetx;
   int bw;
+  std::pair<int,int> real_line( -1, -1 );
 
   if ( isCreated() == false ) return;
 
@@ -295,15 +314,16 @@ void TextView::redraw()
 
   tx = ty = bw;
 
-  if ( font == NULL ) usegc = 0;
-  else usegc = font->getGC();
-
   if ( font == NULL ) elementHeight = _aguix->getCharHeight();
   else elementHeight = font->getCharHeight();
 
+  basetx = tx;
+  tx += getTextStartOffset();
   getLinesWidth( lines, width );
 
   if ( ( _w != last_w ) || ( _h != last_h ) || ( width != last_cont_width ) ) {
+    real_line = ts.getRealLinePair( vbar->getOffset() );
+
     if ( line_wrap == true ) {
       ts.setLineLimit( width );
     } else {
@@ -315,28 +335,54 @@ void TextView::redraw()
     last_cont_width = width;
   }
 
-  if ( font == NULL )
-    _aguix->setFG( 1 );
-  else
-    _aguix->setFG( font->getGC(), 1 );
+  if ( real_line.first >= 0 ) {
+    int linenr = ts.findLineNr( real_line );
 
-  clip_rect.x = tx;
-  clip_rect.y = 0;
-  clip_rect.width = width;
-  clip_rect.height = getHeight();
+    if ( linenr == 0 && ( real_line.first != 0 || real_line.second != 0 ) ) {
+      // wasn't able to found line, probably the subline doesn't exists anymore because of
+      // rewrapping so try subline 0
+      real_line.second = 0;
+      linenr = ts.findLineNr( real_line );
+    }
+    vbar->setOffset( linenr );
+  }
   
-  _aguix->SetClipRectangles( font, 0, 0, &clip_rect, 1, Unsorted );
+  DrawableCont dc( _aguix, win );
+  _aguix->setClip( font, &dc, tx, 0, width, getHeight() );
 
   for ( int i = 0; i < lines; i++ ) {
     std::string s1;
     // width is a good upper limit for the line length
-    ts.getLine( vbar->getOffset() + i, 0, width, s1 );
-    if ( font == NULL )
-      _aguix->DrawText( win, s1.c_str(), tx - hbar->getOffset(), i * elementHeight + ty );
-    else
-      _aguix->DrawText( win, font, s1.c_str(), tx - hbar->getOffset(), i * elementHeight + ty );
+    // if I start at the first visible character
+    // but since I currently always ask for the line
+    // starting at offset 0, width is not enough
+    // possible values are -1 or width+hbar->getOffset()
+    // (was width)
+    ts.getLine( vbar->getOffset() + i, 0, -1, s1 );
+
+    _aguix->DrawText( dc, font, s1.c_str(), tx - hbar->getOffset(), i * elementHeight + ty, 1 );
+  }
+  _aguix->unclip( font, &dc );
+
+  // now draw the line numbers
+  if ( _show_line_numbers == true ) {
+    char buf[A_BYTESFORNUMBER(int)];
+    int w;
+
+    _aguix->setClip( font, &dc, basetx, 0, tx, getHeight() );
+    
+    for ( int i = 0; i < lines; i++ ) {
+      real_line = ts.getRealLinePair( vbar->getOffset() + i );
+      if ( real_line.second == 0 ) {
+        sprintf( buf, "%d", real_line.first + 1 );
+
+        w = ts.getAWidth().getWidth( buf );
+
+        _aguix->DrawText( dc, font, buf, tx - w - 5, i * elementHeight + ty, 1 );
+      }
+    }
+    _aguix->unclip( font, &dc );
   }
-  _aguix->UnsetClipMask( font );
 }
 
 int TextView::setFont( char *fontname )
@@ -391,6 +437,10 @@ void TextView::getLinesWidth( int &lines, int &width ) const
   else elementHeight = font->getCharHeight();
 
   lines = th / elementHeight;
+
+  tw -= getTextStartOffset();
+  if ( tw < 0 ) tw = 0;
+  
   width = tw;
 }
 
@@ -415,7 +465,8 @@ void TextView::maximizeX()
   bw = ( _display_focus == true ) ? 2 : 1;
 
   l = ts.getMaxLineWidth() + 5;
-  l += 2 * bw + 2 + ( vbar != NULL ) ? vbar->getWidth() : 0;
+  l += 2 * bw + 2 + ( ( vbar != NULL ) ? vbar->getWidth() : 0 );
+  l += getTextStartOffset();
 
   if ( l >= _aguix->getRootWindowWidth() )
     l = _aguix->getRootWindowWidth();
@@ -436,7 +487,7 @@ void TextView::maximizeYLines( int max_lines )
   l = ts.getNrOfLines();
   if ( l > max_lines ) l = max_lines;
   l = ( l + 1 ) * elementHeight;
-  l += 2 * bw + 2 + ( ( hbar != NULL ) && ( line_wrap == false ) ) ? hbar->getHeight() : 0;
+  l += 2 * bw + 2 + ( ( ( hbar != NULL ) && ( line_wrap == false ) ) ? hbar->getHeight() : 0 );
 
   if ( l >= _aguix->getRootWindowHeight() )
     l = _aguix->getRootWindowHeight();
@@ -456,3 +507,43 @@ int TextView::getHScrollStep() const
   //TODO some better value
   return 8;
 }
+
+int TextView::getTextStartOffset() const
+{
+  int off = 0;
+
+  if ( _show_line_numbers == false )
+    return off;
+
+  int lines = ts.getNrOfLines();
+  int digits = 1;
+  if ( lines > 0 ) {
+    digits = (int)( log( (double)lines ) / log( 10.0 ) ) ;
+    digits++;
+  }
+  std::string maxnumber( digits, '9' );
+  off = ts.getAWidth().getWidth( maxnumber.c_str() );
+  off += 5;
+  return off;
+}
+
+void TextView::setShowLineNumbers( bool nv )
+{
+  _show_line_numbers = nv;
+  last_w = last_h = last_cont_width = -1; // force textstorage rebuild
+  createContainer();
+  redraw();
+}
+
+bool TextView::getShowLineNumbers() const
+{
+  return _show_line_numbers;
+}
+
+void TextView::jumpToLine( int line_nr )
+{
+  int l;
+  l = ts.findLineNr( std::pair<int,int>( line_nr, 0 ) );
+  vbar->setOffset( l );
+  redraw();
+}
