@@ -1,6 +1,6 @@
 /* textview.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2005 Ralf Hoffmann.
+ * Copyright (C) 2005-2006 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: textview.h,v 1.5 2005/10/16 20:13:04 ralf Exp $ */
 
 #ifndef TEXTVIEW_H
 #define TEXTVIEW_H
@@ -37,8 +36,7 @@ public:
   TVCallBack( const TVCallBack &other );
   TVCallBack &operator=( const TVCallBack &other );
   
-  void run( GUIElement *, int value = 0 );
-  void run( GUIElement *, void *p );
+  void run_int( Widget *, int value );
 private:
   class TextView *tv;
 };
@@ -57,7 +55,7 @@ public:
   TextView( const TextView &other );
   TextView &operator=( const TextView &other );
   bool handleMessage(XEvent *,Message *msg);
-  void gui_callback( GUIElement *, int value );
+  void gui_callback( Widget *, int value );
   void redraw();
   int setFont( char *fontname );
   void setLineWrap( bool nv );
@@ -66,12 +64,18 @@ public:
   bool getDisplayFocus() const;
   void maximizeX();
   void maximizeYLines( int max_lines );
+
+  void setShowLineNumbers( bool nv );
+  bool getShowLineNumbers() const;
+
+  void jumpToLine( int line_nr );
 protected:
   class AContainer *cont;
   Slider *hbar, *vbar;
   TextStorage &ts;
   class AGUIXFont *font;
   TVCallBack tvcb;
+  bool _show_line_numbers;
 
   int last_w, last_h, last_cont_width;
   bool line_wrap;
@@ -87,6 +91,8 @@ protected:
 
   void prepareBG( bool force = false );
   int getHScrollStep() const;
+
+  int getTextStartOffset() const;
 };
 
 #endif
