@@ -11,6 +11,9 @@ class Widget : public Focus
 public:
   Widget( AGUIX *aguix );
   virtual ~Widget();
+  Widget( const Widget &other );
+  Widget &operator=( const Widget &other );
+  
   virtual int create();
   virtual void destroy();
   bool isCreated() const;
