@@ -24,6 +24,7 @@
 #include "listermode.h"
 #include "normalmode.h"
 #include "worker.h"
+#include "wcfiletype.hh"
 
 /***********
   DNDAction
@@ -998,7 +999,7 @@ bool UserAction::save(Datei *fh)
 {
   if ( fh == NULL ) return false;
   
-  WConfig::configPutPairNum( fh, "actionnumber", nr );
+  fh->configPutPairNum( "actionnumber", nr );
   return true;
 }
 
@@ -1095,13 +1096,13 @@ bool ChangeHiddenFlag::save(Datei *fh)
   if ( fh == NULL ) return false;
   switch ( mode ) {
     case 1:
-      WConfig::configPutPair( fh, "hiddenfiles", "hide" );
+      fh->configPutPair( "hiddenfiles", "hide" );
       break;
     case 2:
-      WConfig::configPutPair( fh, "hiddenfiles", "show" );
+      fh->configPutPair( "hiddenfiles", "show" );
       break;
     default:
-      WConfig::configPutPair( fh, "hiddenfiles", "toggle" );
+      fh->configPutPair( "hiddenfiles", "toggle" );
       break;
   }
   return true;
