@@ -84,10 +84,10 @@ bool
 ChModOp::save(Datei *fh)
 {
   if ( fh == NULL ) return false;
-  WConfig::configPutPairBool( fh, "onfiles", onfiles );
-  WConfig::configPutPairBool( fh, "ondirs", ondirs );
-  WConfig::configPutPairBool( fh, "recursive", recursive );
-  WConfig::configPutPairBool( fh, "requestflags", requestflags );
+  fh->configPutPairBool( "onfiles", onfiles );
+  fh->configPutPairBool( "ondirs", ondirs );
+  fh->configPutPairBool( "recursive", recursive );
+  fh->configPutPairBool( "requestflags", requestflags );
   return true;
 }
 
@@ -244,13 +244,13 @@ ChModOp::doconfigure(int mode)
           if(win->isParent(msg->key.window,false)==true) {
             switch(msg->key.key) {
               case XK_1:
-                ofcb->setState((ofcb->getState()==1)?0:1);
+                ofcb->setState( ( ofcb->getState() == true ) ? false : true );
                 break;
               case XK_2:
-                odcb->setState((odcb->getState()==1)?0:1);
+                odcb->setState( ( odcb->getState() == true ) ? false : true );
                 break;
               case XK_3:
-                rcb->setState((rcb->getState()==1)?0:1);
+                rcb->setState( ( rcb->getState() == true ) ? false : true );
                 break;
               case XK_Return:
                 if ( cb->getHasFocus() == false )
@@ -270,14 +270,14 @@ ChModOp::doconfigure(int mode)
   if(endmode==0) {
     // ok
     if(mode==1) {
-      tonfiles=(ofcb->getState()==1)?true:false;
-      tondirs=(odcb->getState()==1)?true:false;
-      trecursive=(rcb->getState()==1)?true:false;
+      tonfiles = ofcb->getState();
+      tondirs = odcb->getState();
+      trecursive = rcb->getState();
     } else {
-      onfiles=(ofcb->getState()==1)?true:false;
-      ondirs=(odcb->getState()==1)?true:false;
-      recursive=(rcb->getState()==1)?true:false;
-      requestflags=(rfcb->getState()==1)?true:false;
+      onfiles = ofcb->getState();
+      ondirs = odcb->getState();
+      recursive = rcb->getState();
+      requestflags = rfcb->getState();
     }
   }
   
