@@ -1,6 +1,6 @@
 /* condparser.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2004-2005 Ralf Hoffmann.
+ * Copyright (C) 2004-2006 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: condparser.cc,v 1.8 2005/05/15 15:53:16 ralf Exp $ */
 
 #include "condparser.h"
 #include <aguix/lowlevelfunc.h>
@@ -549,6 +548,7 @@ CondParser::erg_t *CondParser::factor()
 #if 0
 //TODO: Requester are not possible at the moment because
 //      this thread cannot access GUI functions currently
+//TODO: I should show content of error file just like in wpucontext
                 if ( worker->getRequester() != NULL ) {
                   char *reqstr;
                   reqstr = (char*)_allocsafe( strlen( catalog.getLocale( 473 ) ) + strlen( tstr ) + 1 );
@@ -1064,32 +1064,30 @@ char *CondParser::replaceFlags( const char *sstr, bool quote )
 const char *CondParser::requestFlag()
 {
   AGUIX *aguix = Worker::getAGUIX();
-  Button *okb,*cb;
   AWindow *win;
   FieldListView *lv;
-  int w,h,x,y;
   AGMessage *msg;
   int endmode=-1;
   const char *returnstr;
-  Button *b2[2];
   int i, trow, nr;
   
-  w=400;
-  h=300;
-  x=y=5;
-  win = new AWindow( aguix, 10, 10, w, h, 0, catalog.getLocale( 338 ) );
+  win = new AWindow( aguix, 10, 10, 10, 10, 0, catalog.getLocale( 338 ) );
   win->create();
 
-  win->addTextFromString( catalog.getLocale( 578 ), x, y, 5, NULL, NULL, &y );
-  y += 5;
+  AContainer *ac1 = win->setContainer( new AContainer( win, 1, 3 ), true );
+  ac1->setMinSpace( 5 );
+  ac1->setMaxSpace( 5 );
+  ac1->setBorderWidth( 5 );
 
-  lv = (FieldListView*)win->add( new FieldListView( aguix,
-                                                    x,
-                                                    y,
-                                                    w - 2 * x,
+  win->addMultiLineText( catalog.getLocale( 578 ), *ac1, 0, 0, NULL, NULL );
+
+  lv = (FieldListView*)ac1->add( new FieldListView( aguix,
+                                                    0,
+                                                    0,
+                                                    400,
                                                     200,
-                                                    0 ) );
-  y+=lv->getHeight()+5;
+                                                    0 ),
+                                 0, 1, AContainer::CMIN );
   lv->setHBarState(2);
   lv->setVBarState(2);
 
@@ -1110,30 +1108,27 @@ const char *CondParser::requestFlag()
     lv->setData( trow, i );
   }
   
-  okb=(Button*)win->add(new Button(aguix,
-                                   5,
-                                   y,
-                                   catalog.getLocale(11),
-                                   1,
-                                   0,
-                                   0));
-  cb=(Button*)win->add(new Button(aguix,
-                                  5,
-                                  y,
-                                  catalog.getLocale(8),
-                                  1,
-                                  0,
-                                  0));
-  y+=okb->getHeight()+5;
+  AContainer *ac1_1 = ac1->add( new AContainer( win, 2, 1 ), 0, 2 );
+  ac1_1->setMinSpace( 5 );
+  ac1_1->setMaxSpace( -1 );
+  ac1_1->setBorderWidth( 0 );
+  Button *okb =(Button*)ac1_1->add( new Button( aguix,
+                                                0,
+                                                0,
+                                                catalog.getLocale( 11 ),
+                                                1,
+                                                0,
+                                                0 ), 0, 0, AContainer::CFIX );
+  Button *cancelb = (Button*)ac1_1->add( new Button( aguix,
+						     0,
+						     0,
+						     catalog.getLocale( 8 ),
+						     1,
+						     0,
+						     0 ), 1, 0, AContainer::CFIX );
 
-  b2[0] = okb;
-  b2[1] = cb;
-  AGUIX::scaleElementsW( w, 5, 10, -1, false, false, (GUIElement**)b2, NULL, 2 );
-  
-  h=y;
   win->setDoTabCycling( true );
-  win->resize(w,h);
-  win->setMinSize(w,h);
+  win->contMaximize( true );
   win->show();
   for(;endmode==-1;) {
     msg=aguix->WaitMessage(win);
@@ -1144,14 +1139,7 @@ const char *CondParser::requestFlag()
           break;
         case AG_BUTTONCLICKED:
           if(msg->button.button==okb) endmode=0;
-          else if(msg->button.button==cb) endmode=1;
-          break;
-        case AG_SIZECHANGED:
-          AGUIX::scaleElementsW( msg->size.neww, 5, 10, -1, false, false, (GUIElement**)b2, NULL, 2 );
-          for ( i = 0; i < 2; i++ ) {
-            b2[i]->move( b2[i]->getX(), msg->size.newh - 5 - b2[i]->getHeight() );
-          }
-          lv->resize( msg->size.neww - 10, b2[0]->getY() - 5 - lv->getY() );
+          else if(msg->button.button==cancelb) endmode=1;
           break;
       }
       aguix->ReplyMessage(msg);
