@@ -316,16 +316,19 @@
      SCROLLBUTTON_WCP = 539,
      SELECTMETHOD_WCP = 540,
      ALTERNATIVE_WCP = 541,
-     ERROR = 542,
-     ACTIVESIDE_WCP = 543,
-     SHOWFREESPACE_WCP = 544,
-     ACTIVEMODE_WCP = 545,
-     ASK_WCP = 546,
-     SSHALLOW_WCP = 547,
-     FIELD_WIDTH_WCP = 548,
-     QUICKSEARCHENABLED_WCP = 549,
-     STRING_WCP = 550,
-     NUM_WCP = 551
+     SEARCHOP_WCP = 542,
+     EDITCOMMAND_WCP = 543,
+     SHOWPREVRESULTS_WCP = 544,
+     ERROR = 545,
+     ACTIVESIDE_WCP = 546,
+     SHOWFREESPACE_WCP = 547,
+     ACTIVEMODE_WCP = 548,
+     ASK_WCP = 549,
+     SSHALLOW_WCP = 550,
+     FIELD_WIDTH_WCP = 551,
+     QUICKSEARCHENABLED_WCP = 552,
+     STRING_WCP = 553,
+     NUM_WCP = 554
    };
 #endif
 #define LEFTBRACE_WCP 258
@@ -612,28 +615,31 @@
 #define SCROLLBUTTON_WCP 539
 #define SELECTMETHOD_WCP 540
 #define ALTERNATIVE_WCP 541
-#define ERROR 542
-#define ACTIVESIDE_WCP 543
-#define SHOWFREESPACE_WCP 544
-#define ACTIVEMODE_WCP 545
-#define ASK_WCP 546
-#define SSHALLOW_WCP 547
-#define FIELD_WIDTH_WCP 548
-#define QUICKSEARCHENABLED_WCP 549
-#define STRING_WCP 550
-#define NUM_WCP 551
+#define SEARCHOP_WCP 542
+#define EDITCOMMAND_WCP 543
+#define SHOWPREVRESULTS_WCP 544
+#define ERROR 545
+#define ACTIVESIDE_WCP 546
+#define SHOWFREESPACE_WCP 547
+#define ACTIVEMODE_WCP 548
+#define ASK_WCP 549
+#define SSHALLOW_WCP 550
+#define FIELD_WIDTH_WCP 551
+#define QUICKSEARCHENABLED_WCP 552
+#define STRING_WCP 553
+#define NUM_WCP 554
 
 
 
 
 #ifndef YYSTYPE
-#line 192 "configparser.y"
+#line 196 "configparser.y"
 typedef union {
   int num;
   char *strptr;
 } yystype;
 /* Line 1281 of /usr/share/bison/yacc.c.  */
-#line 637 "configparser.tab.h"
+#line 643 "configparser.tab.h"
 # define YYSTYPE yystype
 #endif
 
