@@ -314,7 +314,10 @@ struct mytoken tokenlist[]={
   { ACTIVATEBUTTON_WCP, "activatebutton" },
   { SCROLLBUTTON_WCP, "scrollbutton" },
   { SELECTMETHOD_WCP, "selectmethod" },
-  { ALTERNATIVE_WCP, "alternative" }
+  { ALTERNATIVE_WCP, "alternative" },
+  { SEARCHOP_WCP, "searchop" },
+  { EDITCOMMAND_WCP, "editcommand" },
+  { SHOWPREVRESULTS_WCP, "showprevresults" }
 };
 
 ArrayList *tokenlist_sorted = NULL;
