@@ -83,9 +83,9 @@ bool
 CreateSymlinkOp::save(Datei *fh)
 {
   if ( fh == NULL ) return false;
-  WConfig::configPutPairBool( fh, "samedir", same_dir );
-  WConfig::configPutPairBool( fh, "relative", local );
-  WConfig::configPutPairBool( fh, "requestflags", requestflags );
+  fh->configPutPairBool( "samedir", same_dir );
+  fh->configPutPairBool( "relative", local );
+  fh->configPutPairBool( "requestflags", requestflags );
   return true;
 }
 
@@ -282,10 +282,10 @@ CreateSymlinkOp::doconfigure(int mode)
           if(win->isParent(msg->key.window,false)==true) {
             switch(msg->key.key) {
               case XK_1:
-                sdcb->setState((sdcb->getState()==1)?0:1);
+                sdcb->setState((sdcb->getState() == true ) ? false : true );
                 break;
               case XK_2:
-                gcb->setState((gcb->getState()==1)?0:1);
+                gcb->setState((gcb->getState() == true ) ? false : true );
                 break;
               case XK_Return:
                 if ( cb->getHasFocus() == false ) {
@@ -306,12 +306,12 @@ CreateSymlinkOp::doconfigure(int mode)
   if(endmode==0) {
     // ok
     if(mode==1) {
-      tsame_dir=(sdcb->getState()==1)?true:false;
-      tlocal=(gcb->getState()==1)?true:false;
+      tsame_dir = sdcb->getState();
+      tlocal = gcb->getState();
     } else {
-      same_dir=(sdcb->getState()==1)?true:false;
-      local=(gcb->getState()==1)?true:false;
-      requestflags=(rfcb->getState()==1)?true:false;
+      same_dir = sdcb->getState();
+      local = gcb->getState();
+      requestflags = rfcb->getState();
     }
   }
   
