@@ -1,6 +1,6 @@
 /* cursorops.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2004 Ralf Hoffmann.
+ * Copyright (C) 2001-2006 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: cursorops.cc,v 1.24 2005/10/19 18:06:21 ralf Exp $ */
+/* $Id: cursorops.cc,v 1.25 2006/02/09 07:01:43 ralf Exp $ */
 
 #include "cursorops.h"
 #include "listermode.h"
@@ -772,7 +772,15 @@ int EnterDirOp::run( WPUContext *wpu, ActionMessage *msg )
           if(lm1!=NULL) {
             if(lm1->isType("NormalMode")==true) {
               nm1=(NormalMode*)lm1;
-              nm1->enterDir(return_str);
+
+	      //TODO show a choosebutton in the requester to enable env replacing?
+	      std::string tstr1 = return_str;
+	      if ( tstr1[0] == '$' ) {
+		char *tstr2 = HandlePathExt( tstr1.c_str() );
+		tstr1 = tstr2;
+		_freesafe( tstr2 );
+	      }
+              nm1->enterDir( tstr1.c_str() );
             }
           }
         }
@@ -959,19 +967,19 @@ int EnterDirOp::configure()
 bool EnterDirOp::save(Datei *fh)
 {
   if ( fh == NULL ) return false;
-  WConfig::configPutPairString( fh, "dir", dir );
+  fh->configPutPairString( "dir", dir );
   switch ( enterdirmode ) {
     case ENTERDIROP_ACTIVE2OTHER:
-      WConfig::configPutPair( fh, "mode", "active2other" );
+      fh->configPutPair( "mode", "active2other" );
       break;
     case ENTERDIROP_SPECIAL:
-      WConfig::configPutPair( fh, "mode", "special" );
+      fh->configPutPair( "mode", "special" );
       break;
     case ENTERDIROP_REQUEST:
-      WConfig::configPutPair( fh, "mode", "request" );
+      fh->configPutPair( "mode", "request" );
       break;
     default:
-      WConfig::configPutPair( fh, "mode", "active" );
+      fh->configPutPair( "mode", "active" );
   }
   return true;
 }
