@@ -32,6 +32,8 @@
 #include "condparser.h"
 #include "stringbuf.h"
 #include <aguix/mutex.h>
+#include "wcfiletype.hh"
+#include <aguix/utf8.hh>
 
 #ifndef MAXPATHLEN
 #define MAXPATHLEN 2048
@@ -42,6 +44,8 @@ Datei::Datei()
   fd = -1;
   error=0;
   iseof = false;
+
+  sectiondepth = 0;
 }
 
 Datei::~Datei()
@@ -2116,7 +2120,7 @@ ArrayList *Verzeichnis::getInvalidEntries()
 char *Datei::shrinkFilename( const char *str, int maxlength, AWidth &lencalc )
 {
   char *tstr = NULL;
-  int len, len1, len2;
+  int len, len1;
   bool stopnow;
   const char *lastl, *lastr, *startl, *startr, *str1;
   const char *filename;
@@ -2154,14 +2158,13 @@ char *Datei::shrinkFilename( const char *str, int maxlength, AWidth &lencalc )
   //   specialcase: filename is shorter then maxlength-5
   //     but the first dir doesnt fit, then use as much chars from it
   //     to fill maxlength
-  
-  str1 = str +
-         len - // this is the 0 byte
-         2;              // to skip a final / (if exists)
-                         // since a filename is atleast 1 char this would
-                         // point in the worst case at the beginning slash
-  // remember that we require maxlength atleast 5 chars and so the str is
-  // atleast 6 chars so this will always point into the string
+
+  int right_pos = len; // this is the 0 byte
+  UTF8::movePosToPrevChar( str, right_pos );  // to last character
+  UTF8::movePosToPrevChar( str, right_pos );  /* to skip a final / (if exists)
+                                                 since a filename is atleast 1 char this would
+                                                 point in the worst case at the beginning slash */
+  str1 = str + right_pos;
   
   // now search for the slash backwards
   
@@ -2214,10 +2217,14 @@ char *Datei::shrinkFilename( const char *str, int maxlength, AWidth &lencalc )
       } else {
         // test if startl and/or startr will fit
         // otherwise stop
-        
-        len1 = startl - str + 1;
-        len2 = len - ( lastr - str );  // ( lastr - str ) is the number of chars before lastr!
-                                       // but because we sub it from len, don't add 1 like before
+
+        // get the number of bytes up to including startl
+        right_pos = startl - str;
+        UTF8::movePosToNextChar( str, right_pos );
+        len1 = right_pos;
+        /* len1 is actually ( startl - str + 1 ) since startl
+           points to the slash but this it's generic
+           the same goes for the next two lastl calculations */
 
 	l1 = lencalc.getWidth( str, len1 );
 	l2 = lencalc.getWidth( lastr );
@@ -2227,8 +2234,10 @@ char *Datei::shrinkFilename( const char *str, int maxlength, AWidth &lencalc )
           lastl = startl;
         }
         
-        len1 = lastl - str + 1;
-        len2 = len - ( startr - str );
+        // get the number of bytes up to including lastl
+        right_pos = lastl - str;
+        UTF8::movePosToNextChar( str, right_pos );
+        len1 = right_pos;
 
 	l1 = lencalc.getWidth( str, len1 );
 	l2 = lencalc.getWidth( startr );
@@ -2266,7 +2275,11 @@ char *Datei::shrinkFilename( const char *str, int maxlength, AWidth &lencalc )
 	    tstr = shrinkstring( str, maxlength, lencalc );
 	  }
         } else {
-          len1 = ( lastl - str + 1);
+          // get the number of bytes up to including lastl
+          right_pos = lastl - str;
+          UTF8::movePosToNextChar( str, right_pos );
+          len1 = right_pos;
+          
 	  tstr1 = "";
 	  tstr1.append( str, len1 );
 	  tstr1 += "...";
@@ -2865,3 +2878,180 @@ int Datei::copyfile( const char *dest, const char *source )
   return erg;
 #undef BUFSIZE
 }
+
+void Datei::configPutPair( const char *id, const char *info )
+{
+  std::string str1;
+  int x;
+
+  if ( ( id == NULL ) || ( info == NULL ) ) return;
+  str1 = "";
+  for ( x = 0; x < sectiondepth; x++ ) str1 += "\t";
+  str1 += id;
+  str1 += " = ";
+  str1 += info;
+  str1 += ";";
+  putLine( str1.c_str() );
+}
+
+void Datei::configPutPairNum( const char *id, int num )
+{
+  std::string str1;
+  char buf[A_BYTESFORNUMBER( int )];
+  int x;
+
+  if ( id == NULL ) return;
+  str1 = "";
+  for ( x = 0; x < sectiondepth; x++ ) str1 += "\t";
+  sprintf( buf, "%d", num );
+  str1 += id;
+  str1 += " = ";
+  str1 += buf;
+  str1 += ";";
+  putLine( str1.c_str() );
+}
+
+void Datei::configPutPairNum( const char *id, int num1, int num2 )
+{
+  std::string str1;
+  char buf[A_BYTESFORNUMBER( int )];
+  int x;
+
+  if ( id == NULL ) return;
+  str1 = "";
+  for ( x = 0; x < sectiondepth; x++ ) str1 += "\t";
+  sprintf( buf, "%d", num1 );
+  str1 += id;
+  str1 += " = ";
+  str1 += buf;
+  str1 += ",";
+  sprintf( buf, "%d", num2 );
+  str1 += buf;
+  str1 += ";";
+  putLine( str1.c_str() );
+}
+
+void Datei::configPutPairString( const char *id, const char *str )
+{
+  std::string str1;
+  char *buf;
+  int i, o;
+  int x;
+
+  if ( ( id == NULL ) || ( str == NULL ) ) return;
+  str1 = "";
+  for ( x = 0; x < sectiondepth; x++ ) str1 += "\t";
+
+  buf = (char*)_allocsafe( strlen( str ) * 2 + 1 );
+  for ( i = 0, o = 0; i < (int)strlen( str ); i++ ) {
+    if ( str[i] == '"' ) {
+      buf[o++] = '\\';
+      buf[o++] = '"';
+    } else if ( str[i] == '\\' ) {
+      buf[o++] = '\\';
+      buf[o++] = '\\';
+    } else {
+      buf[o++] = str[i];
+    }
+  }
+  buf[o] = '\0';
+  str1 += id;
+  str1 += " = \"";
+  str1 += buf;
+  str1 += "\";";
+  _freesafe( buf );
+  putLine( str1.c_str() ); 
+}
+
+void Datei::configPutPairBool( const char *id, bool val )
+{
+  std::string str1;
+  int x;
+
+  if ( id == NULL ) return;
+  str1 = "";
+  for ( x = 0; x < sectiondepth; x++ ) str1 += "\t";
+
+  str1 += id;
+  str1 += " = ";
+  str1 += ( ( val == true ) ? "true" : "false" );
+  str1 += ";";
+  putLine( str1.c_str() );
+}
+
+void Datei::configPutInfo( const char *str, bool semicolon )
+{
+  std::string str1;
+  int x;
+
+  if ( str == NULL ) return;
+  str1 = "";
+  for ( x = 0; x < sectiondepth; x++ ) str1 += "\t";
+
+  str1 += str;
+  if ( semicolon == true ) str1 += ";";
+  putLine( str1.c_str() );
+}
+
+void Datei::configPutString( const char *str, bool semicolon )
+{
+  std::string str1;
+  char *buf;
+  int i, o;
+  int x;
+
+  if ( str == NULL ) return;
+  str1 = "";
+  for ( x = 0; x < sectiondepth; x++ ) str1 += "\t";
+
+  buf = (char*)_allocsafe( strlen( str ) * 2 + 1 );
+  for ( i = 0, o = 0; i < (int)strlen( str ); i++ ) {
+    if ( str[i] == '"' ) {
+      buf[o++] = '\\';
+      buf[o++] = '"';
+    } else if ( str[i] == '\\' ) {
+      buf[o++] = '\\';
+      buf[o++] = '\\';
+    } else {
+      buf[o++] = str[i];
+    }
+  }
+  buf[o] = '\0';
+  str1 += "\"";
+  str1 += buf;
+  str1 += "\";";
+  _freesafe( buf );
+  putLine( str1.c_str() ); 
+}
+
+void Datei::configOpenSection( const char *sectioname )
+{
+  int x;
+  std::string str1;
+
+  if ( sectioname == NULL ) return;
+  if ( ( sectiondepth < 0 ) || ( sectiondepth > 100 ) ) sectiondepth = 0;
+
+  str1 = "";
+  for ( x = 0; x < sectiondepth; x++ ) str1 += "\t";
+
+  str1 += sectioname;
+  str1 += " {";
+  putLine( str1.c_str() );
+  sectiondepth++;
+}
+
+void Datei::configCloseSection()
+{
+  int x;
+  std::string str1;
+
+  sectiondepth--;
+  if ( ( sectiondepth < 0 ) || ( sectiondepth > 100 ) ) sectiondepth = 0;
+
+  str1 = "";
+  for ( x = 0; x < sectiondepth; x++ ) str1 += "\t";
+
+  str1 += "}";
+  putLine( str1.c_str() );
+}
