@@ -102,12 +102,24 @@ public:
   static loff_t fileSize( const char * );
   static char *getRelativePath( const char *source, const char *destdir );
   static int copyfile( const char *dest, const char *source );
+
+  void configPutPair( const char *id, const char *info );
+  void configPutPairNum( const char *id, int num );
+  void configPutPairNum( const char *id, int num1, int num2 );
+  void configPutPairString( const char *id, const char *str );
+  void configPutPairBool( const char *id, bool val );
+  void configPutInfo( const char *str, bool semicolon );
+  void configPutString( const char *str, bool semicolon );
+  void configOpenSection( const char *sectioname );
+  void configCloseSection();
 private:
   int fd;
   long error;
   int putCharacter( int c );
   int getCharacter();
   bool iseof;
+  
+  int sectiondepth;
 };
 
 class FileEntry
