@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: deleteop.cc,v 1.30 2005/10/19 18:06:01 ralf Exp $ */
+/* $Id: deleteop.cc,v 1.31 2006/02/09 21:17:50 ralf Exp $ */
 
 #include "listermode.h"
 #include "normalmode.h"
@@ -182,7 +182,7 @@ int DeleteOp::configure()
     }
   }
   if(ende==1) {
-    also_active = ( cb->getState() == 1 ) ? true : false;
+    also_active = cb->getState();
   }
   delete win;
   return (ende==1)?0:1;
@@ -191,7 +191,7 @@ int DeleteOp::configure()
 bool DeleteOp::save(Datei *fh)
 {
   if ( fh == NULL ) return false;
-  WConfig::configPutPairBool( fh, "alsoactive", also_active );
+  fh->configPutPairBool( "alsoactive", also_active );
   return true;
 }
 
@@ -435,6 +435,16 @@ DeleteOpWin::redraw()
         case AG_BUTTONCLICKED:
           if(msg->button.button==cb) returnvalue=1;
           break;
+	case AG_KEYPRESSED:
+	  if ( msg->key.key == XK_Escape ) {
+	    std::string b1 = catalog.getLocale( 667 );
+	    b1 += "|";
+	    b1 += catalog.getLocale( 668 );
+	    if ( request( catalog.getLocale( 123 ), catalog.getLocale( 666 ), b1.c_str(), Requester::REQUEST_NONE ) == 0 ) {
+	      returnvalue = 1;
+	    }
+	  }
+	  break;
         case AG_SIZECHANGED:
           if ( msg->size.window == window->getWindow() ) {
             bb1->resize( msg->size.neww - 2 * window->getBorderWidth(), bb1->getHeight() );
