@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: dirsizeop.cc,v 1.11 2004/12/12 21:57:12 ralf Exp $ */
+/* $Id: dirsizeop.cc,v 1.12 2005/10/19 18:05:50 ralf Exp $ */
 
 #include "dirsizeop.h"
 #include "listermode.h"
@@ -55,10 +55,9 @@ DirSizeOp::getName()
 }
 
 int
-DirSizeOp::run(ActionMessage *msg)
+DirSizeOp::run( WPUContext *wpu, ActionMessage *msg )
 {
   ListerMode *lm1;
-  am=msg;
   if(msg->mode!=msg->AM_MODE_DNDACTION) {
     Lister *l1 = msg->getWorker()->getActiveLister();
     if(l1!=NULL) {
@@ -66,7 +65,7 @@ DirSizeOp::run(ActionMessage *msg)
       lm1=startlister->getActiveMode();
       if(lm1!=NULL)
         if(lm1->isType("NormalMode")==true)
-          normalmodedirsize();
+          normalmodedirsize( msg );
     }
   }
   return 0;
@@ -79,7 +78,7 @@ DirSizeOp::getDescription()
 }
 
 int
-DirSizeOp::normalmodedirsize()
+DirSizeOp::normalmodedirsize( ActionMessage *am )
 {
   NormalMode *nm1=NULL;
   ListerMode *lm1=NULL;
