@@ -27,6 +27,7 @@
 #include "worker_locale.h"
 #include "wconfig.h"
 #include "worker.h"
+#include "pdatei.h"
 
 /* THREADSAFE */
 ExeClass::ExeClass( execlass_execute_t exetype, Worker *w )
@@ -237,7 +238,11 @@ int ExeClass::getOutputAndRV( char **return_output, int *return_value, int *retu
 
   if ( worker != NULL ) worker->unsetWaitCursor();
 
-  if ( return_output != NULL ) *return_output = erg;
+  if ( return_output != NULL )
+    *return_output = erg;
+  else if ( erg != NULL )
+    _freesafe( erg );
+  
   if ( return_value != NULL ) *return_value = rerg;
   
   return 0;
@@ -762,3 +767,29 @@ char *Worker_replaceEnv( const char *str )
   return curstr;
 }
 
+int ExeClass::readErrorOutput( std::string &return_str, int maxsize )
+{
+  PDatei d;
+  char buf[128];
+  int l, r;
+  
+  if ( maxsize < 1 )
+    maxsize = 1;
+
+  if ( d.open( tmperror ) == 0 ) {
+    while ( maxsize > 0 ) {
+      l = a_min( (int)sizeof( buf ) - 1, maxsize );
+      r = d.read( buf, l );
+      
+      if ( r < 1 )
+        break;
+
+      buf[r] = '\0';
+      return_str += buf;
+      
+      maxsize -= r;
+    }
+    d.close();
+  }
+  return 0;
+}
