@@ -1,6 +1,6 @@
 /* import.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2004 Ralf Hoffmann.
+ * Copyright (C) 2001-2006 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,423 +18,16 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: import.cc,v 1.19 2004/10/27 21:07:39 ralf Exp $ */
 
 #include "import.h"
 #include "worker_commands.h"
-
-int WConfig::parseChunk(Datei *fp)
-{
-  /* 0 kein Fehler
-     1 kein gltiger Chunk
-     2 Dateiende
-     3 Fehler */
-  int returnvalue,y;
-  unsigned char red,green,blue;
-  char *tstr,*chunkname;
-  int len,slen;
-  int sl,cl,il,ll;
-  int colorsize;
-  List *l1,*l2, *keylist;
-  WC_Color *col;
-  WCButton *b1;
-  WCPath *p1;
-  WCDoubleShortkey *key;
-  WCFiletype *ft1;
-  WCHotkey *h1;
-  unsigned long comnr,flag1,flag2;
-  char *usercomstr;
-  FunctionProto *funpro;
-  int x;
-  short filedesc[64];
-  
-  l1=new List();
-  l2=new List();
-  key=new WCDoubleShortkey();
-  keylist = new List();
-  keylist->addElement( key );
-
-  sl=Datei::getUShortSize();
-  cl=Datei::getUCharSize();
-  il=Datei::getIntSize();
-  ll=Datei::getULongSize();
-
-  returnvalue=0;
-  chunkname=fp->getString(4);
-  if(strcmp("GLBL",chunkname)==0) {
-    len=fp->getULong();
-    colorsize=fp->getUShort();
-    len-=sl;
-    while(len>0) {
-      red=fp->getUChar();
-      green=fp->getUChar();
-      blue=fp->getUChar();
-      col=new WC_Color(red,green,blue);
-      l1->addElement(col);
-      len-=3*cl;
-    }
-    setColors(l1);
-    applyColorList(colors);
-    col=(WC_Color*)l1->getFirstElement();
-    while(col!=NULL) {
-      delete col;
-      col=(WC_Color*)l1->getNextElement();
-    }
-    l1->removeAllElements();
-  } else if(strcmp("LANG",chunkname)==0) {
-    len=fp->getULong();
-    if(fp->errors()!=0) {
-      returnvalue=2;
-    }
-    tstr=fp->getString(len);
-    setLang(tstr);
-    _freesafe(tstr);
-  } else if(strcmp("COLD",chunkname)==0) {
-    len=fp->getULong();
-    setStatusbar(0,fp->getUShort());
-    setStatusbar(1,fp->getUShort());
-    setSelLVB(0,fp->getUShort());
-    setSelLVB(1,fp->getUShort());
-    setUnselLVB(0,fp->getUShort());
-    setUnselLVB(1,fp->getUShort());
-    setSelDir(0,fp->getUShort());
-    setSelDir(1,fp->getUShort());
-    setUnselDir(0,fp->getUShort());
-    setUnselDir(1,fp->getUShort());
-    setSelFile(0,fp->getUShort());
-    setSelFile(1,fp->getUShort());
-    setUnselFile(0,fp->getUShort());
-    setUnselFile(1,fp->getUShort());
-    setClockbar(0,fp->getUShort());
-    setClockbar(1,fp->getUShort());
-    setRequest(0,fp->getUShort());
-    setRequest(1,fp->getUShort());
-    fp->getUShort(); // no use
-    fp->getUShort(); // no use
-    fp->getUShort(); // no use
-    fp->getUShort(); // no use
-    len-=22*sl;
-    if(len>0) {
-      /* da gibts noch Informationen, die ich nicht auswerten kann.
-         damit's weiter geht, diesen bereich berspringen */
-      fp->seek(len,SEEK_CUR);
-    }
-    if(fp->errors()!=0) {
-      returnvalue=2;
-    }
-  } else if(strcmp("LDEF",chunkname)==0) {
-    len=fp->getULong();
-    setVBarLeft(0,(fp->getUChar()==1)?true:false);
-    setHBarTop(0,(fp->getUChar()==1)?true:false);
-    setHBarHeight(0,fp->getUShort());
-    setVBarWidth(0,fp->getUShort());
-    setVBarLeft(1,(fp->getUChar()==1)?true:false);
-    setHBarTop(1,(fp->getUChar()==1)?true:false);
-    setHBarHeight(1,fp->getUShort());
-    setVBarWidth(1,fp->getUShort());
-    setColumns(fp->getUChar());
-    setRows(fp->getUChar());
-    len-=6*cl+4*sl;
-    if(len>0) {
-      fp->seek(len,SEEK_CUR);
-    }
-    if(fp->errors()!=0) {
-      returnvalue=2;
-    }
-  } else if(strcmp("DIRS",chunkname)==0) {
-    len=fp->getULong();
-    slen=fp->getULong();
-    tstr=fp->getString(slen);
-    setStartDir(0,tstr);
-    _freesafe(tstr);
-    len-=slen+ll;
-    slen=fp->getULong();
-    tstr=fp->getString(slen);
-    setStartDir(1,tstr);
-    _freesafe(tstr);
-    len-=slen+ll;
-    if(len>0) {
-      fp->seek(len,SEEK_CUR);
-    }
-    if(fp->errors()!=0) {
-      returnvalue=2;
-    }
-  } else if(strcmp("BUTD",chunkname)==0) {
-    len=fp->getULong();
-    while(len>0) {
-      b1=new WCButton();
-      
-      b1->setCheck((fp->getUChar()==1)?true:false);
-      len-=cl;
-      y=fp->getULong();
-      len-=ll;
-      tstr=fp->getString(y);
-      b1->setText(tstr);
-      _freesafe(tstr);
-      len-=y;
-      b1->setFG(fp->getUShort());
-      b1->setBG(fp->getUShort());
-
-      key->setKeySym( fp->getULong(), 0 );
-      key->setMod( fp->getUShort(), 0 );  //TODO: ob das alte Mod und das neue kompatible sind?
-                                     // erstmal lasse ich es so, aber das muss geprueft werden
-      b1->setDoubleKeys( keylist);
-      
-      comnr=fp->getULong();
-      flag1=fp->getULong();
-      flag2=fp->getULong();
-
-      len-=4*ll+3*sl;
-      y=fp->getULong();
-      len-=ll;
-      usercomstr=fp->getString(y);
-      len-=y;
-
-      if(b1->getCheck()==true) {
-        getFunctionProtoOldStyle(comnr,flag1,flag2,usercomstr,l2);
-        b1->setComs(l2);
-      }
-
-      funpro=(FunctionProto*)l2->getFirstElement();
-      while(funpro!=NULL) {
-        delete funpro;
-        funpro=(FunctionProto*)l2->getNextElement();
-      }
-      l2->removeAllElements();
-
-      _freesafe(usercomstr);
-      
-      l1->addElement(b1);
-    }
-    setButtons(l1);
-    b1=(WCButton*)l1->getFirstElement();
-    while(b1!=NULL) {
-      delete b1;
-      b1=(WCButton*)l1->getNextElement();
-    }
-    l1->removeAllElements();
-    
-    if(fp->errors()!=0) {
-      returnvalue=2;
-    }
-  } else if(strcmp("PATD",chunkname)==0) {
-    len=fp->getULong();
-    while(len>0) {
-      p1=new WCPath();
-      
-      p1->setCheck((fp->getUChar()==1)?true:false);
-      len-=cl;
-      y=fp->getULong();
-      len-=ll;
-      tstr=fp->getString(y);
-      len-=y;
-      p1->setName(tstr);
-      _freesafe(tstr);
-      
-      p1->setFG(fp->getUShort());
-      p1->setBG(fp->getUShort());
-      
-      key->setKeySym( fp->getULong(), 0 );
-      key->setMod( fp->getUShort(), 0 );  //TODO: ob das alte Mod und das neue kompatible sind?
-                                     // erstmal lasse ich es so, aber das muss geprueft werden
-      p1->setDoubleKeys( keylist );
-      len-=3*sl+ll;
-
-      y=fp->getULong();
-      len-=ll;
-      tstr=fp->getString(y);
-      len-=y;
-      p1->setPath(tstr);
-      _freesafe(tstr);
-
-      l1->addElement(p1);
-    }
-    setPaths(l1);
-    p1=(WCPath*)l1->getFirstElement();
-    while(p1!=NULL) {
-      delete p1;
-      p1=(WCPath*)l1->getNextElement();
-    }
-    l1->removeAllElements();
-    if(fp->errors()!=0) {
-      returnvalue=2;
-    }
-  } else if(strcmp("FITY",chunkname)==0) {
-    len=fp->getULong();
-    while(len>0) {
-      ft1=new WCFiletype();
-      
-      y=fp->getULong();
-      len-=ll;
-      tstr=fp->getString(y);
-      len-=y;
-      ft1->setName(tstr);
-      _freesafe(tstr);
-      
-      y=fp->getULong();
-      len-=ll;
-      tstr=fp->getString(y);
-      len-=y;
-      _freesafe(tstr);
-      
-      comnr=fp->getULong();
-      flag1=fp->getULong();
-      flag2=fp->getULong();
-      len-=3*ll;
-      y=fp->getULong();
-      len-=ll;
-      usercomstr=fp->getString(y);
-      len-=y;
-      
-      getFunctionProtoOldStyle(comnr,flag1,flag2,usercomstr,l2);
-      ft1->setDoubleClickActions(l2);
-
-      funpro=(FunctionProto*)l2->getFirstElement();
-      while(funpro!=NULL) {
-        delete funpro;
-        funpro=(FunctionProto*)l2->getNextElement();
-      }
-      l2->removeAllElements();
-
-      _freesafe(usercomstr);
-      
-      y=fp->getULong();
-      len-=ll;
-      tstr=fp->getString(y);
-      len-=y;
-      ft1->setPattern(tstr);
-      _freesafe(tstr);
-
-      for(x=0;x<64;x++) {
-        filedesc[x]=(signed short)fp->getUShort();
-        len-=sl;
-      }
-      ft1->setFiledesc(filedesc);
-      ft1->setUsePattern((fp->getUChar()==1)?true:false);
-      ft1->setUseFiledesc((fp->getUChar()==1)?true:false);
-      len-=2*cl;
-
-      l1->addElement(ft1);
-    }
-    setFiletypes(l1);
-    initFixTypes();
-    ft1=(WCFiletype*)l1->getFirstElement();
-    while(ft1!=NULL) {
-      delete ft1;
-      ft1=(WCFiletype*)l1->getNextElement();
-    }
-    l1->removeAllElements();
-    if(fp->errors()!=0) {
-      returnvalue=2;
-    }
-  } else if(strcmp("HOTS",chunkname)==0) {
-    len=fp->getULong();
-    while(len>0) {
-      h1=new WCHotkey();
-
-      y=fp->getULong();
-      len-=ll;
-      tstr=fp->getString(y);
-      len-=y;
-      h1->setName(tstr);
-      _freesafe(tstr);
-
-      key->setKeySym( fp->getULong(), 0 );
-      key->setMod( fp->getUShort(), 0 );  //TODO: ob das alte Mod und das neue kompatible sind?
-                                     // erstmal lasse ich es so, aber das muss geprueft werden
-      h1->setDoubleKeys( keylist );
-
-      comnr=fp->getULong();
-      flag1=fp->getULong();
-      flag2=fp->getULong();
-      len-=4*ll+sl;
-      y=fp->getULong();
-      len-=ll;
-      usercomstr=fp->getString(y);
-      len-=y;
-      
-      getFunctionProtoOldStyle(comnr,flag1,flag2,usercomstr,l2);
-      h1->setComs(l2);
-
-      funpro=(FunctionProto*)l2->getFirstElement();
-      while(funpro!=NULL) {
-        delete funpro;
-        funpro=(FunctionProto*)l2->getNextElement();
-      }
-      l2->removeAllElements();
-
-      _freesafe(usercomstr);
-      
-      l1->addElement(h1);
-    }
-    setHotkeys(l1);
-    h1=(WCHotkey*)l1->getFirstElement();
-    while(h1!=NULL) {
-      delete h1;
-      h1=(WCHotkey*)l1->getNextElement();
-    }
-    l1->removeAllElements();
-    
-    if(fp->errors()!=0) {
-      returnvalue=2;
-    }
-  } else if(strcmp("FONT",chunkname)==0) {
-    len=fp->getULong();
-    if(fp->errors()!=0) {
-      returnvalue=2;
-    }
-    tstr=fp->getString(len);
-    setFont(0,tstr);
-    setFont(1,tstr);
-    setFont(2,tstr);
-    setFont(3,tstr);
-    _freesafe(tstr);
-  } else {
-    returnvalue=1;
-  }
-  _freesafe(chunkname);
-  
-  delete l1;
-  delete l2;
-  delete key;
-  delete keylist;
-  
-  return returnvalue;
-}
-
-int WConfig::read1Config(Datei *fp)
-{
-  char *tstr;
-  const char *buttonstr,*textstr;
-  int x;
-  Requester *req;
-
-  showOldRequest=false;
-  fp->seek(0,SEEK_SET);
-  tstr=fp->getString(4);
-  if(strcmp("FORM",tstr)==0) {
-    fp->seek(4,SEEK_CUR);
-    _freesafe(tstr);
-    tstr=fp->getString(4);
-    if(strcmp("WCFG",tstr)==0) {
-      _freesafe(tstr);
-      req=new Requester(worker->getAGUIX());
-      textstr=catalog.getLocale(366);
-      buttonstr=catalog.getLocale(11);
-      req->request(catalog.getLocale(124),textstr,buttonstr);
-      delete req;
-      do {
-        x=parseChunk(fp);
-      } while(x==0);
-    } else {
-      _freesafe(tstr);
-    }
-  } else {
-    _freesafe(tstr);
-    return 1;
-  }
-  if(fp->errors()==0) return 0; else return 1;
-}
+#include "wc_color.hh"
+#include "wcdoubleshortkey.hh"
+#include "wcpath.hh"
+#include "wcfiletype.hh"
+#include "wchotkey.hh"
+#include "wcbutton.hh"
+#include "workerversion.h"
 
 void WConfig::setDefaultConfig()
 {
@@ -1211,246 +804,6 @@ void WConfig::setDefaultConfig()
   delete keylist;
 }
 
-void WConfig::getFunctionProtoOldStyle(const unsigned long comnr,
-                                       const unsigned long flag1,
-                                       const unsigned long flag2,
-                                       const char *usercomstr,
-                                       List *l2)
-{
-  FunctionProto *funpro=NULL;
-  char *tstr;
-  const char *buttonstr,*textstr;
-  Requester *req;
-
-  switch(comnr) {
-    case USER:
-      funpro=new OwnOp();
-      if(usercomstr!=NULL) {
-        changeRS(usercomstr,&tstr);
-        ((OwnOp*)funpro)->setComStr(tstr);
-        _freesafe(tstr);
-      }
-      if((flag1&1)==1) {
-        ((OwnOp*)funpro)->setSeparateEachEntry(true);
-        if(showOldRequest==false) {
-          req=new Requester(worker->getAGUIX());
-          textstr=catalog.getLocale(363);
-          buttonstr=catalog.getLocale(11);
-          req->request(catalog.getLocale(364),textstr,buttonstr);
-          delete req;
-          showOldRequest=true;
-        }
-      } else ((OwnOp*)funpro)->setSeparateEachEntry(false);
-      if((flag1&2)==2) ((OwnOp*)funpro)->setRecursive(true);
-      else ((OwnOp*)funpro)->setRecursive(false);
-      
-      if((flag1&4)==4) ((OwnOp*)funpro)->setOwnStart(OwnOp::OWNOP_START_IN_TERMINAL);
-      else if((flag1&8)==8) ((OwnOp*)funpro)->setOwnStart(OwnOp::OWNOP_START_IN_TERMINAL_AND_WAIT4KEY);
-      else if((flag1&16)==16) ((OwnOp*)funpro)->setOwnStart(OwnOp::OWNOP_SHOW_OUTPUT);
-      else ((OwnOp*)funpro)->setOwnStart(OwnOp::OWNOP_START_NORMAL);
-      l2->addElement(funpro);
-      funpro=NULL;
-      if((flag1&64)==64) {
-        funpro=new ReloadOp();
-        ((ReloadOp*)funpro)->setReloadside(ReloadOp::RELOADOP_THISSIDE);
-        l2->addElement(funpro);
-        funpro=NULL;
-      }
-      if((flag1&128)==128) {
-        funpro=new ReloadOp();
-        ((ReloadOp*)funpro)->setReloadside(ReloadOp::RELOADOP_OTHERSIDE);
-        l2->addElement(funpro);
-        funpro=NULL;
-      }
-      break;
-    case QUIT:
-      funpro=new QuitOp();
-      if(flag1!=0) ((QuitOp*)funpro)->setMode(QuitOp::Q_QUICK_QUIT);
-      break;
-    case COPY:
-      funpro=new CopyOp();
-      ((CopyOp*)funpro)->setMove(false);
-      if((flag1&1)==1) ((CopyOp*)funpro)->setFollowSymlinks(true);
-      else ((CopyOp*)funpro)->setFollowSymlinks(false);
-      if((flag1&2)==2) ((CopyOp*)funpro)->setOverwrite(CopyOp::COPYOP_OVERWRITE_ALWAYS);
-      else if((flag1&4)==4) ((CopyOp*)funpro)->setOverwrite(CopyOp::COPYOP_OVERWRITE_NEVER);
-      else ((CopyOp*)funpro)->setOverwrite(CopyOp::COPYOP_OVERWRITE_NORMAL);
-      if((flag1&8)==8) ((CopyOp*)funpro)->setRename(true);
-      else ((CopyOp*)funpro)->setRename(false);
-      if((flag1&16)==16) ((CopyOp*)funpro)->setSameDir(true);
-      else ((CopyOp*)funpro)->setSameDir(false);
-      if((flag1&32)==32) ((CopyOp*)funpro)->setRequestDest(true);
-      else ((CopyOp*)funpro)->setRequestDest(false);
-      if((flag1&64)==64) ((CopyOp*)funpro)->setRequestFlags(true);
-      else ((CopyOp*)funpro)->setRequestFlags(false);
-      break;
-    case MOVE:
-      funpro=new CopyOp();
-      ((CopyOp*)funpro)->setMove(true);
-      if((flag1&1)==1) ((CopyOp*)funpro)->setOverwrite(CopyOp::COPYOP_OVERWRITE_ALWAYS);
-      else if((flag1&2)==2) ((CopyOp*)funpro)->setOverwrite(CopyOp::COPYOP_OVERWRITE_NEVER);
-      else ((CopyOp*)funpro)->setOverwrite(CopyOp::COPYOP_OVERWRITE_NORMAL);
-      if((flag1&4)==4) ((CopyOp*)funpro)->setRename(true);
-      else ((CopyOp*)funpro)->setRename(false);
-      if((flag1&8)==8) ((CopyOp*)funpro)->setRequestFlags(true);
-      else ((CopyOp*)funpro)->setRequestFlags(false);
-      break;
-    case DELETE:
-      funpro=new DeleteOp();
-      break;
-    case MAKEDIR:
-      funpro=new MakeDirOp();
-      break;
-    case RENAME:
-      funpro=new RenameOp();
-      break;
-    case SELECTALL:
-      funpro=new SelectAllOp();
-      break;
-    case SELECTNONE:
-      funpro=new SelectNoneOp();
-      break;
-    case INVERT:
-      funpro=new InvertAllOp();
-      break;
-    case RELOAD:
-      funpro=new ReloadOp();
-      break;
-    case PREVITEM:
-      funpro=new RowUp();
-      break;
-    case NEXTITEM:
-      funpro=new RowDown();
-      break;
-    case PARENT:
-      funpro=new ParentDirOp();
-      break;
-    case GODIR:
-      funpro=new EnterDirOp();
-      break;
-    case FIRSTITEM:
-      funpro=new FirstRow();
-      break;
-    case LASTITEM:
-      funpro=new LastRow();
-      break;
-    case PAGEUP:
-      funpro=new PageUp();
-      break;
-    case PAGEDOWN:
-      funpro=new PageDown();
-      break;
-    case SELECT:
-      funpro=new SelectOp();
-      break;
-    case MAIN_FUNC:
-      funpro=new SimDDOp();
-      break;
-    case RUNPROGRAM:
-      funpro=new StartProgOp();
-      if((flag1&1)==1) ((StartProgOp*)funpro)->setStart(StartProgOp::STARTPROGOP_START_IN_TERMINAL);
-      else if((flag1&2)==2) ((StartProgOp*)funpro)->setStart(StartProgOp::STARTPROGOP_START_IN_TERMINAL_AND_WAIT4KEY);
-      else if((flag1&4)==4) ((StartProgOp*)funpro)->setStart(StartProgOp::STARTPROGOP_SHOW_OUTPUT);
-      else ((StartProgOp*)funpro)->setStart(StartProgOp::STARTPROGOP_START_NORMAL);
-      if((flag1&8)==8) ((StartProgOp*)funpro)->setGlobal(true);
-      else ((StartProgOp*)funpro)->setGlobal(false);
-      if((flag1&16)==16) ((StartProgOp*)funpro)->setRequestFlags(true);
-      else ((StartProgOp*)funpro)->setRequestFlags(false);
-      break;
-    case LISTEROPTIONS:
-      funpro=new ChangeListerSetOp();
-      if((flag1&1)==1) ((ChangeListerSetOp*)funpro)->setMode(ChangeListerSetOp::CLS_LEFT_LISTER);
-      else if((flag1&2)==2) ((ChangeListerSetOp*)funpro)->setMode(ChangeListerSetOp::CLS_RIGHT_LISTER);
-      else ((ChangeListerSetOp*)funpro)->setMode(ChangeListerSetOp::CLS_CURRENT_LISTER);
-      break;
-    case LISTERSCROLLLEFT:
-      funpro=new ScrollListerOp();
-      ((ScrollListerOp*)funpro)->setDir(ScrollListerOp::SCROLLLISTEROP_LEFT);
-      break;
-    case LISTERSCROLLRIGHT:
-      funpro=new ScrollListerOp();
-      ((ScrollListerOp*)funpro)->setDir(ScrollListerOp::SCROLLLISTEROP_RIGHT);
-      break;
-    case FILTERSELECT:
-      funpro=new FilterSelectOp();
-      break;
-    case DIRSIZE:
-      funpro=new DirSizeOp();
-      break;
-    case CREATESYMLINK:
-      funpro=new CreateSymlinkOp();
-      if((flag1&1)==1) ((CreateSymlinkOp*)funpro)->setSameDir(true);
-      else ((CreateSymlinkOp*)funpro)->setSameDir(false);
-      if((flag1&2)==2) ((CreateSymlinkOp*)funpro)->setLocal(true);
-      else ((CreateSymlinkOp*)funpro)->setLocal(false);
-      if((flag1&4)==4) ((CreateSymlinkOp*)funpro)->setRequestFlags(true);
-      else ((CreateSymlinkOp*)funpro)->setRequestFlags(false);
-      break;
-    case CHANGESYMLINK:
-      funpro=new ChangeSymlinkOp();
-      break;
-    case CHANGEMOD:
-      funpro=new ChModOp();
-      if((flag1&1)==1) ((ChModOp*)funpro)->setOnFiles(true);
-      else ((ChModOp*)funpro)->setOnFiles(false);
-      if((flag1&2)==2) ((ChModOp*)funpro)->setOnDirs(true);
-      else ((ChModOp*)funpro)->setOnDirs(false);
-      if((flag1&4)==4) ((ChModOp*)funpro)->setRecursive(true);
-      else ((ChModOp*)funpro)->setRecursive(false);
-      if((flag1&8)==8) ((ChModOp*)funpro)->setRequestFlags(true);
-      else ((ChModOp*)funpro)->setRequestFlags(false);
-      break;
-    case TOGGLEINFOMODE:
-      funpro=new ToggleListermodeOp();
-      ((ToggleListermodeOp*)funpro)->setMode(2);
-      break;
-    case SEARCHENTRY:
-      funpro=new SearchEntryOp();
-      break;
-    case PATH2OTHERLISTER:
-      funpro=new Path2OSideOp();
-      break;
-    case ENTERPATH:
-      funpro=new EnterPathOp();
-      if((flag1&1)==1) ((EnterPathOp*)funpro)->setSide(EnterPathOp::ENTERPATHOP_OTHERSIDE);
-      else if((flag1&2)==2) ((EnterPathOp*)funpro)->setSide(EnterPathOp::ENTERPATHOP_LEFTSIDE);
-      else if((flag1&4)==4) ((EnterPathOp*)funpro)->setSide(EnterPathOp::ENTERPATHOP_RIGHTSIDE);
-      else ((EnterPathOp*)funpro)->setSide(EnterPathOp::ENTERPATHOP_THISSIDE);
-      break;
-  }
-  if(funpro!=NULL) l2->addElement(funpro);
-}
-
-void WConfig::changeRS(const char *old,char **newstr)
-{
-  char *tstr=dupstring(old),ch;
-  int mode=0,pos=0;
-  for(;;) {
-    ch=tstr[pos];
-    if(ch==0) break;
-    switch(mode) {
-      case 1:
-        if(ch=='R') mode=2;
-        else mode=0;
-        break;
-      case 2:
-        if(ch=='s') mode=3;
-        else mode=0;
-        break;
-      case 3:
-        if(ch=='<') tstr[pos]='{';
-        else if(ch=='>') tstr[pos]='}';
-        else if(ch=='}') mode=0;
-        break;
-      default:
-        if(ch=='{') mode=1;
-        break;
-    }
-    pos++;
-  }
-  *newstr=tstr;
-}
-
 bool WConfig::loadBinConfig( const char *file )
 {
   int id;
@@ -1883,7 +1236,9 @@ bool WConfig::loadBinConfig( const char *file )
           }
         } else {
           // Keine 2er-Version
-          read1Config(fh);
+	  req = new Requester( worker->getAGUIX() );
+	  req->request( catalog.getLocale( 125 ), catalog.getLocale( 665 ), catalog.getLocale( 11 ) );
+	  delete req;
         }
       } else {
         // kein Config-file
@@ -1946,7 +1301,7 @@ int WConfig::loadBinPath( Datei *fh, WCPath *p1 )
   List *tdkeys;
   int id;
   char *str;
-  WCShortkey *key;
+  WCDoubleShortkey *key;
 
   if ( ( fh == NULL ) || ( p1 == NULL ) ) return 1;
 
@@ -2005,12 +1360,12 @@ int WConfig::loadBinPath( Datei *fh, WCPath *p1 )
       chunksize--;
     }
     // Hier sollte das Shortkey folgen, aber die Load-Funktion prueft das schon :-)
-    key = new WCShortkey();
+    key = new WCDoubleShortkey();
     loadBinShortkey( fh, key );
     if ( key->isReal() == true ) {
       // real key but it's not used anymore so convert into doubleshortkey
-      if ( p1->hasKey( key->getShortkey(), key->getMod() ) == false ) {
-        p1->addKey ( key->getShortkey(), key->getMod() );
+      if ( p1->hasKey( key->getKeySym( 0 ), key->getMod( 0 ) ) == false ) {
+        p1->addKey( key->getKeySym( 0 ), key->getMod( 0 ) );
       }
     }
     delete key;
@@ -2018,7 +1373,7 @@ int WConfig::loadBinPath( Datei *fh, WCPath *p1 )
   return 0;
 }
 
-int WConfig::loadBinShortkey( Datei *fh, WCShortkey *key )
+int WConfig::loadBinShortkey( Datei *fh, WCDoubleShortkey *key )
 {
   if ( ( fh == NULL ) || ( key == NULL ) ) return 1;
   char *str = fh->getString( 4 );
@@ -2029,9 +1384,10 @@ int WConfig::loadBinShortkey( Datei *fh, WCShortkey *key )
   } else {
     unsigned long chunksize = fh->getULong();
     if ( chunksize >= 9 ) {
-      key->setShortkey( fh->getULong() );
+      key->setType( WCDoubleShortkey::WCDS_NORMAL );
+      key->setKeySym( fh->getULong(), 0 );
       chunksize -= 4;
-      key->setMod( fh->getInt() );
+      key->setMod( fh->getInt(), 0 );
       chunksize -= 5;
     }
     while ( chunksize > 0 ) {
@@ -2356,13 +1712,13 @@ int WConfig::loadBinHotkey( Datei *fh, WCHotkey *h1 )
       fh->getUChar();
       chunksize--;
     }
-    WCShortkey *key;
-    key = new WCShortkey();
+    WCDoubleShortkey *key;
+    key = new WCDoubleShortkey();
     loadBinShortkey( fh, key );
     if ( key->isReal() == true ) {
       // real key but it's not used anymore so convert into doubleshortkey
-      if ( h1->hasKey( key->getShortkey(), key->getMod() ) == false ) {
-        h1->addKey( key->getShortkey(), key->getMod() );
+      if ( h1->hasKey( key->getKeySym( 0 ), key->getMod( 0 ) ) == false ) {
+        h1->addKey( key->getKeySym( 0 ), key->getMod( 0 ) );
       }
     }
     delete key;
@@ -2449,13 +1805,13 @@ int WConfig::loadBinButton( Datei *fh, WCButton *b1 )
       chunksize--;
     }
     
-    WCShortkey *key;
-    key = new WCShortkey();
+    WCDoubleShortkey *key;
+    key = new WCDoubleShortkey();
     loadBinShortkey( fh, key );
     if ( key->isReal() == true ) {
       // real key but it's not used anymore so convert into doubleshortkey
-      if ( b1->hasKey( key->getShortkey(), key->getMod() ) == false ) {
-        b1->addKey( key->getShortkey(), key->getMod() );
+      if ( b1->hasKey( key->getKeySym( 0 ), key->getMod( 0 ) ) == false ) {
+        b1->addKey( key->getKeySym( 0 ), key->getMod( 0 ) );
       }
     }
     delete key;
