@@ -1,6 +1,6 @@
 /* intviewop.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2005 Ralf Hoffmann.
+ * Copyright (C) 2005-2006 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: intviewop.cc,v 1.3 2005/10/19 18:04:08 ralf Exp $ */
 
 #include "intviewop.h"
 #include "listermode.h"
@@ -27,8 +26,7 @@
 #include "ownop.h"
 #include "wpucontext.h"
 #include "execlass.h"
-#include <aguix/textview.h>
-#include "textstoragefile.h"
+#include "fileviewer.hh"
 
 const char *InternalViewOp::name = "InternalViewOp";
 
@@ -147,7 +145,7 @@ InternalViewOp::run( WPUContext *wpu, ActionMessage *msg )
 
     if ( filelist.size() > 0 ) {
       msg->getWorker()->setWaitCursor();
-      view( filelist );
+      FileViewer::view( filelist );
       msg->getWorker()->unsetWaitCursor();
     }
   }
@@ -158,17 +156,17 @@ bool
 InternalViewOp::save(Datei *fh)
 {
   if ( fh == NULL ) return false;
-  WConfig::configPutPairBool( fh, "requestflags", _request_flags );
-  WConfig::configPutPairString( fh, "customfiles", _custom_files.c_str() );
+  fh->configPutPairBool( "requestflags", _request_flags );
+  fh->configPutPairString( "customfiles", _custom_files.c_str() );
   switch ( _mode ) {
     /*case SHOW_SELECTED_FILE:
-      WConfig::configPutPair( fh, "showmode", "selected" );
+      fh->configPutPair( "showmode", "selected" );
       break;*/
     case SHOW_CUSTOM_FILES:
-      WConfig::configPutPair( fh, "showmode", "custom" );
+      fh->configPutPair( "showmode", "custom" );
       break;
     default:
-      WConfig::configPutPair( fh, "showmode", "active" );
+      fh->configPutPair( "showmode", "active" );
       break;
   }
   return true;
@@ -341,7 +339,7 @@ InternalViewOp::doconfigure(int mode)
 	  _tmode = SHOW_ACTIVE_FILE;
 	  break;
       }
-      if ( rfcb != NULL ) _request_flags = ( rfcb->getState() == 1 ) ? true : false;
+      if ( rfcb != NULL ) _request_flags = rfcb->getState();
       setCustomFiles( sgcf->getText() );
     }
   }
@@ -364,165 +362,3 @@ void InternalViewOp::setCustomFiles( std::string nv )
 {
   _custom_files = nv;
 }
-
-void InternalViewOp::view( std::list<std::string> &filelist ) const
-{
-  AGUIX *aguix = Worker::getAGUIX();
-  Button *okb;
-  const int cfix = AContainer::ACONT_MINH +
-                   AContainer::ACONT_MINW +
-                   AContainer::ACONT_MAXH +
-                   AContainer::ACONT_MAXW;
-  const int cincw = AContainer::ACONT_MINH +
-                    AContainer::ACONT_MINW +
-                    AContainer::ACONT_MAXH;
-  const int cincwnr = cincw +
-                      AContainer::ACONT_NORESIZE;
-  TextStorageFile *ts = NULL;
-  TextView *tv = NULL;
-  std::list<std::string>::iterator it1;
-  int w, h, sw, sh;
-  static bool last_wrap_mode = false;
-
-  AWindow *win = new AWindow( aguix, 10, 10, 10, 10, 0, catalog.getLocaleCom( 49 ) );
-  win->create();
-  /*  if ( aguix->getTransientWindow() != NULL ) {
-    win->setTransientForAWindow( aguix->getTransientWindow() );
-    }*/
-
-  AContainer *ac1 = win->setContainer( new AContainer( win, 1, 3 ), true );
-  ac1->setMinSpace( 5 );
-  ac1->setMaxSpace( 5 );
-
-  AContainer *ac1_1 = ac1->add( new AContainer( win, 2, 1 ), 0, 0 );
-  ac1_1->setMinSpace( 5 );
-  ac1_1->setMaxSpace( 5 );
-  ac1_1->setBorderWidth( 0 );
-  ac1_1->add( new Text( aguix, 0, 0, catalog.getLocale( 404 ), 1 ), 0, 0, cfix );
-  Text *fnt = (Text*)ac1_1->add( new Text( aguix, 0, 0, "", 1 ), 1, 0, cincwnr );
-
-  it1 = filelist.begin();
-  
-  AFontWidth lencalc( aguix, NULL );
-
-  buildTextView( *it1, &ts, &tv, ac1, fnt, lencalc );
-  ac1->readLimits();
-  ac1_1->readLimits();
-
-  AContainer *ac1_3 = ac1->add( new AContainer( win, 2, 1 ), 0, 2 );
-  ac1_3->setMinSpace( 5 );
-  ac1_3->setMaxSpace( -1 );
-  ac1_3->setBorderWidth( 0 );
-  
-  /*nextb = (Button*)ac1_3->add( new Button( aguix, 0, 0, "Next", 1, 0, 2 ),
-    0, 0, cfix );
-    prevb = (Button*)ac1_3->add( new Button( aguix, 0, 0, "Prev", 1, 0, 2 ),
-    1, 0, cfix );*/
-  ChooseButton *wcb = (ChooseButton*)ac1_3->add( new ChooseButton( aguix, 0, 0,
-								 last_wrap_mode, catalog.getLocale( 637 ),
-								 LABEL_RIGHT, 1, 0 ),
-					       0, 0, cincwnr );
-  okb = (Button*)ac1_3->add( new Button( aguix, 0, 0, catalog.getLocale( 633 ), 1, 0, 2 ),
-			     1, 0, cfix );
-
-  win->setDoTabCycling( true );
-  win->contMaximize( true );
-  
-  w = win->getWidth();
-  h = win->getHeight();
-
-  sw = aguix->getRootWindowWidth();
-  sh = aguix->getRootWindowHeight();
-  sw = (int)( (double)sw * 0.8 );
-  sh = (int)( (double)sh * 0.8 );
-  if ( sw < 200 ) sw = 200;
-  if ( sh < 100 ) sh = 100;
-  if ( w < sw ) w = sw;
-  if ( h < sh ) h = sh;
-  win->resize( w, h );
-
-  tv->setLineWrap( wcb->getState() );
-
-  win->useStippleBackground();
-  win->centerScreen();
-  win->show();
-
-  win->applyFocus( tv );
-
-  AGMessage *msg;
-  int endmode = -1;
-  for( ; endmode == -1; ) {
-    msg = aguix->WaitMessage( win );
-    if ( msg != NULL ) {
-      switch ( msg->type ) {
-        case AG_CLOSEWINDOW:
-          if ( msg->closewindow.window == win->getWindow() ) {
-	    endmode = 0;
-	  }
-          break;
-	case AG_CHOOSECLICKED:
-	  if ( msg->choose.button == wcb ) {
-	    tv->setLineWrap( msg->choose.state );
-	  }
-	  break;
-        case AG_BUTTONCLICKED:
-	  if ( msg->button.button == okb ) {
-	    endmode = 0;
-	    /*	  } else if ( msg->button.button == nextb ) {
-		  it1++;
-		  if ( it1 == filelist.end() ) it1 = filelist.begin();
-		  buildTextView( *it1, &ts, &tv, ac1 );
-		  } else if ( msg->button.button == prevb ) {
-		  if ( it1 == filelist.begin() )
-		  it1 = filelist.end();
-		  it1--;
-		  buildTextView( *it1, &ts, &tv, ac1 );*/
-	  }
-          break;
-	case AG_KEYPRESSED:
-	  if ( win->isParent( msg->key.window, false ) == true ) {
-	    wcb->setState( tv->getLineWrap() );
-	    switch(msg->key.key) {
-	      case XK_q:
-	      case XK_Escape:
-	      case XK_F3:
-	      case XK_F10:
-	        endmode = 0;
-	        break;
-	    }
-	  }
-	  break;
-      }
-      aguix->ReplyMessage( msg );
-    }
-  }
-
-  last_wrap_mode = tv->getLineWrap();
-
-  delete win;
-  if ( ts != NULL ) delete ts;
-}
-
-void InternalViewOp::buildTextView( std::string &filename,
-				    TextStorageFile **ts,
-				    TextView **tv,
-				    AContainer *ac1,
-				    class Text *fnt,
-				    AWidth &lencalc ) const
-{
-  AGUIX *aguix = Worker::getAGUIX();
-  const int cmin = AContainer::ACONT_MINH +
-                   AContainer::ACONT_MINW;
-  
-  if ( ts == NULL || tv == NULL || ac1 == NULL ) return;
-  
-  delete *tv;
-  *ts = new TextStorageFile( filename, lencalc );
-  *tv = new TextView( aguix, 0, 0, 100, 100, 0, "", **ts );
-  (*tv)->setDisplayFocus( true );
-  ac1->add( *tv, 0, 1, cmin );
-  (*tv)->create();
-  if ( fnt != NULL ) fnt->setText( filename.c_str() );
-  ac1->rearrange();
-  (*tv)->show();
-}
