@@ -1,6 +1,6 @@
 /* intviewop.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2005 Ralf Hoffmann.
+ * Copyright (C) 2005-2006 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: intviewop.h,v 1.2 2005/08/17 06:29:59 ralf Exp $ */
 
 #ifndef INTVIEWOP_H
 #define INTVIEWOP_H
@@ -58,13 +57,6 @@ public:
 
   static const char *name;
 protected:
-  void view( std::list<std::string> &filelist ) const;
-  void buildTextView( std::string &filename,
-		      class TextStorageFile **ts,
-		      class TextView **tv,
-		      class AContainer *ac1,
-		      class Text *fnt,
-		      class AWidth &lencalc ) const;
   // Infos to save
 
   show_file_mode_t _mode;
