@@ -1,6 +1,6 @@
 /* normalmode.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2005 Ralf Hoffmann.
+ * Copyright (C) 2001-2006 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: normalmode.h,v 1.111 2005/11/28 22:03:45 ralf Exp $ */
 
 #ifndef NORMALMODE_H
 #define NORMALMODE_H
@@ -37,109 +36,17 @@
 #include "deleteop.h"
 #include "condparser.h"
 #include <map>
-
-#ifdef WANT_THREADS
+#include "nmfilter.hh"
+#include "nmcacheentry.hh"
+#include "nmcopyopdir.hh"
+#include "nmextlist.hh"
+#include "nmspecialsourceext.hh"
 #include <aguix/mutex.h>
 #include <aguix/condvar.h>
-#endif
 
 class Lister;
 class NMFieldListViewDND;
-
-class NM_Filter {
-public:
-  NM_Filter();
-  ~NM_Filter();
-  NM_Filter( const NM_Filter &other );
-  NM_Filter &operator=( const NM_Filter &other );
-
-  void setPattern(const char*);
-  char *getPattern();
-  void setCheck(int);
-  int getCheck();
-  int load();
-  int loadBin(Datei*);
-  int save(Datei*);
-  NM_Filter *duplicate();
-private:
-  char *pattern;
-  int check;
-};
-
-class NMCacheEntry {
-public:
-  NMCacheEntry();
-  ~NMCacheEntry();
-  NMCacheEntry( const NMCacheEntry &other );
-  NMCacheEntry &operator=( const NMCacheEntry &other );
-
-  void recalcStats();
-  void subentry(FileEntry *fe);
-  void next_checkfe();
-  void restartcheck();
-  void reset_checkfe();
-  void checkfordcd();
-  void reset_dirsizes();
-  void reset_firstnullft();
-  void next_firstnullft();
-//protected:  // Vorerst public
-  Verzeichnis *verz;
-  FileEntry *activefe;
-  int pos,xpos;
-  long files[2];
-  loff_t files_s[2];  // Jeweils Insgesamt und selektiert, Bytes gesamt, Bytes
-                  // selektiert
-  long dirs[2];
-  loff_t dirs_s[2];
-  FileEntry *checkfe;
-  FileEntry *lastfe;  // when this is recognized update the whole listview
-  
-  int actsortmode;
-  int actshowhidden;
-  int actfilterlfdnr;
-  bool dontcheck;
-  FileEntry *firstnullft;
-};
-
-class NM_CopyOp_Dir
-{
-public:
-  NM_CopyOp_Dir(const FileEntry *fe);
-  ~NM_CopyOp_Dir();
-  NM_CopyOp_Dir( const NM_CopyOp_Dir &other );
-  NM_CopyOp_Dir &operator=( const NM_CopyOp_Dir &other );
-
-  int createSubDirs(struct NM_copyorder*copyorder,unsigned long *gf,unsigned long *gd);
-  int createSubDirs(struct NM_deleteorder*delorder,unsigned long *gf,unsigned long *gd);
-  int createSubDirs();
-  
-  List *subdirs; // contains elements of this class
-  Verzeichnis *verz;
-  const FileEntry *fileentry;
-  unsigned long files,dirs;
-  loff_t bytes;
-  bool ok; // only use this dir if ok==true
-  bool user_abort; // true when user selected cancel from one of
-                   // the requesters used inside
-  
-  unsigned long error_counter; // files/dirs not finished (recursive)
-};
-
-/*
- * NM_specialsourceExt always stores a duplicate FE
- */
-class NM_specialsourceExt {
- public:
-  NM_specialsourceExt( const FileEntry *tfe );
-  ~NM_specialsourceExt();
-  const FileEntry *entry() const
-  {
-    return fe;
-  }
-  int row;  // corresponding row or -1
- private:
-  FileEntry *fe;  // element to copy
-};
+class CopyOpWin;
 
 struct NM_copyorder {
   char *destdir;
@@ -165,7 +72,7 @@ struct NM_copyorder {
 struct NM_deleteorder {
   enum {NM_ALLENTRIES,NM_ONLYACTIVE,NM_SPECIAL,NM_ONLYSELECTED} source;
   std::list<NM_specialsourceExt*> *sources;
-  enum {NM_DELMODE_NORMAL,NM_DELMODE_NODATABASE} delmode;
+  enum {NM_DELMODE_NORMAL} delmode;
   enum {NM_DIRDELETE_NORMAL,NM_DIRDELETE_ALL,NM_DIRDELETE_NONE} dirdel;
   DeleteOpWin *dowin;
 
@@ -235,52 +142,6 @@ struct NM_changesymlinkorder {
   std::list<NM_specialsourceExt*> *sources;
 };
 
-class NM_extern_fe {
-public:
-  NM_extern_fe(char *nfn);
-  NM_extern_fe( char *nfn, const FileEntry *fe, int row );
-  ~NM_extern_fe();
-  NM_extern_fe( const NM_extern_fe &other );
-  NM_extern_fe &operator=( const NM_extern_fe &other );
-
-  char *getFullname(bool noext);
-  char *getName(bool noext);
-  void setDirFinished(int);
-  int getDirFinished();
-  const FileEntry *getFE();
-  int getRow();
-protected:
-  char *fullname[2];
-  char *name[2];
-  FileEntry *fe;
-  int row;
-  int dirfinished;
-};
-
-class NMExtList
-{
-public:
-  NMExtList();
-  ~NMExtList();
-  NMExtList( const NMExtList &other );
-  NMExtList &operator=( const NMExtList &other );
-
-  int getSize();
-  int getRealSize();
-  void setTakeDirs( bool nv);
-  int initEnum();
-  void closeEnum( int );
-  NM_extern_fe *getFirstElement( int id );
-  NM_extern_fe *getNextElement( int id );
-  int removeElement( NM_extern_fe * );
-  void createExtList( class NormalMode *nm, bool rec );
-  void createExtList( class NormalMode *nm, ActionMessage *msg, bool rec );
-protected:
-  List *extlist;
-  int files, dirs;
-  bool take_dirs;
-};
-
 class NormalMode:public ListerMode
 {
 public:
@@ -308,6 +169,7 @@ public:
   static const char *getStaticType();
   
   int enterDir(const char *dirstr);
+  int enterPath( const std::string &fullname );
   void enterDirActive();
   void setActiveDir2Other();
   void up();
@@ -361,16 +223,11 @@ public:
   void unsetAllFilters();
   void setFilter(const char *filter,nm_filter_t mode);
 
-#ifdef WANT_THREADS
   void slavehandler();
-#endif
-  int createExtList( bool rec, List *extlist );
   static void freeExtList( List *extlist );
   char *parseComStrExt( const char *sstr,class NM_externorder *extorder,int maxlen, NMExtList *entries[2], bool quote);
   /* deselect for extern access, check for existance of fe => slow for big dirs */
   void deselect( const FileEntry *fe );
-  int createExtList( ActionMessage *amsg, bool rec, List *extlist );
-  static int getEntriesRealSize( List* );
   virtual void lvbDoubleClicked();
   
   int showCacheList();
@@ -419,6 +276,7 @@ public:
                          const gid_t wanted_group,
                          const mode_t wanted_mode,
                          struct NM_copyorder *copyorder );
+  NM_specialsourceExt *getSpecialsourceForFE( const FileEntry *searchfe );
 protected:
   /*
    * NM_specialsourceInt always stores a pointer to a FE
@@ -512,12 +370,6 @@ protected:
   int lastrow;
   void removeEntry(FileEntry *fe, int row,bool quick);
   void fixSpecialSourceList( const std::list<NM_specialsourceInt*> *l, int deleted_row );
-  int createExtList( std::list<NM_specialsourceExt*> *splist,bool rec,List *extlist) const;
-  int create_externfe_rec(List *extlist,
-                          char *fullname,
-                          bool rec,
-                          const FileEntry *fe,
-                          int row ) const;
   char *parseComStr( const char *sstr,class NM_externorder *extorder,int maxlen, NMExtList *entries[2], bool quote );
   void deselect( FileEntry *fe, int row );
   char *StringRequest(char *sstr,class NM_externorder *extorder,int maxlen, NMExtList *entries[2]);
@@ -583,7 +435,6 @@ protected:
   
   static int maxfilestrlen,maxdirstrlen,maxbytesstrlen,maxwbytesstrlen,maxnochanges;
   
-#ifdef WANT_THREADS
 public:   // why the h*** need the Sun compiler a public definition for a
           // protected struct?
   typedef enum { THREAD_NOP,
@@ -608,11 +459,6 @@ protected:
   int waitForNewOrder( void );
   int switchStatus( thread_order_t newstatus );
   int waitForStatus( thread_order_t waitstatus );
-  // true if thread creation was successful
-  // false otherwise and also when WANT_THREADS is not defined
-#endif
-  bool thread_usage;
-#ifdef WANT_THREADS
   
   // intern list (special fifo) for the tasks for the slave-thread
   // can contain up to size elements of prev type
@@ -735,10 +581,8 @@ protected:
   };
   
   checkFiletypeRes_t slave_checkFiletype( const char *fullname, bool dontCheckContent );
-#endif
   
   bool lasteagain;
-  bool finish_done;
   
   void setupLVFields();
 
@@ -759,8 +603,7 @@ protected:
   bool isColumnVisible( const WorkerTypes::listcol_t c );
   bool visChanged;
   int oldlvy;
-  FileEntry *findFileEntryForData( int data, int startpos );
-  NM_specialsourceExt *getSpecialsourceForFE( const FileEntry *searchfe );
+  FileEntry *findFileEntryForData( int data, int startpos = -1 );
   
   void showInvalidList( ArrayList *list, const char *descr );
   void changeSortModeForField( int field );
@@ -810,6 +653,8 @@ protected:
   int writeFieldWidthsToLoadMap();
 
   bool quicksearch_enabled;
+
+  void makeRowActive( int row );
 };
 
 class NMFieldListViewDND:public FieldListViewDND
