@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: normalops.cc,v 1.24 2005/10/19 18:03:49 ralf Exp $ */
+/* $Id: normalops.cc,v 1.25 2006/02/05 23:06:14 ralf Exp $ */
 
 #include "normalops.h"
 #include "listermode.h"
@@ -204,16 +204,16 @@ bool ChangeListerSetOp::save(Datei *fh)
   if ( fh == NULL ) return false;
   switch(mode) {
     case CLS_RIGHT_LISTER:
-      WConfig::configPutPair( fh, "mode", "right" );
+      fh->configPutPair( "mode", "right" );
       break;
     case CLS_CURRENT_LISTER:
-      WConfig::configPutPair( fh, "mode", "current" );
+      fh->configPutPair( "mode", "current" );
       break;
     case CLS_OTHER_LISTER:
-      WConfig::configPutPair( fh, "mode", "other" );
+      fh->configPutPair( "mode", "other" );
       break;
     default:
-      WConfig::configPutPair( fh, "mode", "left" );
+      fh->configPutPair( "mode", "left" );
       break;
   }
   return true;
@@ -450,7 +450,7 @@ int FilterSelectOp::configure()
 bool FilterSelectOp::save(Datei *fh)
 {
   if ( fh == NULL ) return false;
-  WConfig::configPutPairString( fh, "filter", filter );
+  fh->configPutPairString( "filter", filter );
   return true;
 }
 
@@ -897,7 +897,7 @@ bool FilterUnSelectOp::requestfilter()
   ac1->add( new Text( aguix, 0, 0, catalog.getLocale( 271 ), 1 ), 0, 0, cincwnr );
   ac1->add( new Text( aguix, 0, 0, catalog.getLocale( 272 ), 1 ), 0, 1, cincwnr );
 
-  AContainer *ac1_1 = ac1->add( new AContainer( win, 2, 1 ), 0, 2 );
+  AContainer *ac1_1 = ac1->add( new AContainer( win, 1, 2 ), 0, 2 );
   ac1_1->setMinSpace( 0 );
   ac1_1->setMaxSpace( 0 );
   ac1_1->setBorderWidth( 0 );
@@ -1252,10 +1252,10 @@ bool QuitOp::save(Datei *fh)
   if ( fh == NULL ) return false;
   switch(mode) {
     case Q_QUICK_QUIT:
-      WConfig::configPutPair( fh, "mode", "quick" );
+      fh->configPutPair( "mode", "quick" );
       break;
     default:
-      WConfig::configPutPair( fh, "mode", "normal" );
+      fh->configPutPair( "mode", "normal" );
       break;
   }
   return true;
