@@ -105,28 +105,28 @@ OwnOp::save(Datei *fh)
 {
   if ( fh == NULL ) return false;
 
-  WConfig::configPutPairBool( fh, "separateeachentry", separate_each_entry );
-  WConfig::configPutPairBool( fh, "recursive", recursive );
+  fh->configPutPairBool( "separateeachentry", separate_each_entry );
+  fh->configPutPairBool( "recursive", recursive );
   switch ( ownstart ) {
     case OWNOP_START_IN_TERMINAL:
-      WConfig::configPutPair( fh, "start", "terminal" );
+      fh->configPutPair( "start", "terminal" );
       break;
     case OWNOP_START_IN_TERMINAL_AND_WAIT4KEY:
-      WConfig::configPutPair( fh, "start", "terminalwait" );
+      fh->configPutPair( "start", "terminalwait" );
       break;
     case OWNOP_SHOW_OUTPUT:
-      WConfig::configPutPair( fh, "start", "showoutput" );
+      fh->configPutPair( "start", "showoutput" );
       break;
     default:
-      WConfig::configPutPair( fh, "start", "normal" );
+      fh->configPutPair( "start", "normal" );
       break;
   }
-  WConfig::configPutPairString( fh, "com", com_str );
-  WConfig::configPutPairString( fh, "viewstr", view_str );
+  fh->configPutPairString( "com", com_str );
+  fh->configPutPairString( "viewstr", view_str );
   
-  WConfig::configPutPairBool( fh, "inbackground", inbackground );
-  WConfig::configPutPairBool( fh, "takedirs", take_dirs );
-  WConfig::configPutPairBool( fh, "dontcd", dontcd );
+  fh->configPutPairBool( "inbackground", inbackground );
+  fh->configPutPairBool( "takedirs", take_dirs );
+  fh->configPutPairBool( "dontcd", dontcd );
   return true;
 }
 
@@ -472,11 +472,11 @@ OwnOp::configure()
   
   if(endmode==0) {
     // ok
-    separate_each_entry=(scb->getState()==1)?true:false;
-    recursive=(rcb->getState()==1)?true:false;
-    take_dirs = ( tdcb->getState() == 1 ) ? true : false;
-    dontcd = ( dcdcb->getState() == 1 ) ? true : false;
-    inbackground = ( ibcb->getState() == 1 ) ? true : false;
+    separate_each_entry = scb->getState();
+    recursive = rcb->getState();
+    take_dirs = tdcb->getState();
+    dontcd = dcdcb->getState();
+    inbackground = ibcb->getState();
     _freesafe(com_str);
     _freesafe(view_str);
     com_str=dupstring(sg[0]->getText());
