@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: ownop.h,v 1.21 2005/05/19 19:53:18 ralf Exp $ */
+/* $Id: ownop.h,v 1.22 2005/10/19 18:03:26 ralf Exp $ */
 
 #ifndef OWNOP_H
 #define OWNOP_H
@@ -135,7 +135,7 @@ protected:
   Lister *startlister,*endlister;
   class WPUContext *use_wpu;
   
-  int normalmodeown();
+  int normalmodeown( ActionMessage *am );
 };
 
 #endif
