@@ -1,6 +1,6 @@
 /* partspace.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2005 Ralf Hoffmann.
+ * Copyright (C) 2001-2006 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: partspace.h,v 1.13 2005/01/11 23:21:18 ralf Exp $ */
 
 #ifndef PARTSPACE_H
 #define PARTSPACE_H
@@ -26,11 +25,8 @@
 #include "wdefines.h"
 #include <aguix/lowlevelfunc.h>
 #include <aguix/util.h>
-
-#ifdef WANT_THREADS  
 #include <aguix/mutex.h>
 #include <aguix/condvar.h>
-#endif
 
 class PartSpace
 {
@@ -49,9 +45,7 @@ public:
   loff_t getFreeSpaceH(char **unit_return);
   loff_t getSpaceH(char **unit_return);
 
-#ifdef WANT_THREADS  
   void slavehandler();
-#endif
   
   void setLifetime( double t );
 protected:
@@ -62,7 +56,6 @@ protected:
   double info_lifetime;
   int spaceinfo_maxsize;
   
-#ifdef WANT_THREADS  
   struct {
     int running;
     bool stop;
@@ -70,10 +63,7 @@ protected:
     
     CondVar waitvar;
   } slave;
-#endif
-  bool thread_usage;
 
-#ifdef WANT_THREADS  
   class SpaceRequestList
   {
   public:
@@ -113,7 +103,6 @@ protected:
 
   SpaceRequestList *spacerequest;
   SpaceRequestList *spaceanswer;
-#endif
 
 #ifdef HAVE_STATVFS
   int getSpace( const char *name, worker_struct_statvfs *statbuf );
@@ -123,9 +112,7 @@ protected:
   int getSpace( const char *name, int *statbuf );
 #endif
 
-#ifdef WANT_THREADS  
   List *spaceinfo;
-#endif
 };
 
 #endif
