@@ -84,20 +84,20 @@ ReloadOp::save(Datei *fh)
   if ( fh == NULL ) return false;
   switch(reloadside) {
     case RELOADOP_OTHERSIDE:
-      WConfig::configPutPair( fh, "mode", "other" );
+      fh->configPutPair( "mode", "other" );
       break;
     case RELOADOP_LEFTSIDE:
-      WConfig::configPutPair( fh, "mode", "left" );
+      fh->configPutPair( "mode", "left" );
       break;
     case RELOADOP_RIGHTSIDE:
-      WConfig::configPutPair( fh, "mode", "right" );
+      fh->configPutPair( "mode", "right" );
       break;
     default:
-      WConfig::configPutPair( fh, "mode", "current" );
+      fh->configPutPair( "mode", "current" );
       break;
   }
-  WConfig::configPutPairBool( fh, "resetdirsizes", reset_dirsizes );
-  WConfig::configPutPairBool( fh, "keepfiletypes", keep_filetypes );
+  fh->configPutPairBool( "resetdirsizes", reset_dirsizes );
+  fh->configPutPairBool( "keepfiletypes", keep_filetypes );
   return true;
 }
 
@@ -274,8 +274,8 @@ ReloadOp::configure()
         reloadside=RELOADOP_THISSIDE;
         break;
     }
-    reset_dirsizes=(rdscb->getState()==1)?true:false;
-    keep_filetypes = ( kftcb->getState() == 1 ) ? true : false;
+    reset_dirsizes = rdscb->getState();
+    keep_filetypes = kftcb->getState();
   }
   
   delete win;
