@@ -1,6 +1,6 @@
 /* scriptop.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2002-2005 Ralf Hoffmann.
+ * Copyright (C) 2002-2006 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: scriptop.cc,v 1.19 2005/08/17 06:32:35 ralf Exp $ */
 
 #include "scriptop.h"
 #include "listermode.h"
@@ -105,8 +104,7 @@ int
 ScriptOp::run( WPUContext *wpu, ActionMessage *msg )
 {
   char *tstr, *tstr2, *tstr3;
-  ExeClass *ec;
-  int erg, l, exeerror;
+  int erg, l, exeerror = 1;
   
   switch ( type ) {
     case SCRIPT_PUSH:
@@ -118,11 +116,10 @@ ScriptOp::run( WPUContext *wpu, ActionMessage *msg )
         tstr = wpu->parse( push_string, a_max( EXE_STRING_LEN - 1024, 256 ), ( ( push_useoutput == true ) ? true : false ) );
         if ( tstr != NULL ) {
           if ( push_useoutput == true ) {
-            ec = new ExeClass( ExeClass::EXECUTE_NORMAL, msg->getWorker() );
+            std::auto_ptr<ExeClass> ec( new ExeClass( ExeClass::EXECUTE_NORMAL, msg->getWorker() ) );
             ec->cdDir( wpu->getBaseDir() );
             ec->addCommand( "%s", tstr );
             tstr2 = ec->getOutput( &exeerror );
-            delete ec;
             
             if ( exeerror == 0 ) {
               if ( tstr2 != NULL ) {
@@ -144,10 +141,21 @@ ScriptOp::run( WPUContext *wpu, ActionMessage *msg )
               if ( tstr2 != NULL ) _freesafe( tstr2 );
               if ( Worker::getRequester() != NULL ) {
                 char *reqstr;
-                reqstr = (char*)_allocsafe( strlen( catalog.getLocale( 480 ) ) + strlen( tstr ) + 1 );
-                sprintf( reqstr, catalog.getLocale( 480 ), tstr );
-                Worker::getRequester()->request( catalog.getLocale( 347 ), reqstr, catalog.getLocale( 11 ) );
+                std::string error, str1;
+                
+                reqstr = (char*)_allocsafe( strlen( catalog.getLocale( 750 ) ) + strlen( tstr ) + 1 );
+                sprintf( reqstr, catalog.getLocale( 750 ), tstr );
+                
+                ec->readErrorOutput( error, 1024 );
+                
+                str1 = reqstr;
+                str1 += error;
                 _freesafe( reqstr );
+
+                AFontWidth lencalc( Worker::getAGUIX(), NULL );
+                TextStorageString ts( str1, lencalc );
+
+                Worker::getRequester()->request( catalog.getLocale( 347 ), ts, catalog.getLocale( 11 ) );
               }
               wpu->continueAtLabel( NULL );
             }
@@ -248,11 +256,10 @@ ScriptOp::run( WPUContext *wpu, ActionMessage *msg )
           tstr = wpu->parse( progress, a_max( EXE_STRING_LEN - 1024, 256 ), ( ( progress_useoutput == true ) ? true : false ) );
           if ( tstr != NULL ) {
             if ( progress_useoutput == true ) {
-              ec = new ExeClass( ExeClass::EXECUTE_NORMAL );
+              std::auto_ptr<ExeClass> ec( new ExeClass( ExeClass::EXECUTE_NORMAL ) );
               ec->cdDir( wpu->getBaseDir() );
               ec->addCommand( "%s", tstr );
               tstr2 = ec->getOutput( &exeerror );
-              delete ec;
               
               if ( exeerror == 0 ) {
                 _freesafe( tstr );
@@ -265,10 +272,21 @@ ScriptOp::run( WPUContext *wpu, ActionMessage *msg )
                 if ( tstr2 != NULL ) _freesafe( tstr2 );
                 if ( Worker::getRequester() != NULL ) {
                   char *reqstr;
-                  reqstr = (char*)_allocsafe( strlen( catalog.getLocale( 504 ) ) + strlen( tstr ) + 1 );
-                  sprintf( reqstr, catalog.getLocale( 504 ), tstr );
-                  Worker::getRequester()->request( catalog.getLocale( 347 ), reqstr, catalog.getLocale( 11 ) );
+                  std::string error, str1;
+                  
+                  reqstr = (char*)_allocsafe( strlen( catalog.getLocale( 751 ) ) + strlen( tstr ) + 1 );
+                  sprintf( reqstr, catalog.getLocale( 751 ), tstr );
+                  
+                  ec->readErrorOutput( error, 1024 );
+                  
+                  str1 = reqstr;
+                  str1 += error;
                   _freesafe( reqstr );
+                  
+                  AFontWidth lencalc( Worker::getAGUIX(), NULL );
+                  TextStorageString ts( str1, lencalc );
+                  
+                  Worker::getRequester()->request( catalog.getLocale( 347 ), ts, catalog.getLocale( 11 ) );
                 }
                 _freesafe( tstr );
                 tstr = NULL;
@@ -288,11 +306,11 @@ ScriptOp::run( WPUContext *wpu, ActionMessage *msg )
           tstr = wpu->parse( wintext, a_max( EXE_STRING_LEN - 1024, 256 ), ( ( wintext_useoutput == true ) ? true : false ) );
           if ( tstr != NULL ) {
             if ( wintext_useoutput == true ) {
-              ec = new ExeClass( ExeClass::EXECUTE_NORMAL );
+              std::auto_ptr<ExeClass> ec( new ExeClass( ExeClass::EXECUTE_NORMAL ) );
               ec->cdDir( wpu->getBaseDir() );
               ec->addCommand( "%s", tstr );
               tstr2 = ec->getOutput( &exeerror );
-              delete ec;
+              
               if ( exeerror == 0 ) {
                 _freesafe( tstr );
                 if ( tstr2 != NULL ) {
@@ -304,10 +322,21 @@ ScriptOp::run( WPUContext *wpu, ActionMessage *msg )
                 if ( tstr2 != NULL ) _freesafe( tstr2 );
                 if ( Worker::getRequester() != NULL ) {
                   char *reqstr;
-                  reqstr = (char*)_allocsafe( strlen( catalog.getLocale( 504 ) ) + strlen( tstr ) + 1 );
-                  sprintf( reqstr, catalog.getLocale( 504 ), tstr );
-                  msg->getWorker()->getRequester()->request( catalog.getLocale( 347 ), reqstr, catalog.getLocale( 11 ) );
+                  std::string error, str1;
+                  
+                  reqstr = (char*)_allocsafe( strlen( catalog.getLocale( 751 ) ) + strlen( tstr ) + 1 );
+                  sprintf( reqstr, catalog.getLocale( 751 ), tstr );
+                  
+                  ec->readErrorOutput( error, 1024 );
+                  
+                  str1 = reqstr;
+                  str1 += error;
                   _freesafe( reqstr );
+                  
+                  AFontWidth lencalc( Worker::getAGUIX(), NULL );
+                  TextStorageString ts( str1, lencalc );
+                  
+                  Worker::getRequester()->request( catalog.getLocale( 347 ), ts, catalog.getLocale( 11 ) );
                 }
                 _freesafe( tstr );
                 tstr = NULL;
@@ -1095,12 +1124,12 @@ int ScriptOp::configure()
     switch ( lv->getActiveRow() ) {
       case 1:
         type = SCRIPT_PUSH;
-        if ( chb->getState() == 1 ) push_useoutput = true;
+        if ( chb->getState() == true ) push_useoutput = true;
         else push_useoutput = false;
         stack_nr = atoi( psnsg->getText() );
         if ( stack_nr < 0 ) stack_nr = 0;
         setPushString( pssg->getText() );
-        setDoDebug( ( pdcb->getState() == 1 ) ? true : false );
+        setDoDebug( pdcb->getState() );
         break;
       case 2:
         type = SCRIPT_POP;
@@ -1115,19 +1144,19 @@ int ScriptOp::configure()
         type = SCRIPT_IF;
         setIfTest( iftsg->getText() );
         setIfLabel( iflsg->getText() );
-        setDoDebug( ( idcb->getState() == 1 ) ? true : false );
+        setDoDebug( idcb->getState() );
         break;
       case 5:
         type = SCRIPT_END;
         break;
       case 6:
         type = SCRIPT_SETTINGS;
-        setWPURecursive( ( setrcb->getState() == 1 ) ? true : false );
-        setWPUTakeDirs( ( settdcb->getState() == 1 ) ? true : false );
+        setWPURecursive( setrcb->getState() );
+        setWPUTakeDirs( settdcb->getState() );
         break;
       case 7:
         type = SCRIPT_WINDOW;
-        if ( cwcb->getState() == 1 ) {
+        if ( cwcb->getState() == true ) {
           switch ( cwcycb->getSelectedOption() ) {
             case 1:
               setWinType( SCRIPT_WINDOW_CLOSE );
@@ -1139,17 +1168,17 @@ int ScriptOp::configure()
         } else {
           setWinType( SCRIPT_WINDOW_LEAVE );
         }
-        if ( cpcb->getState() == 1 ) {
+        if ( cpcb->getState() == true ) {
           setChangeProgress( true );
           setProgress( prosg->getText() );
-          setProgressUseOutput( ( prouocb->getState() == 1 ) ? true : false );
+          setProgressUseOutput( prouocb->getState() );
         } else {
           setChangeProgress( false );
         }
-        if ( cwtcb->getState() == 1 ) {
+        if ( cwtcb->getState() == true ) {
           setChangeText( true );
           setWinText( wintextsg->getText() );
-          setWinTextUseOutput( ( wintextuocb->getState() == 1 ) ? true : false );
+          setWinTextUseOutput( wintextuocb->getState() );
         } else {
           setChangeText( false );
         }
@@ -1173,71 +1202,71 @@ bool ScriptOp::save(Datei *fh)
   if ( fh == NULL ) return false;
   switch(type) {
     case SCRIPT_PUSH:
-      WConfig::configPutPair( fh, "type", "push" );
+      fh->configPutPair( "type", "push" );
       break;
     case SCRIPT_LABEL:
-      WConfig::configPutPair( fh, "type", "label" );
+      fh->configPutPair( "type", "label" );
       break;
     case SCRIPT_IF:
-      WConfig::configPutPair( fh, "type", "if" );
+      fh->configPutPair( "type", "if" );
       break;
     case SCRIPT_END:
-      WConfig::configPutPair( fh, "type", "end" );
+      fh->configPutPair( "type", "end" );
       break;
     case SCRIPT_POP:
-      WConfig::configPutPair( fh, "type", "pop" );
+      fh->configPutPair( "type", "pop" );
       break;
     case SCRIPT_SETTINGS:
-      WConfig::configPutPair( fh, "type", "settings" );
+      fh->configPutPair( "type", "settings" );
       break;
     case SCRIPT_WINDOW:
-      WConfig::configPutPair( fh, "type", "window" );
+      fh->configPutPair( "type", "window" );
       break;
     case SCRIPT_GOTO:
-      WConfig::configPutPair( fh, "type", "goto" );
+      fh->configPutPair( "type", "goto" );
       break;
     default:
-      WConfig::configPutPair( fh, "type", "nop" );
+      fh->configPutPair( "type", "nop" );
       break;
   }
-  WConfig::configPutPairBool( fh, "pushuseoutput", push_useoutput );
-  WConfig::configPutPairBool( fh, "dodebug", dodebug );
-  WConfig::configPutPairBool( fh, "wpurecursive", wpu_recursive );
-  WConfig::configPutPairBool( fh, "wputakedirs", wpu_take_dirs );
-  WConfig::configPutPairNum( fh, "stacknr", stack_nr );
+  fh->configPutPairBool( "pushuseoutput", push_useoutput );
+  fh->configPutPairBool( "dodebug", dodebug );
+  fh->configPutPairBool( "wpurecursive", wpu_recursive );
+  fh->configPutPairBool( "wputakedirs", wpu_take_dirs );
+  fh->configPutPairNum( "stacknr", stack_nr );
   if ( label != NULL ) {
-    WConfig::configPutPairString( fh, "label", label );
+    fh->configPutPairString( "label", label );
   }
   if ( push_string != NULL ) {
-    WConfig::configPutPairString( fh, "pushstring", push_string );
+    fh->configPutPairString( "pushstring", push_string );
   }
   if ( if_test != NULL ) {
-    WConfig::configPutPairString( fh, "iftest", if_test );
+    fh->configPutPairString( "iftest", if_test );
   }
   if ( if_label != NULL ) {
-    WConfig::configPutPairString( fh, "iflabel", if_label );
+    fh->configPutPairString( "iflabel", if_label );
   }
 
   switch ( wintype ) {
     case SCRIPT_WINDOW_OPEN:
-      WConfig::configPutPair( fh, "wintype", "open" );
+      fh->configPutPair( "wintype", "open" );
       break;
     case SCRIPT_WINDOW_CLOSE:
-      WConfig::configPutPair( fh, "wintype", "close" );
+      fh->configPutPair( "wintype", "close" );
       break;
     default:
-      WConfig::configPutPair( fh, "wintype", "leave" );
+      fh->configPutPair( "wintype", "leave" );
       break;
   }
-  WConfig::configPutPairBool( fh, "changeprogress", change_progress );
-  WConfig::configPutPairBool( fh, "changetext", change_text );
-  WConfig::configPutPairBool( fh, "progressuseoutput", progress_useoutput );
-  WConfig::configPutPairBool( fh, "wintextuseoutput", wintext_useoutput );
+  fh->configPutPairBool( "changeprogress", change_progress );
+  fh->configPutPairBool( "changetext", change_text );
+  fh->configPutPairBool( "progressuseoutput", progress_useoutput );
+  fh->configPutPairBool( "wintextuseoutput", wintext_useoutput );
   if ( progress != NULL ) {
-    WConfig::configPutPairString( fh, "progress", progress );
+    fh->configPutPairString( "progress", progress );
   }
   if ( wintext != NULL ) {
-    WConfig::configPutPairString( fh, "wintext", wintext );
+    fh->configPutPairString( "wintext", wintext );
   }
 
   return true;
@@ -1257,32 +1286,30 @@ char *ScriptOp::getPushFlag()
 char *ScriptOp::getIfFlag()
 {
   AGUIX *aguix = Worker::getAGUIX();
-  Button *okb,*cb;
   AWindow *win;
   FieldListView *lv;
-  int w,h,x,y;
   AGMessage *msg;
   int endmode=-1;
   char *returnstr;
-  Button *b2[2];
   int i, trow, nr, nr2;
   
-  w=400;
-  h=300;
-  x=y=5;
-  win = new AWindow( aguix, 10, 10, w, h, 0, catalog.getLocale( 338 ) );
+  win = new AWindow( aguix, 10, 10, 10, 10, 0, catalog.getLocale( 338 ) );
   win->create();
 
-  win->addTextFromString( catalog.getLocale( 481 ), x, y, 5, NULL, NULL, &y );
-  y += 5;
+  AContainer *ac1 = win->setContainer( new AContainer( win, 1, 3 ), true );
+  ac1->setMinSpace( 5 );
+  ac1->setMaxSpace( 5 );
+  ac1->setBorderWidth( 5 );
 
-  lv = (FieldListView*)win->add( new FieldListView( aguix,
-                                                    x,
-                                                    y,
-                                                    w - 2 * x,
-                                                    200,
-                                                    0 ) );
-  y+=lv->getHeight()+5;
+  win->addMultiLineText( catalog.getLocale( 481 ), *ac1, 0, 0, NULL, NULL );
+
+  lv = (FieldListView*)ac1->add( new FieldListView( aguix,
+                                                    0,
+                                                    0,
+                                                    400,
+                                                    300,
+                                                    0 ),
+                                 0, 1, AContainer::CMIN );
   lv->setHBarState(2);
   lv->setVBarState(2);
 
@@ -1308,30 +1335,27 @@ char *ScriptOp::getIfFlag()
     lv->setData( trow, i + nr );
   }
 
-  okb=(Button*)win->add(new Button(aguix,
-                                   5,
-                                   y,
-                                   catalog.getLocale(11),
-                                   1,
-                                   0,
-                                   0));
-  cb=(Button*)win->add(new Button(aguix,
-                                  5,
-                                  y,
-                                  catalog.getLocale(8),
-                                  1,
-                                  0,
-                                  0));
-  y+=okb->getHeight()+5;
+  AContainer *ac1_1 = ac1->add( new AContainer( win, 2, 1 ), 0, 2 );
+  ac1_1->setMinSpace( 5 );
+  ac1_1->setMaxSpace( -1 );
+  ac1_1->setBorderWidth( 0 );
+  Button *okb =(Button*)ac1_1->add( new Button( aguix,
+                                                0,
+                                                0,
+                                                catalog.getLocale( 11 ),
+                                                1,
+                                                0,
+                                                0 ), 0, 0, AContainer::CFIX );
+  Button *cancelb = (Button*)ac1_1->add( new Button( aguix,
+						     0,
+						     0,
+						     catalog.getLocale( 8 ),
+						     1,
+						     0,
+						     0 ), 1, 0, AContainer::CFIX );
 
-  b2[0] = okb;
-  b2[1] = cb;
-  AGUIX::scaleElementsW( w, 5, 10, -1, false, false, (GUIElement**)b2, NULL, 2 );
-  
-  h=y;
   win->setDoTabCycling( true );
-  win->resize(w,h);
-  win->setMinSize(w,h);
+  win->contMaximize( true );
   win->show();
   for(;endmode==-1;) {
     msg=aguix->WaitMessage(win);
@@ -1342,14 +1366,7 @@ char *ScriptOp::getIfFlag()
           break;
         case AG_BUTTONCLICKED:
           if(msg->button.button==okb) endmode=0;
-          else if(msg->button.button==cb) endmode=1;
-          break;
-        case AG_SIZECHANGED:
-          AGUIX::scaleElementsW( msg->size.neww, 5, 10, -1, false, false, (GUIElement**)b2, NULL, 2 );
-          for ( i = 0; i < 2; i++ ) {
-            b2[i]->move( b2[i]->getX(), msg->size.newh - 5 - b2[i]->getHeight() );
-          }
-          lv->resize( msg->size.neww - 10, b2[0]->getY() - 5 - lv->getY() );
+          else if(msg->button.button==cancelb) endmode=1;
           break;
       }
       aguix->ReplyMessage(msg);
