@@ -101,8 +101,8 @@ SearchEntryOp::normalmodesearchentry()
 bool SearchEntryOp::save( Datei *fh )
 {
   if ( fh == NULL ) return false;
-  WConfig::configPutPairBool( fh, "ignorecase", ignore_case );
-  WConfig::configPutPairBool( fh, "reversesearch", reverse_search );
+  fh->configPutPairBool( "ignorecase", ignore_case );
+  fh->configPutPairBool( "reversesearch", reverse_search );
   return true;
 }
 
@@ -187,8 +187,8 @@ int SearchEntryOp::configure()
     }
   }
   if ( ende == 1 ) {
-    ignore_case = ( cb->getState() == 1 ) ? true : false;
-    reverse_search = ( rscb->getState() == 1 ) ? true : false;
+    ignore_case = cb->getState();
+    reverse_search = rscb->getState();
   }
   delete win;
   return ( ende == 1 ) ? 0 : 1;
