@@ -98,22 +98,22 @@ bool
 SetFilterOp::save(Datei *fh)
 {
   if ( fh == NULL ) return false;
-  WConfig::configPutPairBool( fh, "requestflags", request_flags );
+  fh->configPutPairBool( "requestflags", request_flags );
   switch(filtermode) {
     case EXCLUDE_FILTER:
-      WConfig::configPutPair( fh, "mode", "exlude" );
+      fh->configPutPair( "mode", "exclude" );
       break;
     case UNSET_FILTER:
-      WConfig::configPutPair( fh, "mode", "unset" );
+      fh->configPutPair( "mode", "unset" );
       break;
     case UNSET_ALL:
-      WConfig::configPutPair( fh, "mode", "unsetall" );
+      fh->configPutPair( "mode", "unsetall" );
       break;
     default:
-      WConfig::configPutPair( fh, "mode", "include" );
+      fh->configPutPair( "mode", "include" );
       break;
   }
-  WConfig::configPutPairString( fh, "filter", filter );
+  fh->configPutPairString( "filter", filter );
   return true;
 }
 
@@ -329,7 +329,7 @@ SetFilterOp::doconfigure(int mode)
                 sg->activate();
                 break;
               case XK_3:
-                if(rfcb!=NULL) rfcb->setState((rfcb->getState()==1)?0:1);
+                if(rfcb!=NULL) rfcb->setState((rfcb->getState()==true)?false:true);
                 break;
               case XK_Return:
                 if ( cb->getHasFocus() == false ) {
@@ -410,7 +410,7 @@ SetFilterOp::doconfigure(int mode)
       }
     } else {
       // store in normal variables
-      request_flags=(rfcb->getState()==1)?true:false;
+      request_flags = rfcb->getState();
       _freesafe(filter);
       filter=dupstring(sg->getText());
       switch(fmcyb->getSelectedOption()) {
