@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: setsortmodeop.h,v 1.8 2004/10/27 21:09:05 ralf Exp $ */
+/* $Id: setsortmodeop.h,v 1.9 2005/10/19 18:01:39 ralf Exp $ */
 
 #ifndef SETSORTMODEOP_H
 #define SETSORTMODEOP_H
@@ -41,7 +41,7 @@ public:
 #if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
   using FunctionProto::run;
 #endif
-  virtual int run(ActionMessage*);
+  int run( WPUContext *wpu, ActionMessage* );
   virtual bool save(Datei*);
   virtual const char *getDescription();
   virtual int configure();
