@@ -1,6 +1,6 @@
 /* showimagemode.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2004 Ralf Hoffmann.
+ * Copyright (C) 2001-2006 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -24,6 +24,7 @@
 #include "normalmode.h"
 #include "worker_locale.h"
 #include "wconfig.h"
+#include "wc_color.hh"
 #include "worker.h"
 #include "configheader.h"
 #include "configparser.tab.h"
@@ -298,7 +299,7 @@ bool ShowImageMode::save(Datei *fh)
 {
   if ( fh == NULL ) return false;
   
-  WConfig::configPutPairString( fh, "viewstr", show_program );
+  fh->configPutPairString( "viewstr", show_program );
 
   return false;
 }
