@@ -30,6 +30,7 @@
 #include "execlass.h"
 #include "basic_actions.h"
 #include <algorithm>
+#include "wcfiletype.hh"
 
 const char *StartProgOp::name="StartProgOp";
 
@@ -44,7 +45,7 @@ StartProgOp::StartProgOp() : FunctionProto()
   dontcd = false;
   hasConfigure = true;
 
-  gui_msg = catalog.getLocale( 645 );
+  gui_msg = "";
 }
 
 StartProgOp::~StartProgOp()
@@ -100,22 +101,22 @@ StartProgOp::save(Datei *fh)
   if ( fh == NULL ) return false;
   switch(startprogstart) {
     case STARTPROGOP_START_IN_TERMINAL:
-      WConfig::configPutPair( fh, "start", "terminal" );
+      fh->configPutPair( "start", "terminal" );
       break;
     case STARTPROGOP_START_IN_TERMINAL_AND_WAIT4KEY:
-      WConfig::configPutPair( fh, "start", "terminalwait" );
+      fh->configPutPair( "start", "terminalwait" );
       break;
     case STARTPROGOP_SHOW_OUTPUT:
-      WConfig::configPutPair( fh, "start", "showoutput" );
+      fh->configPutPair( "start", "showoutput" );
       break;
     default:
-      WConfig::configPutPair( fh, "start", "normal" );
+      fh->configPutPair( "start", "normal" );
       break;
   }
-  WConfig::configPutPairString( fh, "viewstr", view_str.c_str() );
-  WConfig::configPutPairBool( fh, "global", global );
-  WConfig::configPutPairBool( fh, "inbackground", inbackground );
-  WConfig::configPutPairBool( fh, "dontcd", dontcd );
+  fh->configPutPairString( "viewstr", view_str.c_str() );
+  fh->configPutPairBool( "global", global );
+  fh->configPutPairBool( "inbackground", inbackground );
+  fh->configPutPairBool( "dontcd", dontcd );
   return true;
 }
 
@@ -440,10 +441,10 @@ int StartProgOp::doconfigure()
                 m1->_cyb->setOption(i);
                 break;
               case XK_2:
-                m1->_gcb->setState((m1->_gcb->getState()==1)?0:1);
+                m1->_gcb->setState((m1->_gcb->getState()==true)?false:true);
                 break;
               case XK_3:
-                m1->_ibcb->setState( ( m1->_ibcb->getState() == 1 ) ? 0 : 1 );
+                m1->_ibcb->setState( ( m1->_ibcb->getState() == true ) ? false : true );
                 break;
               case XK_Return:
                 if ( cb->getHasFocus() == false ) {
@@ -478,9 +479,9 @@ int StartProgOp::doconfigure()
 	startprogstart=STARTPROGOP_START_NORMAL;
 	break;
     }
-    global=(m1->_gcb->getState()==1)?true:false;
-    inbackground = ( m1->_ibcb->getState() == 1 ) ? true : false;
-    dontcd = ( m1->_dcdcb->getState() == 1 ) ? true : false;
+    global = m1->_gcb->getState();
+    inbackground = m1->_ibcb->getState();
+    dontcd = m1->_dcdcb->getState();
   }
   
   delete win;
@@ -577,6 +578,9 @@ std::auto_ptr< StartProgOp::StartSettings > StartProgOp::showGUI()
   char **liness;
   std::string str1;
 
+  if ( gui_msg.length() < 1 )
+    gui_msg = catalog.getLocale( 645 );
+
   win = new AWindow( aguix, 10, 10, 10, 10, 0, catalog.getLocaleCom( 32 ) );
   win->create();
 
@@ -734,13 +738,13 @@ std::auto_ptr< StartProgOp::StartSettings > StartProgOp::showGUI()
                 m1->_cyb->setOption( i );
                 break;
               case XK_2:
-                m1->_gcb->setState( ( m1->_gcb->getState() == 1 ) ? 0 : 1 );
+                m1->_gcb->setState( ( m1->_gcb->getState() == true ) ? false : true );
                 break;
               case XK_3:
-                m1->_ibcb->setState( ( m1->_ibcb->getState() == 1 ) ? 0 : 1 );
+                m1->_ibcb->setState( ( m1->_ibcb->getState() == true ) ? false : true );
                 break;
               case XK_4:
-                m1->_dcdcb->setState( ( m1->_dcdcb->getState() == 1 ) ? 0 : 1 );
+                m1->_dcdcb->setState( ( m1->_dcdcb->getState() == true ) ? false : true );
                 break;
               case XK_Return:
                 if ( cancelb->getHasFocus() == false ) {
@@ -790,9 +794,9 @@ std::auto_ptr< StartProgOp::StartSettings > StartProgOp::showGUI()
 	  sets->_start = STARTPROGOP_START_NORMAL;
 	  break;
       }
-      sets->_global = ( m1->_gcb->getState() == 1 ) ? true : false;
-      sets->_inbackground = ( m1->_ibcb->getState() == 1 ) ? true : false;
-      sets->_dontcd = ( m1->_dcdcb->getState() == 1 ) ? true : false;
+      sets->_global = m1->_gcb->getState();
+      sets->_inbackground = m1->_ibcb->getState();
+      sets->_dontcd = m1->_dcdcb->getState();
     } else if ( k1->getCurOption() == 1 ) {
       sets->_startmode = StartSettings::HANDLE_TYPE;
 
