@@ -1,6 +1,6 @@
 /* textstoragefile.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2005 Ralf Hoffmann.
+ * Copyright (C) 2005-2006 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: textstoragefile.cc,v 1.4 2005/08/17 06:33:06 ralf Exp $ */
 
 #include "textstoragefile.h"
 #include <sys/types.h>
@@ -26,30 +25,33 @@
 #include <fcntl.h>
 #include <unistd.h>
 #include "worker_locale.h"
+#include "pdatei.h"
 
 TextStorageFile::TextStorageFile( std::string filename, AWidth &lencalc ) : tss( "", lencalc )
 {
-  int fd;
   int read_bytes;
   char buffer[ 64 * 1024 ];
+  PDatei pd;
 
-  fd = worker_open( filename.c_str(), O_RDONLY, 0 );
-  if ( fd >= 0 ) {
-    read_bytes = worker_read( fd, buffer, sizeof( buffer ) );
+  if ( pd.open( filename.c_str() ) == 0 ) {
+    read_bytes = pd.read( buffer, sizeof( buffer ) );
     if ( read_bytes >= 0 ) {
 
       // tab replacing
-      int pos = 0;
       std::string notab_buffer;
       
       for ( int i = 0; i < read_bytes; i++ ) {
 	if ( buffer[i] != '\t' ) {
-	  notab_buffer += buffer[i];
-	  if ( buffer[i] == '\n' ) pos = 0;
-	  else pos++;
+	  // ignore \r from dos files
+	  if ( buffer[i] != '\r' ) {
+	    notab_buffer += buffer[i];
+	  }
 	} else {
-	  notab_buffer.append( 8 - ( pos % 8 ), ' ' );
-	  pos += 8 - ( pos % 8 );
+          //TODO currently I replace tabs with 8 spaces
+          //  In the future I hope I can make some GUI improvements
+          //  so it will not draw tabs but align the next character
+          //  at the next tab stop
+	  notab_buffer.append( 8, ' ' );
 	}
       }
 
@@ -62,7 +64,6 @@ TextStorageFile::TextStorageFile( std::string filename, AWidth &lencalc ) : tss(
       tss = TextStorageString( tstr, lencalc );
       _freesafe( tstr );
     }
-    worker_close( fd );
   }
 }
 
@@ -95,3 +96,18 @@ void TextStorageFile::setLineLimit( int new_limit )
 {
   tss.setLineLimit( new_limit );
 }
+
+std::pair<int,int> TextStorageFile::getRealLinePair( int line_nr ) const
+{
+  return tss.getRealLinePair( line_nr );
+}
+
+AWidth &TextStorageFile::getAWidth()
+{
+  return tss.getAWidth();
+}
+
+int TextStorageFile::findLineNr( std::pair<int,int> real_line ) const
+{
+  return tss.findLineNr( real_line );
+}
