@@ -35,6 +35,9 @@ class TextStorageFile : public TextStorage
   int getMaxLineWidth() const;
   int getLineWidth( int line_nr ) const;
   void setLineLimit( int new_limit );
+  std::pair<int,int> getRealLinePair( int line_nr ) const;
+  int findLineNr( std::pair<int,int> real_line ) const;
+  AWidth &getAWidth();
  private:
   TextStorageString tss;
 };
