@@ -89,7 +89,7 @@ bool
 ToggleListermodeOp::save(Datei *fh)
 {
   if ( fh == NULL ) return false;
-  WConfig::configPutPairString( fh, "mode", Worker::getNameOfMode( mode ) );
+  fh->configPutPairString( "mode", Worker::getNameOfMode( mode ) );
   return true;
 }
 
