@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: togglelistermodeop.h,v 1.9 2004/10/27 21:09:35 ralf Exp $ */
+/* $Id: togglelistermodeop.h,v 1.10 2005/10/19 17:57:14 ralf Exp $ */
 
 #ifndef TOGGLELISTRERMODEOP_H
 #define TOGGLELISTRERMODEOP_H
@@ -48,7 +48,7 @@ public:
 #if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
   using FunctionProto::run;
 #endif
-  virtual int run(ActionMessage*);
+  int run( WPUContext *wpu, ActionMessage* );
   virtual bool save(Datei*);
   virtual const char *getDescription();
   virtual int configure();
