@@ -1,6 +1,6 @@
 /* worker.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2005 Ralf Hoffmann.
+ * Copyright (C) 2001-2006 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,13 +18,14 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: worker.cc,v 1.117 2005/12/11 19:26:59 ralf Exp $ */
 
 #include "worker.h"
 #include "lister.h"
 #include "worker_locale.h"
 #include "normalmode.h"
 #include "wconfig.h"
+#include "wcdoubleshortkey.hh"
+#include "wcpath.hh"
 #include "filereq.h"
 #include "grouphash.h"
 #include "wdefines.h"
@@ -46,6 +47,10 @@
 #include "worker_shm.h"
 #include "parentactionop.h"
 #include <aguix/textstorage.h>
+#include "wchotkey.hh"
+#include "wcbutton.hh"
+#include <aguix/utf8.hh>
+#include "workerversion.h"
 
 Requester *Worker::req_static=NULL;
 int Worker::argc = 0;
@@ -947,45 +952,17 @@ void Worker::about()
   int erg;
   
   tstr = (char*)_allocsafe( 1024 + 3 * A_BYTESFORNUMBER( int ) + strlen( WORKER_COMMENT ) );
-  sprintf(tstr,"Worker %d.%d.%d%s|Copyright (C) 1998 - 2005 Ralf Hoffmann",WORKER_MAJOR,WORKER_MINOR,WORKER_PATCH,WORKER_COMMENT);
+  sprintf(tstr,"Worker %d.%d.%d%s|Copyright (C) 1998 - 2006 Ralf Hoffmann",WORKER_MAJOR,WORKER_MINOR,WORKER_PATCH,WORKER_COMMENT);
   str1 = tstr;
   _freesafe( tstr );
   
-  str1 += "||GZIP support for filetype recognition: ";
-#ifdef HAVE_LIBZ
-  str1 += "yes";
-#else
-  str1 += "no";
-#endif
-
-  str1 += "|BZIP2 support for filetype recognition: ";
-#ifdef HAVE_LIBBZ2
-  str1 += "yes";
-#else
-  str1 += "no";
-#endif
-
-  str1 += "|XPKMaster support for filetype recognition: ";
-#ifdef HAVE_LIBXPKMASTER
-  str1 += "yes";
-#else
-  str1 += "no";
-#endif
-
-  str1 += "|Regular expressions for filetype-pattern: ";
+  str1 += "||Regular expressions for filetype-pattern: ";
 #ifdef HAVE_REGEX
   str1 += "yes";
 #else
   str1 += "no";
 #endif
 
-  str1 += "|Thread usage: ";
-#ifdef WANT_THREADS
-  str1 += "yes";
-#else
-  str1 += "no";
-#endif
-
   str1 += "|Large file support: ";
 #ifdef WORKER_LFS_SUPPORTED
   str1 += "yes";
@@ -1000,6 +977,22 @@ void Worker::about()
   str1 += "no";
 #endif
 
+  str1 += "|UTF8 support: ";
+#ifdef DISABLE_UTF8_SUPPORT
+  str1 += "no";
+#else
+  str1 += "yes";
+  str1 += "|  current encoding: ";
+  switch ( UTF8::checkSupportedEncodings() ) {
+    case UTF8::ENCODING_UTF8:
+      str1 += "utf8";
+      break;
+    default:
+      str1 += "8 bit";
+      break;
+  }
+#endif
+
 #ifdef USE_MEM_SYSTEM
   str1 += "|This program is compiled with SLOW memorysystem";
 #endif
@@ -1320,16 +1313,16 @@ int Worker::saveListerState()
   fh = new Datei();
   if ( fh->open( str1.c_str(), "w" ) == 0 ) {
     if ( lister[1]->getFocus() == true ) {
-      WConfig::configPutPair( fh, "activeside", "right" );
+      fh->configPutPair( "activeside", "right" );
     } else {
-      WConfig::configPutPair( fh, "activeside", "left" );
+      fh->configPutPair( "activeside", "left" );
     }
-    WConfig::configOpenSection( fh, "left" );
+    fh->configOpenSection( "left" );
     lister[0]->saveState( fh );
-    WConfig::configCloseSection( fh ); //left
-    WConfig::configOpenSection( fh, "right" );
+    fh->configCloseSection(); //left
+    fh->configOpenSection( "right" );
     lister[1]->saveState( fh );
-    WConfig::configCloseSection( fh ); //right
+    fh->configCloseSection(); //right
 
     if ( fh->errors() != 0 ) {
       //TODO: Requester zeigen?
@@ -1670,12 +1663,17 @@ void Worker::checkfirststart( char **setlang )
         catdir += "/catalogs";
         dir2 = worker_opendir( catdir.c_str() );
         if ( dir2 != NULL ) {
+          std::string ending = ".catalog";
+          if ( UTF8::getUTF8Mode() != UTF8::UTF8_DISABLED && UTF8::getCurrentEncoding() == UTF8::ENCODING_UTF8 ) {
+            ending += ".utf8";
+          }
+
           while ( ( namelist = worker_readdir( dir2 ) ) != NULL ) {
-            if ( strlen( namelist->d_name ) > 8 ) {
-              if ( strcmp( ".catalog", ( namelist->d_name ) + strlen( namelist->d_name ) - 8 ) == 0 ) {
+            if ( strlen( namelist->d_name ) > ending.length() ) {
+              if ( strcmp( ending.c_str(), ( namelist->d_name ) + strlen( namelist->d_name ) - ending.length() ) == 0 ) {
                 // Dies ist ein Katalog
                 tstr = namelist->d_name;
-                tstr[ strlen( tstr ) - 8 ] = 0;
+                tstr[ strlen( tstr ) - ending.length() ] = 0;
                 langs->addElement( dupstring( tstr ) );
               }
             }
@@ -1720,6 +1718,9 @@ void Worker::checkfirststart( char **setlang )
         str2 = Worker::getDataDir();
         str2 += "/config-";
         str2 += tstr;
+        if ( UTF8::getUTF8Mode() != UTF8::UTF8_DISABLED && UTF8::getCurrentEncoding() == UTF8::ENCODING_UTF8 ) {
+          str2 += ".utf8";
+        }
       } else str2 = "";
       
       if ( Datei::fileExists( str2.c_str() ) == false ) {
