@@ -175,6 +175,9 @@ FunctionProto *Worker::getCommand4ID(int id)
     case 49:
       fpr = new InternalViewOp();
       break;
+    case 50:
+      fpr = new SearchOp();
+      break;
     default:
       fpr=new DNDAction();
   }
@@ -234,6 +237,7 @@ int Worker::getID4Command(FunctionProto *fpr)
   else if ( fpr->isName( NoOperationOp::name ) == true ) type = 47;
   else if ( fpr->isName( GoFTPOp::name ) == true ) type = 48;
   else if ( fpr->isName( InternalViewOp::name ) == true ) type = 49;
+  else if ( fpr->isName( SearchOp::name ) == true ) type = 50;
   return type;
 }
 
