@@ -353,8 +353,10 @@ int WPUContext::openWin()
     ty += cancelb->getHeight() + 5;
     userwin->maximizeX();
     userwin->maximizeY();
-    
-    tw = AGUIX::scaleElementsW( userwin->getWidth(), 5, 0, -1, false, false, (GUIElement**)&cancelb, NULL, 1 );
+
+    GUIElement *tbutton[1];
+    tbutton[0] = cancelb;
+    tw = AGUIX::scaleElementsW( userwin->getWidth(), 5, 0, -1, false, false, tbutton, NULL, 1 );
     
     if ( tw > userwin->getWidth() ) {
       userwin->resize( tw, userwin->getHeight() );
@@ -751,7 +753,6 @@ struct WPUContext::ifp_erg *WPUContext::ifp_factor()
   struct ifp_erg *e = NULL;
   int tnum;
   char *tstr, *tstr2;
-  ExeClass *ec;
   int exeerror;
 
   switch ( lookahead ) {
@@ -867,11 +868,10 @@ struct WPUContext::ifp_erg *WPUContext::ifp_factor()
   
           if ( tstr != NULL ) {
             e = (struct ifp_erg*)_allocsafe( sizeof( struct ifp_erg ) );
-            ec = new ExeClass( ExeClass::EXECUTE_NORMAL, worker );
+            std::auto_ptr<ExeClass> ec( new ExeClass( ExeClass::EXECUTE_NORMAL, worker ) );
             ec->cdDir( getBaseDir() );
             ec->addCommand( "%s", tstr );
             e->numval = ec->getReturnCode( &exeerror );
-            delete ec;
             e->strval = (char*)_allocsafe( A_BYTESFORNUMBER( e->numval ) );
             e->wasstring = 0;
             sprintf( e->strval, "%d", e->numval );
@@ -879,10 +879,21 @@ struct WPUContext::ifp_erg *WPUContext::ifp_factor()
             if ( exeerror != 0 ) {
               if ( worker->getRequester() != NULL ) {
                 char *reqstr;
-                reqstr = (char*)_allocsafe( strlen( catalog.getLocale( 473 ) ) + strlen( tstr ) + 1 );
-                sprintf( reqstr, catalog.getLocale( 473 ), tstr );
-                worker->getRequester()->request( catalog.getLocale( 347 ), reqstr, catalog.getLocale( 11 ) );
+                std::string error, str1;
+                
+                reqstr = (char*)_allocsafe( strlen( catalog.getLocale( 749 ) ) + strlen( tstr ) + 1 );
+                sprintf( reqstr, catalog.getLocale( 749 ), tstr );
+                
+                ec->readErrorOutput( error, 1024 );
+                
+                str1 = reqstr;
+                str1 += error;
                 _freesafe( reqstr );
+
+                AFontWidth lencalc( worker->getAGUIX(), NULL );
+                TextStorageString ts( str1, lencalc );
+
+                worker->getRequester()->request( catalog.getLocale( 347 ), ts, catalog.getLocale( 11 ) );
               }
               _freesafe( e->strval );
               _freesafe( e );
@@ -917,12 +928,11 @@ struct WPUContext::ifp_erg *WPUContext::ifp_factor()
   
           if ( tstr != NULL ) {
             e = (struct ifp_erg*)_allocsafe( sizeof( struct ifp_erg ) );
-            ec = new ExeClass( ExeClass::EXECUTE_NORMAL, worker );
+            std::auto_ptr<ExeClass> ec( new ExeClass( ExeClass::EXECUTE_NORMAL, worker ) );
             ec->cdDir( getBaseDir() );
             ec->addCommand( "%s", tstr );
             e->strval = ec->getOutput( &exeerror );
             e->wasstring = 1;
-            delete ec;
             if ( e->strval == NULL ) {
               e->strval = dupstring( "" );
             }
@@ -931,10 +941,21 @@ struct WPUContext::ifp_erg *WPUContext::ifp_factor()
             if ( exeerror != 0 ) {
               if ( worker->getRequester() != NULL ) {
                 char *reqstr;
-                reqstr = (char*)_allocsafe( strlen( catalog.getLocale( 473 ) ) + strlen( tstr ) + 1 );
-                sprintf( reqstr, catalog.getLocale( 473 ), tstr );
-                worker->getRequester()->request( catalog.getLocale( 347 ), reqstr, catalog.getLocale( 11 ) );
+                std::string error, str1;
+                
+                reqstr = (char*)_allocsafe( strlen( catalog.getLocale( 749 ) ) + strlen( tstr ) + 1 );
+                sprintf( reqstr, catalog.getLocale( 749 ), tstr );
+                
+                ec->readErrorOutput( error, 1024 );
+                
+                str1 = reqstr;
+                str1 += error;
                 _freesafe( reqstr );
+
+                AFontWidth lencalc( worker->getAGUIX(), NULL );
+                TextStorageString ts( str1, lencalc );
+
+                worker->getRequester()->request( catalog.getLocale( 347 ), ts, catalog.getLocale( 11 ) );
               }
               _freesafe( e->strval );
               _freesafe( e );
@@ -1181,8 +1202,10 @@ void WPUContext::setWinText( const char *str )
   if ( i < 2 ) i = 2;
   prosb->resize( i, prosb->getHeight() );
   bb2->resize( tw - 10, bb2->getHeight() );
-  
-  AGUIX::scaleElementsW( userwin->getWidth(), 5, 0, -1, false, false, (GUIElement**)&cancelb, NULL, 1 );
+
+  GUIElement *tbutton[1];
+  tbutton[0] = cancelb;
+  AGUIX::scaleElementsW( userwin->getWidth(), 5, 0, -1, false, false, tbutton, NULL, 1 );
   userwin->setMinSize( userwin->getWidth(), userwin->getHeight() );
   userwin->setMaxSize( userwin->getWidth(), userwin->getHeight() );
 }
